EXPECTED = {'EUTRA-InterNodeDefinitions': {'extensibility-implied': False,
                                'imports': {'EUTRA-RRC-Definitions': ['AntennaInfoCommon',
                                                                      'CellIdentity',
                                                                      'C-RNTI',
                                                                      'DL-DCCH-Message',
                                                                      'ARFCN-ValueEUTRA',
                                                                      'MasterInformationBlock',
                                                                      'MeasConfig',
                                                                      'PhysCellId',
                                                                      'RadioResourceConfigDedicated',
                                                                      'SecurityAlgorithmConfig',
                                                                      'ShortMAC-I',
                                                                      'SystemInformationBlockType1',
                                                                      'SystemInformationBlockType2',
                                                                      'UECapabilityInformation',
                                                                      'UE-CapabilityRAT-ContainerList']},
                                'object-classes': {},
                                'object-sets': {},
                                'tags': 'AUTOMATIC',
                                'types': {'AS-Config': {'members': [{'name': 'sourceMeasConfig',
                                                                     'type': 'MeasConfig'},
                                                                    {'name': 'sourceRadioResourceConfig',
                                                                     'type': 'RadioResourceConfigDedicated'},
                                                                    {'name': 'sourceSecurityAlgorithmConfig',
                                                                     'type': 'SecurityAlgorithmConfig'},
                                                                    {'name': 'sourceUE-Identity',
                                                                     'type': 'C-RNTI'},
                                                                    {'name': 'sourceMasterInformationBlock',
                                                                     'type': 'MasterInformationBlock'},
                                                                    {'name': 'sourceSystemInformationBlockType1',
                                                                     'type': 'SystemInformationBlockType1'},
                                                                    {'name': 'sourceSystemInformationBlockType2',
                                                                     'type': 'SystemInformationBlockType2'},
                                                                    {'name': 'antennaInfoCommon',
                                                                     'type': 'AntennaInfoCommon'},
                                                                    {'name': 'sourceDl-CarrierFreq',
                                                                     'type': 'ARFCN-ValueEUTRA'},
                                                                    '...'],
                                                        'type': 'SEQUENCE'},
                                          'AS-Context': {'members': [{'name': 'reestablishmentInfo',
                                                                      'optional': True,
                                                                      'type': 'ReestablishmentInfo'}],
                                                         'type': 'SEQUENCE'},
                                          'AdditionalReestabInfo': {'members': [{'name': 'cellIdentity',
                                                                                 'type': 'CellIdentity'},
                                                                                {'name': 'key-eNodeB-Star',
                                                                                 'type': 'Key-eNodeB-Star'},
                                                                                {'name': 'shortMAC-I',
                                                                                 'type': 'ShortMAC-I'}],
                                                                    'type': 'SEQUENCE'},
                                          'AdditionalReestabInfoList': {'element': {'type': 'AdditionalReestabInfo'},
                                                                        'size': [(1,
                                                                                  'maxReestabInfo')],
                                                                        'type': 'SEQUENCE '
                                                                                'OF'},
                                          'HandoverCommand': {'members': [{'members': [{'members': [{'name': 'handoverCommand-r8',
                                                                                                     'type': 'HandoverCommand-r8-IEs'},
                                                                                                    {'name': 'spare7',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare6',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare5',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare4',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare3',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare2',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare1',
                                                                                                     'type': 'NULL'}],
                                                                                        'name': 'c1',
                                                                                        'type': 'CHOICE'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                          'HandoverCommand-r8-IEs': {'members': [{'name': 'handoverCommandMessage',
                                                                                  'type': 'OCTET '
                                                                                          'STRING'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                          'HandoverPreparationInformation': {'members': [{'members': [{'members': [{'name': 'handoverPreparationInformation-r8',
                                                                                                                    'type': 'HandoverPreparationInformation-r8-IEs'},
                                                                                                                   {'name': 'spare7',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare6',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare5',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare4',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare3',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare2',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare1',
                                                                                                                    'type': 'NULL'}],
                                                                                                       'name': 'c1',
                                                                                                       'type': 'CHOICE'},
                                                                                                      {'members': [],
                                                                                                       'name': 'criticalExtensionsFuture',
                                                                                                       'type': 'SEQUENCE'}],
                                                                                          'name': 'criticalExtensions',
                                                                                          'type': 'CHOICE'}],
                                                                             'type': 'SEQUENCE'},
                                          'HandoverPreparationInformation-r8-IEs': {'members': [{'name': 'ue-RadioAccessCapabilityInfo',
                                                                                                 'type': 'UE-CapabilityRAT-ContainerList'},
                                                                                                {'name': 'as-Config',
                                                                                                 'optional': True,
                                                                                                 'type': 'AS-Config'},
                                                                                                {'name': 'rrm-Config',
                                                                                                 'optional': True,
                                                                                                 'type': 'RRM-Config'},
                                                                                                {'name': 'as-Context',
                                                                                                 'optional': True,
                                                                                                 'type': 'AS-Context'},
                                                                                                {'members': [],
                                                                                                 'name': 'nonCriticalExtension',
                                                                                                 'optional': True,
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'type': 'SEQUENCE'},
                                          'Key-eNodeB-Star': {'size': [256],
                                                              'type': 'BIT '
                                                                      'STRING'},
                                          'RRM-Config': {'members': [{'name': 'ue-InactiveTime',
                                                                      'optional': True,
                                                                      'type': 'ENUMERATED',
                                                                      'values': {0: 's1',
                                                                                 1: 's2',
                                                                                 2: 's3',
                                                                                 3: 's5',
                                                                                 4: 's7',
                                                                                 5: 's10',
                                                                                 6: 's15',
                                                                                 7: 's20',
                                                                                 8: 's25',
                                                                                 9: 's30',
                                                                                 10: 's40',
                                                                                 11: 's50',
                                                                                 12: 'min1',
                                                                                 13: 'min1s20c',
                                                                                 14: 'min1s40',
                                                                                 15: 'min2',
                                                                                 16: 'min2s30',
                                                                                 17: 'min3',
                                                                                 18: 'min3s30',
                                                                                 19: 'min4',
                                                                                 20: 'min5',
                                                                                 21: 'min6',
                                                                                 22: 'min7',
                                                                                 23: 'min8',
                                                                                 24: 'min9',
                                                                                 25: 'min10',
                                                                                 26: 'min12',
                                                                                 27: 'min14',
                                                                                 28: 'min17',
                                                                                 29: 'min20',
                                                                                 30: 'min24',
                                                                                 31: 'min28',
                                                                                 32: 'min33',
                                                                                 33: 'min38',
                                                                                 34: 'min44',
                                                                                 35: 'min50',
                                                                                 36: 'hr1',
                                                                                 37: 'hr1min30',
                                                                                 38: 'hr2',
                                                                                 39: 'hr2min30',
                                                                                 40: 'hr3',
                                                                                 41: 'hr3min30',
                                                                                 42: 'hr4',
                                                                                 43: 'hr5',
                                                                                 44: 'hr6',
                                                                                 45: 'hr8',
                                                                                 46: 'hr10',
                                                                                 47: 'hr13',
                                                                                 48: 'hr16',
                                                                                 49: 'hr20',
                                                                                 50: 'day1',
                                                                                 51: 'day1hr12',
                                                                                 52: 'day2',
                                                                                 53: 'day2hr12',
                                                                                 54: 'day3',
                                                                                 55: 'day4',
                                                                                 56: 'day5',
                                                                                 57: 'day7',
                                                                                 58: 'day10',
                                                                                 59: 'day14',
                                                                                 60: 'day19',
                                                                                 61: 'day24',
                                                                                 62: 'day30',
                                                                                 63: 'dayMoreThan30'}},
                                                                     '...'],
                                                         'type': 'SEQUENCE'},
                                          'ReestablishmentInfo': {'members': [{'name': 'sourcePhysCellId',
                                                                               'type': 'PhysCellId'},
                                                                              {'name': 'targetCellShortMAC-I',
                                                                               'type': 'ShortMAC-I'},
                                                                              {'name': 'additionalReestabInfoList',
                                                                               'optional': True,
                                                                               'type': 'AdditionalReestabInfoList'},
                                                                              '...'],
                                                                  'type': 'SEQUENCE'},
                                          'UERadioAccessCapabilityInformation': {'members': [{'members': [{'members': [{'name': 'ueRadioAccessCapabilityInformation-r8',
                                                                                                                        'type': 'UERadioAccessCapabilityInformation-r8-IEs'},
                                                                                                                       {'name': 'spare7',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare6',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare5',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare4',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare3',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare2',
                                                                                                                        'type': 'NULL'},
                                                                                                                       {'name': 'spare1',
                                                                                                                        'type': 'NULL'}],
                                                                                                           'name': 'c1',
                                                                                                           'type': 'CHOICE'},
                                                                                                          {'members': [],
                                                                                                           'name': 'criticalExtensionsFuture',
                                                                                                           'type': 'SEQUENCE'}],
                                                                                              'name': 'criticalExtensions',
                                                                                              'type': 'CHOICE'}],
                                                                                 'type': 'SEQUENCE'},
                                          'UERadioAccessCapabilityInformation-r8-IEs': {'members': [{'name': 'ue-RadioAccessCapabilityInfo',
                                                                                                     'type': 'OCTET '
                                                                                                             'STRING'},
                                                                                                    {'members': [],
                                                                                                     'name': 'nonCriticalExtension',
                                                                                                     'optional': True,
                                                                                                     'type': 'SEQUENCE'}],
                                                                                        'type': 'SEQUENCE'}},
                                'values': {'maxReestabInfo': {'type': 'INTEGER',
                                                              'value': 32}}},
 'EUTRA-RRC-Definitions': {'extensibility-implied': False,
                           'imports': {},
                           'object-classes': {},
                           'object-sets': {},
                           'tags': 'AUTOMATIC',
                           'types': {'AC-BarringConfig': {'members': [{'name': 'ac-BarringFactor',
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 'p00',
                                                                                  1: 'p05',
                                                                                  2: 'p10',
                                                                                  3: 'p15',
                                                                                  4: 'p20',
                                                                                  5: 'p25',
                                                                                  6: 'p30',
                                                                                  7: 'p40',
                                                                                  8: 'p50',
                                                                                  9: 'p60',
                                                                                  10: 'p70',
                                                                                  11: 'p75',
                                                                                  12: 'p80',
                                                                                  13: 'p85',
                                                                                  14: 'p90',
                                                                                  15: 'p95'}},
                                                                      {'name': 'ac-BarringTime',
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 's4',
                                                                                  1: 's8',
                                                                                  2: 's16',
                                                                                  3: 's32',
                                                                                  4: 's64',
                                                                                  5: 's128',
                                                                                  6: 's256',
                                                                                  7: 's512'}},
                                                                      {'name': 'ac-BarringForSpecialAC',
                                                                       'size': [5],
                                                                       'type': 'BIT '
                                                                               'STRING'}],
                                                          'type': 'SEQUENCE'},
                                     'ARFCN-ValueCDMA2000': {'restricted-to': [(0,
                                                                                2047)],
                                                             'type': 'INTEGER'},
                                     'ARFCN-ValueEUTRA': {'restricted-to': [(0,
                                                                             'maxEARFCN')],
                                                          'type': 'INTEGER'},
                                     'ARFCN-ValueGERAN': {'restricted-to': [(0,
                                                                             1023)],
                                                          'type': 'INTEGER'},
                                     'ARFCN-ValueUTRA': {'restricted-to': [(0,
                                                                            16383)],
                                                         'type': 'INTEGER'},
                                     'AccessStratumRelease': {'type': 'ENUMERATED',
                                                              'values': {0: 'rel8',
                                                                         1: 'spare7',
                                                                         2: 'spare6',
                                                                         3: 'spare5',
                                                                         4: 'spare4',
                                                                         5: 'spare3',
                                                                         6: 'spare2',
                                                                         7: 'spare1',
                                                                         8: '...'}},
                                     'AdditionalSpectrumEmission': {'restricted-to': [(1,
                                                                                       32)],
                                                                    'type': 'INTEGER'},
                                     'AllowedMeasBandwidth': {'type': 'ENUMERATED',
                                                              'values': {0: 'mbw6',
                                                                         1: 'mbw15',
                                                                         2: 'mbw25',
                                                                         3: 'mbw50',
                                                                         4: 'mbw75',
                                                                         5: 'mbw100'}},
                                     'AntennaInfoCommon': {'members': [{'name': 'antennaPortsCount',
                                                                        'type': 'ENUMERATED',
                                                                        'values': {0: 'an1',
                                                                                   1: 'an2',
                                                                                   2: 'an4',
                                                                                   3: 'spare1'}}],
                                                           'type': 'SEQUENCE'},
                                     'AntennaInfoDedicated': {'members': [{'name': 'transmissionMode',
                                                                           'type': 'ENUMERATED',
                                                                           'values': {0: 'tm1',
                                                                                      1: 'tm2',
                                                                                      2: 'tm3',
                                                                                      3: 'tm4',
                                                                                      4: 'tm5',
                                                                                      5: 'tm6',
                                                                                      6: 'tm7',
                                                                                      7: 'spare1'}},
                                                                          {'members': [{'name': 'n2TxAntenna-tm3',
                                                                                        'size': [2],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm3',
                                                                                        'size': [4],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n2TxAntenna-tm4',
                                                                                        'size': [6],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm4',
                                                                                        'size': [64],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n2TxAntenna-tm5',
                                                                                        'size': [4],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm5',
                                                                                        'size': [16],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n2TxAntenna-tm6',
                                                                                        'size': [4],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'n4TxAntenna-tm6',
                                                                                        'size': [16],
                                                                                        'type': 'BIT '
                                                                                                'STRING'}],
                                                                           'name': 'codebookSubsetRestriction',
                                                                           'optional': True,
                                                                           'type': 'CHOICE'},
                                                                          {'members': [{'name': 'release',
                                                                                        'type': 'NULL'},
                                                                                       {'name': 'setup',
                                                                                        'type': 'ENUMERATED',
                                                                                        'values': {0: 'closedLoop',
                                                                                                   1: 'openLoop'}}],
                                                                           'name': 'ue-TransmitAntennaSelection',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'BCCH-BCH-Message': {'members': [{'name': 'message',
                                                                       'type': 'BCCH-BCH-MessageType'}],
                                                          'type': 'SEQUENCE'},
                                     'BCCH-BCH-MessageType': {'type': 'MasterInformationBlock'},
                                     'BCCH-Config': {'members': [{'name': 'modificationPeriodCoeff',
                                                                  'type': 'ENUMERATED',
                                                                  'values': {0: 'n2',
                                                                             1: 'n4',
                                                                             2: 'n8',
                                                                             3: 'n16'}}],
                                                     'type': 'SEQUENCE'},
                                     'BCCH-DL-SCH-Message': {'members': [{'name': 'message',
                                                                          'type': 'BCCH-DL-SCH-MessageType'}],
                                                             'type': 'SEQUENCE'},
                                     'BCCH-DL-SCH-MessageType': {'members': [{'members': [{'name': 'systemInformation',
                                                                                           'type': 'SystemInformation'},
                                                                                          {'name': 'systemInformationBlockType1',
                                                                                           'type': 'SystemInformationBlockType1'}],
                                                                              'name': 'c1',
                                                                              'type': 'CHOICE'},
                                                                             {'members': [],
                                                                              'name': 'messageClassExtension',
                                                                              'type': 'SEQUENCE'}],
                                                                 'type': 'CHOICE'},
                                     'BandClassInfoCDMA2000': {'members': [{'name': 'bandClass',
                                                                            'type': 'BandclassCDMA2000'},
                                                                           {'name': 'cellReselectionPriority',
                                                                            'optional': True,
                                                                            'type': 'CellReselectionPriority'},
                                                                           {'name': 'threshX-High',
                                                                            'restricted-to': [(0,
                                                                                               63)],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'threshX-Low',
                                                                            'restricted-to': [(0,
                                                                                               63)],
                                                                            'type': 'INTEGER'},
                                                                           '...'],
                                                               'type': 'SEQUENCE'},
                                     'BandClassListCDMA2000': {'element': {'type': 'BandClassInfoCDMA2000'},
                                                               'size': [(1,
                                                                         'maxCDMA-BandClass')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'BandClassPriority1XRTT': {'members': [{'name': 'bandClass',
                                                                             'type': 'BandclassCDMA2000'},
                                                                            {'name': 'cellReselectionPriority',
                                                                             'type': 'CellReselectionPriority'}],
                                                                'type': 'SEQUENCE'},
                                     'BandClassPriorityHRPD': {'members': [{'name': 'bandClass',
                                                                            'type': 'BandclassCDMA2000'},
                                                                           {'name': 'cellReselectionPriority',
                                                                            'type': 'CellReselectionPriority'}],
                                                               'type': 'SEQUENCE'},
                                     'BandClassPriorityList1XRTT': {'element': {'type': 'BandClassPriority1XRTT'},
                                                                    'size': [(1,
                                                                              'maxCDMA-BandClass')],
                                                                    'type': 'SEQUENCE '
                                                                            'OF'},
                                     'BandClassPriorityListHRPD': {'element': {'type': 'BandClassPriorityHRPD'},
                                                                   'size': [(1,
                                                                             'maxCDMA-BandClass')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'BandIndicatorGERAN': {'type': 'ENUMERATED',
                                                            'values': {0: 'dcs1800',
                                                                       1: 'pcs1900'}},
                                     'BandInfoEUTRA': {'members': [{'name': 'interFreqBandList',
                                                                    'type': 'InterFreqBandList'},
                                                                   {'name': 'interRAT-BandList',
                                                                    'optional': True,
                                                                    'type': 'InterRAT-BandList'}],
                                                       'type': 'SEQUENCE'},
                                     'BandListEUTRA': {'element': {'type': 'BandInfoEUTRA'},
                                                       'size': [(1,
                                                                 'maxBands')],
                                                       'type': 'SEQUENCE OF'},
                                     'BandclassCDMA2000': {'type': 'ENUMERATED',
                                                           'values': {0: 'bc0',
                                                                      1: 'bc1',
                                                                      2: 'bc2',
                                                                      3: 'bc3',
                                                                      4: 'bc4',
                                                                      5: 'bc5',
                                                                      6: 'bc6',
                                                                      7: 'bc7',
                                                                      8: 'bc8',
                                                                      9: 'bc9',
                                                                      10: 'bc10',
                                                                      11: 'bc11',
                                                                      12: 'bc12',
                                                                      13: 'bc13',
                                                                      14: 'bc14',
                                                                      15: 'bc15',
                                                                      16: 'bc16',
                                                                      17: 'bc17',
                                                                      18: 'spare14',
                                                                      19: 'spare13',
                                                                      20: 'spare12',
                                                                      21: 'spare11',
                                                                      22: 'spare10',
                                                                      23: 'spare9',
                                                                      24: 'spare8',
                                                                      25: 'spare7',
                                                                      26: 'spare6',
                                                                      27: 'spare5',
                                                                      28: 'spare4',
                                                                      29: 'spare3',
                                                                      30: 'spare2',
                                                                      31: 'spare1',
                                                                      32: '...'}},
                                     'BlackCellsToAddMod': {'members': [{'name': 'cellIndex',
                                                                         'restricted-to': [(1,
                                                                                            'maxCellMeas')],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'physCellIdRange',
                                                                         'type': 'PhysCellIdRange'}],
                                                            'type': 'SEQUENCE'},
                                     'BlackCellsToAddModList': {'element': {'type': 'BlackCellsToAddMod'},
                                                                'size': [(1,
                                                                          'maxCellMeas')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'C-RNTI': {'size': [16],
                                                'type': 'BIT STRING'},
                                     'CDMA2000-Type': {'type': 'ENUMERATED',
                                                       'values': {0: 'type1XRTT',
                                                                  1: 'typeHRPD'}},
                                     'CQI-ReportConfig': {'members': [{'name': 'cqi-ReportModeAperiodic',
                                                                       'optional': True,
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 'rm12',
                                                                                  1: 'rm20',
                                                                                  2: 'rm22',
                                                                                  3: 'rm30',
                                                                                  4: 'rm31',
                                                                                  5: 'spare3',
                                                                                  6: 'spare2',
                                                                                  7: 'spare1'}},
                                                                      {'name': 'nomPDSCH-RS-EPRE-Offset',
                                                                       'restricted-to': [(-1,
                                                                                          6)],
                                                                       'type': 'INTEGER'},
                                                                      {'name': 'cqi-ReportPeriodic',
                                                                       'optional': True,
                                                                       'type': 'CQI-ReportPeriodic'}],
                                                          'type': 'SEQUENCE'},
                                     'CQI-ReportPeriodic': {'members': [{'name': 'release',
                                                                         'type': 'NULL'},
                                                                        {'members': [{'name': 'cqi-PUCCH-ResourceIndex',
                                                                                      'restricted-to': [(0,
                                                                                                         1185)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'cqi-pmi-ConfigIndex',
                                                                                      'restricted-to': [(0,
                                                                                                         1023)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'members': [{'name': 'widebandCQI',
                                                                                                   'type': 'NULL'},
                                                                                                  {'members': [{'name': 'k',
                                                                                                                'restricted-to': [(1,
                                                                                                                                   4)],
                                                                                                                'type': 'INTEGER'}],
                                                                                                   'name': 'subbandCQI',
                                                                                                   'type': 'SEQUENCE'}],
                                                                                      'name': 'cqi-FormatIndicatorPeriodic',
                                                                                      'type': 'CHOICE'},
                                                                                     {'name': 'ri-ConfigIndex',
                                                                                      'optional': True,
                                                                                      'restricted-to': [(0,
                                                                                                         1023)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'simultaneousAckNackAndCQI',
                                                                                      'type': 'BOOLEAN'}],
                                                                         'name': 'setup',
                                                                         'type': 'SEQUENCE'}],
                                                            'type': 'CHOICE'},
                                     'CSFB-RegistrationParam1XRTT': {'members': [{'name': 'sid',
                                                                                  'size': [15],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'nid',
                                                                                  'size': [16],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'multipleSID',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'multipleNID',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'homeReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'foreignSIDReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'foreignNIDReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'parameterReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'powerUpReg',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'registrationPeriod',
                                                                                  'size': [7],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'registrationZone',
                                                                                  'size': [12],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'totalZone',
                                                                                  'size': [3],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'zoneTimer',
                                                                                  'size': [3],
                                                                                  'type': 'BIT '
                                                                                          'STRING'}],
                                                                     'type': 'SEQUENCE'},
                                     'CSFBParametersRequestCDMA2000': {'members': [{'members': [{'name': 'csfbParametersRequestCDMA2000-r8',
                                                                                                 'type': 'CSFBParametersRequestCDMA2000-r8-IEs'},
                                                                                                {'members': [],
                                                                                                 'name': 'criticalExtensionsFuture',
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'name': 'criticalExtensions',
                                                                                    'type': 'CHOICE'}],
                                                                       'type': 'SEQUENCE'},
                                     'CSFBParametersRequestCDMA2000-r8-IEs': {'members': [{'members': [],
                                                                                           'name': 'nonCriticalExtension',
                                                                                           'optional': True,
                                                                                           'type': 'SEQUENCE'}],
                                                                              'type': 'SEQUENCE'},
                                     'CSFBParametersResponseCDMA2000': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                     'type': 'RRC-TransactionIdentifier'},
                                                                                    {'members': [{'name': 'csfbParametersResponseCDMA2000-r8',
                                                                                                  'type': 'CSFBParametersResponseCDMA2000-r8-IEs'},
                                                                                                 {'members': [],
                                                                                                  'name': 'criticalExtensionsFuture',
                                                                                                  'type': 'SEQUENCE'}],
                                                                                     'name': 'criticalExtensions',
                                                                                     'type': 'CHOICE'}],
                                                                        'type': 'SEQUENCE'},
                                     'CSFBParametersResponseCDMA2000-r8-IEs': {'members': [{'name': 'rand',
                                                                                            'type': 'RAND-CDMA2000'},
                                                                                           {'name': 'mobilityParameters',
                                                                                            'type': 'MobilityParametersCDMA2000'},
                                                                                           {'members': [],
                                                                                            'name': 'nonCriticalExtension',
                                                                                            'optional': True,
                                                                                            'type': 'SEQUENCE'}],
                                                                               'type': 'SEQUENCE'},
                                     'CarrierBandwidthEUTRA': {'members': [{'name': 'dl-Bandwidth',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'n6',
                                                                                       1: 'n15',
                                                                                       2: 'n25',
                                                                                       3: 'n50',
                                                                                       4: 'n75',
                                                                                       5: 'n100',
                                                                                       6: 'spare10',
                                                                                       7: 'spare9',
                                                                                       8: 'spare8',
                                                                                       9: 'spare7',
                                                                                       10: 'spare6',
                                                                                       11: 'spare5',
                                                                                       12: 'spare4',
                                                                                       13: 'spare3',
                                                                                       14: 'spare2',
                                                                                       15: 'spare1'}},
                                                                           {'name': 'ul-Bandwidth',
                                                                            'optional': True,
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'n6',
                                                                                       1: 'n15',
                                                                                       2: 'n25',
                                                                                       3: 'n50',
                                                                                       4: 'n75',
                                                                                       5: 'n100',
                                                                                       6: 'spare10',
                                                                                       7: 'spare9',
                                                                                       8: 'spare8',
                                                                                       9: 'spare7',
                                                                                       10: 'spare6',
                                                                                       11: 'spare5',
                                                                                       12: 'spare4',
                                                                                       13: 'spare3',
                                                                                       14: 'spare2',
                                                                                       15: 'spare1'}}],
                                                               'type': 'SEQUENCE'},
                                     'CarrierFreqCDMA2000': {'members': [{'name': 'bandClass',
                                                                          'type': 'BandclassCDMA2000'},
                                                                         {'name': 'arfcn',
                                                                          'type': 'ARFCN-ValueCDMA2000'}],
                                                             'type': 'SEQUENCE'},
                                     'CarrierFreqEUTRA': {'members': [{'name': 'dl-CarrierFreq',
                                                                       'type': 'ARFCN-ValueEUTRA'},
                                                                      {'name': 'ul-CarrierFreq',
                                                                       'optional': True,
                                                                       'type': 'ARFCN-ValueEUTRA'}],
                                                          'type': 'SEQUENCE'},
                                     'CarrierFreqGERAN': {'members': [{'name': 'arfcn',
                                                                       'type': 'ARFCN-ValueGERAN'},
                                                                      {'name': 'bandIndicator',
                                                                       'type': 'BandIndicatorGERAN'}],
                                                          'type': 'SEQUENCE'},
                                     'CarrierFreqListUTRA-FDD': {'element': {'type': 'CarrierFreqUTRA-FDD'},
                                                                 'size': [(1,
                                                                           'maxUTRA-FDD-Carrier')],
                                                                 'type': 'SEQUENCE '
                                                                         'OF'},
                                     'CarrierFreqListUTRA-TDD': {'element': {'type': 'CarrierFreqUTRA-TDD'},
                                                                 'size': [(1,
                                                                           'maxUTRA-TDD-Carrier')],
                                                                 'type': 'SEQUENCE '
                                                                         'OF'},
                                     'CarrierFreqUTRA-FDD': {'members': [{'name': 'carrierFreq',
                                                                          'type': 'ARFCN-ValueUTRA'},
                                                                         {'name': 'cellReselectionPriority',
                                                                          'optional': True,
                                                                          'type': 'CellReselectionPriority'},
                                                                         {'name': 'threshX-High',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'threshX-Low',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'q-RxLevMin',
                                                                          'restricted-to': [(-60,
                                                                                             -13)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'p-MaxUTRA',
                                                                          'restricted-to': [(-50,
                                                                                             33)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'q-QualMin',
                                                                          'restricted-to': [(-24,
                                                                                             0)],
                                                                          'type': 'INTEGER'},
                                                                         '...'],
                                                             'type': 'SEQUENCE'},
                                     'CarrierFreqUTRA-TDD': {'members': [{'name': 'carrierFreq',
                                                                          'type': 'ARFCN-ValueUTRA'},
                                                                         {'name': 'cellReselectionPriority',
                                                                          'optional': True,
                                                                          'type': 'CellReselectionPriority'},
                                                                         {'name': 'threshX-High',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'threshX-Low',
                                                                          'type': 'ReselectionThreshold'},
                                                                         {'name': 'q-RxLevMin',
                                                                          'restricted-to': [(-60,
                                                                                             -13)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'p-MaxUTRA',
                                                                          'restricted-to': [(-50,
                                                                                             33)],
                                                                          'type': 'INTEGER'},
                                                                         '...'],
                                                             'type': 'SEQUENCE'},
                                     'CarrierFreqsGERAN': {'members': [{'name': 'startingARFCN',
                                                                        'type': 'ARFCN-ValueGERAN'},
                                                                       {'name': 'bandIndicator',
                                                                        'type': 'BandIndicatorGERAN'},
                                                                       {'members': [{'name': 'explicitListOfARFCNs',
                                                                                     'type': 'ExplicitListOfARFCNs'},
                                                                                    {'members': [{'name': 'arfcn-Spacing',
                                                                                                  'restricted-to': [(1,
                                                                                                                     8)],
                                                                                                  'type': 'INTEGER'},
                                                                                                 {'name': 'numberOfFollowingARFCNs',
                                                                                                  'restricted-to': [(0,
                                                                                                                     31)],
                                                                                                  'type': 'INTEGER'}],
                                                                                     'name': 'equallySpacedARFCNs',
                                                                                     'type': 'SEQUENCE'},
                                                                                    {'name': 'variableBitMapOfARFCNs',
                                                                                     'size': [(1,
                                                                                               16)],
                                                                                     'type': 'OCTET '
                                                                                             'STRING'}],
                                                                        'name': 'followingARFCNs',
                                                                        'type': 'CHOICE'}],
                                                           'type': 'SEQUENCE'},
                                     'CarrierFreqsInfoGERAN': {'members': [{'name': 'carrierFreqs',
                                                                            'type': 'CarrierFreqsGERAN'},
                                                                           {'members': [{'name': 'cellReselectionPriority',
                                                                                         'optional': True,
                                                                                         'type': 'CellReselectionPriority'},
                                                                                        {'name': 'ncc-Permitted',
                                                                                         'size': [8],
                                                                                         'type': 'BIT '
                                                                                                 'STRING'},
                                                                                        {'name': 'q-RxLevMin',
                                                                                         'restricted-to': [(0,
                                                                                                            45)],
                                                                                         'type': 'INTEGER'},
                                                                                        {'name': 'p-MaxGERAN',
                                                                                         'optional': True,
                                                                                         'restricted-to': [(0,
                                                                                                            39)],
                                                                                         'type': 'INTEGER'},
                                                                                        {'name': 'threshX-High',
                                                                                         'type': 'ReselectionThreshold'},
                                                                                        {'name': 'threshX-Low',
                                                                                         'type': 'ReselectionThreshold'}],
                                                                            'name': 'commonInfo',
                                                                            'type': 'SEQUENCE'},
                                                                           '...'],
                                                               'type': 'SEQUENCE'},
                                     'CarrierFreqsInfoListGERAN': {'element': {'type': 'CarrierFreqsInfoGERAN'},
                                                                   'size': [(1,
                                                                             'maxGNFG')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellChangeOrder': {'members': [{'name': 't304',
                                                                      'type': 'ENUMERATED',
                                                                      'values': {0: 'ms100',
                                                                                 1: 'ms200',
                                                                                 2: 'ms500',
                                                                                 3: 'ms1000',
                                                                                 4: 'ms2000',
                                                                                 5: 'ms4000',
                                                                                 6: 'ms8000',
                                                                                 7: 'spare1'}},
                                                                     {'members': [{'members': [{'name': 'physCellId',
                                                                                                'type': 'PhysCellIdGERAN'},
                                                                                               {'name': 'carrierFreq',
                                                                                                'type': 'CarrierFreqGERAN'},
                                                                                               {'name': 'networkControlOrder',
                                                                                                'optional': True,
                                                                                                'size': [2],
                                                                                                'type': 'BIT '
                                                                                                        'STRING'},
                                                                                               {'name': 'systemInformation',
                                                                                                'optional': True,
                                                                                                'type': 'SI-OrPSI-GERAN'}],
                                                                                   'name': 'geran',
                                                                                   'type': 'SEQUENCE'},
                                                                                  '...'],
                                                                      'name': 'targetRAT-Type',
                                                                      'type': 'CHOICE'}],
                                                         'type': 'SEQUENCE'},
                                     'CellGlobalIdCDMA2000': {'members': [{'name': 'cellGlobalId1XRTT',
                                                                           'size': [47],
                                                                           'type': 'BIT '
                                                                                   'STRING'},
                                                                          {'name': 'cellGlobalIdHRPD',
                                                                           'size': [128],
                                                                           'type': 'BIT '
                                                                                   'STRING'}],
                                                              'type': 'CHOICE'},
                                     'CellGlobalIdEUTRA': {'members': [{'name': 'plmn-Identity',
                                                                        'type': 'PLMN-Identity'},
                                                                       {'name': 'cellIdentity',
                                                                        'type': 'CellIdentity'}],
                                                           'type': 'SEQUENCE'},
                                     'CellGlobalIdGERAN': {'members': [{'name': 'plmn-Identity',
                                                                        'type': 'PLMN-Identity'},
                                                                       {'name': 'locationAreaCode',
                                                                        'size': [16],
                                                                        'type': 'BIT '
                                                                                'STRING'},
                                                                       {'name': 'cellIdentity',
                                                                        'size': [16],
                                                                        'type': 'BIT '
                                                                                'STRING'}],
                                                           'type': 'SEQUENCE'},
                                     'CellGlobalIdUTRA': {'members': [{'name': 'plmn-Identity',
                                                                       'type': 'PLMN-Identity'},
                                                                      {'name': 'cellIdentity',
                                                                       'size': [28],
                                                                       'type': 'BIT '
                                                                               'STRING'}],
                                                          'type': 'SEQUENCE'},
                                     'CellIdentity': {'size': [28],
                                                      'type': 'BIT STRING'},
                                     'CellIndex': {'restricted-to': [(1,
                                                                      'maxCellMeas')],
                                                   'type': 'INTEGER'},
                                     'CellIndexList': {'element': {'type': 'CellIndex'},
                                                       'size': [(1,
                                                                 'maxCellMeas')],
                                                       'type': 'SEQUENCE OF'},
                                     'CellReselectionParametersCDMA2000': {'members': [{'name': 'bandClassList',
                                                                                        'type': 'BandClassListCDMA2000'},
                                                                                       {'name': 'neighCellList',
                                                                                        'type': 'NeighCellListCDMA2000'},
                                                                                       {'name': 't-ReselectionCDMA2000',
                                                                                        'type': 'T-Reselection'},
                                                                                       {'name': 't-ReselectionCDMA2000-SF',
                                                                                        'optional': True,
                                                                                        'type': 'SpeedStateScaleFactors'}],
                                                                           'type': 'SEQUENCE'},
                                     'CellReselectionPriority': {'restricted-to': [(0,
                                                                                    7)],
                                                                 'type': 'INTEGER'},
                                     'CellsToAddMod': {'members': [{'name': 'cellIndex',
                                                                    'restricted-to': [(1,
                                                                                       'maxCellMeas')],
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'physCellId',
                                                                    'type': 'PhysCellId'},
                                                                   {'name': 'cellIndividualOffset',
                                                                    'type': 'Q-OffsetRange'}],
                                                       'type': 'SEQUENCE'},
                                     'CellsToAddModCDMA2000': {'members': [{'name': 'cellIndex',
                                                                            'restricted-to': [(1,
                                                                                               'maxCellMeas')],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'physCellId',
                                                                            'type': 'PhysCellIdCDMA2000'}],
                                                               'type': 'SEQUENCE'},
                                     'CellsToAddModList': {'element': {'type': 'CellsToAddMod'},
                                                           'size': [(1,
                                                                     'maxCellMeas')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'CellsToAddModListCDMA2000': {'element': {'type': 'CellsToAddModCDMA2000'},
                                                                   'size': [(1,
                                                                             'maxCellMeas')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellsToAddModListUTRA-FDD': {'element': {'type': 'CellsToAddModUTRA-FDD'},
                                                                   'size': [(1,
                                                                             'maxCellMeas')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellsToAddModListUTRA-TDD': {'element': {'type': 'CellsToAddModUTRA-TDD'},
                                                                   'size': [(1,
                                                                             'maxCellMeas')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'CellsToAddModUTRA-FDD': {'members': [{'name': 'cellIndex',
                                                                            'restricted-to': [(1,
                                                                                               'maxCellMeas')],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'physCellId',
                                                                            'type': 'PhysCellIdUTRA-FDD'}],
                                                               'type': 'SEQUENCE'},
                                     'CellsToAddModUTRA-TDD': {'members': [{'name': 'cellIndex',
                                                                            'restricted-to': [(1,
                                                                                               'maxCellMeas')],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'physCellId',
                                                                            'type': 'PhysCellIdUTRA-TDD'}],
                                                               'type': 'SEQUENCE'},
                                     'CounterCheck': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                   'type': 'RRC-TransactionIdentifier'},
                                                                  {'members': [{'members': [{'name': 'counterCheck-r8',
                                                                                             'type': 'CounterCheck-r8-IEs'},
                                                                                            {'name': 'spare3',
                                                                                             'type': 'NULL'},
                                                                                            {'name': 'spare2',
                                                                                             'type': 'NULL'},
                                                                                            {'name': 'spare1',
                                                                                             'type': 'NULL'}],
                                                                                'name': 'c1',
                                                                                'type': 'CHOICE'},
                                                                               {'members': [],
                                                                                'name': 'criticalExtensionsFuture',
                                                                                'type': 'SEQUENCE'}],
                                                                   'name': 'criticalExtensions',
                                                                   'type': 'CHOICE'}],
                                                      'type': 'SEQUENCE'},
                                     'CounterCheck-r8-IEs': {'members': [{'name': 'drb-CountMSB-InfoList',
                                                                          'type': 'DRB-CountMSB-InfoList'},
                                                                         {'members': [],
                                                                          'name': 'nonCriticalExtension',
                                                                          'optional': True,
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'SEQUENCE'},
                                     'CounterCheckResponse': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                          {'members': [{'name': 'counterCheckResponse-r8',
                                                                                        'type': 'CounterCheckResponse-r8-IEs'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'CounterCheckResponse-r8-IEs': {'members': [{'name': 'drb-CountInfoList',
                                                                                  'type': 'DRB-CountInfoList'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'DL-AM-RLC': {'members': [{'name': 't-Reordering',
                                                                'type': 'T-Reordering'},
                                                               {'name': 't-StatusProhibit',
                                                                'type': 'T-StatusProhibit'}],
                                                   'type': 'SEQUENCE'},
                                     'DL-CCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'DL-CCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'DL-CCCH-MessageType': {'members': [{'members': [{'name': 'rrcConnectionReestablishment',
                                                                                       'type': 'RRCConnectionReestablishment'},
                                                                                      {'name': 'rrcConnectionReestablishmentReject',
                                                                                       'type': 'RRCConnectionReestablishmentReject'},
                                                                                      {'name': 'rrcConnectionReject',
                                                                                       'type': 'RRCConnectionReject'},
                                                                                      {'name': 'rrcConnectionSetup',
                                                                                       'type': 'RRCConnectionSetup'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'DL-DCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'DL-DCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'DL-DCCH-MessageType': {'members': [{'members': [{'name': 'csfbParametersResponseCDMA2000',
                                                                                       'type': 'CSFBParametersResponseCDMA2000'},
                                                                                      {'name': 'dlInformationTransfer',
                                                                                       'type': 'DLInformationTransfer'},
                                                                                      {'name': 'handoverFromEUTRAPreparationRequest',
                                                                                       'type': 'HandoverFromEUTRAPreparationRequest'},
                                                                                      {'name': 'mobilityFromEUTRACommand',
                                                                                       'type': 'MobilityFromEUTRACommand'},
                                                                                      {'name': 'rrcConnectionReconfiguration',
                                                                                       'type': 'RRCConnectionReconfiguration'},
                                                                                      {'name': 'rrcConnectionRelease',
                                                                                       'type': 'RRCConnectionRelease'},
                                                                                      {'name': 'securityModeCommand',
                                                                                       'type': 'SecurityModeCommand'},
                                                                                      {'name': 'ueCapabilityEnquiry',
                                                                                       'type': 'UECapabilityEnquiry'},
                                                                                      {'name': 'counterCheck',
                                                                                       'type': 'CounterCheck'},
                                                                                      {'name': 'spare7',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare6',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare5',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare4',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare3',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare2',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare1',
                                                                                       'type': 'NULL'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'DL-UM-RLC': {'members': [{'name': 'sn-FieldLength',
                                                                'type': 'SN-FieldLength'},
                                                               {'name': 't-Reordering',
                                                                'type': 'T-Reordering'}],
                                                   'type': 'SEQUENCE'},
                                     'DLInformationTransfer': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                            'type': 'RRC-TransactionIdentifier'},
                                                                           {'members': [{'members': [{'name': 'dlInformationTransfer-r8',
                                                                                                      'type': 'DLInformationTransfer-r8-IEs'},
                                                                                                     {'name': 'spare3',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare2',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare1',
                                                                                                      'type': 'NULL'}],
                                                                                         'name': 'c1',
                                                                                         'type': 'CHOICE'},
                                                                                        {'members': [],
                                                                                         'name': 'criticalExtensionsFuture',
                                                                                         'type': 'SEQUENCE'}],
                                                                            'name': 'criticalExtensions',
                                                                            'type': 'CHOICE'}],
                                                               'type': 'SEQUENCE'},
                                     'DLInformationTransfer-r8-IEs': {'members': [{'members': [{'name': 'dedicatedInfoNAS',
                                                                                                'type': 'DedicatedInfoNAS'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-1XRTT',
                                                                                                'type': 'DedicatedInfoCDMA2000'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-HRPD',
                                                                                                'type': 'DedicatedInfoCDMA2000'}],
                                                                                   'name': 'dedicatedInfoType',
                                                                                   'type': 'CHOICE'},
                                                                                  {'members': [],
                                                                                   'name': 'nonCriticalExtension',
                                                                                   'optional': True,
                                                                                   'type': 'SEQUENCE'}],
                                                                      'type': 'SEQUENCE'},
                                     'DRB-CountInfo': {'members': [{'name': 'drb-Identity',
                                                                    'type': 'DRB-Identity'},
                                                                   {'name': 'count-Uplink',
                                                                    'restricted-to': [(0,
                                                                                       4294967295)],
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'count-Downlink',
                                                                    'restricted-to': [(0,
                                                                                       4294967295)],
                                                                    'type': 'INTEGER'}],
                                                       'type': 'SEQUENCE'},
                                     'DRB-CountInfoList': {'element': {'type': 'DRB-CountInfo'},
                                                           'size': [(0,
                                                                     'maxDRB')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'DRB-CountMSB-Info': {'members': [{'name': 'drb-Identity',
                                                                        'type': 'DRB-Identity'},
                                                                       {'name': 'countMSB-Uplink',
                                                                        'restricted-to': [(0,
                                                                                           33554431)],
                                                                        'type': 'INTEGER'},
                                                                       {'name': 'countMSB-Downlink',
                                                                        'restricted-to': [(0,
                                                                                           33554431)],
                                                                        'type': 'INTEGER'}],
                                                           'type': 'SEQUENCE'},
                                     'DRB-CountMSB-InfoList': {'element': {'type': 'DRB-CountMSB-Info'},
                                                               'size': [(1,
                                                                         'maxDRB')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'DRB-Identity': {'restricted-to': [(1,
                                                                         32)],
                                                      'type': 'INTEGER'},
                                     'DRB-ToAddMod': {'members': [{'name': 'eps-BearerIdentity',
                                                                   'optional': True,
                                                                   'restricted-to': [(0,
                                                                                      15)],
                                                                   'type': 'INTEGER'},
                                                                  {'name': 'drb-Identity',
                                                                   'type': 'DRB-Identity'},
                                                                  {'name': 'pdcp-Config',
                                                                   'optional': True,
                                                                   'type': 'PDCP-Config'},
                                                                  {'name': 'rlc-Config',
                                                                   'optional': True,
                                                                   'type': 'RLC-Config'},
                                                                  {'name': 'logicalChannelIdentity',
                                                                   'optional': True,
                                                                   'restricted-to': [(3,
                                                                                      10)],
                                                                   'type': 'INTEGER'},
                                                                  {'name': 'logicalChannelConfig',
                                                                   'optional': True,
                                                                   'type': 'LogicalChannelConfig'},
                                                                  '...'],
                                                      'type': 'SEQUENCE'},
                                     'DRB-ToAddModList': {'element': {'type': 'DRB-ToAddMod'},
                                                          'size': [(1,
                                                                    'maxDRB')],
                                                          'type': 'SEQUENCE '
                                                                  'OF'},
                                     'DRB-ToReleaseList': {'element': {'type': 'DRB-Identity'},
                                                           'size': [(1,
                                                                     'maxDRB')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'DRX-Config': {'members': [{'name': 'release',
                                                                 'type': 'NULL'},
                                                                {'members': [{'name': 'onDurationTimer',
                                                                              'type': 'ENUMERATED',
                                                                              'values': {0: 'psf1',
                                                                                         1: 'psf2',
                                                                                         2: 'psf3',
                                                                                         3: 'psf4',
                                                                                         4: 'psf5',
                                                                                         5: 'psf6',
                                                                                         6: 'psf8',
                                                                                         7: 'psf10',
                                                                                         8: 'psf20',
                                                                                         9: 'psf30',
                                                                                         10: 'psf40',
                                                                                         11: 'psf50',
                                                                                         12: 'psf60',
                                                                                         13: 'psf80',
                                                                                         14: 'psf100',
                                                                                         15: 'psf200'}},
                                                                             {'name': 'drx-InactivityTimer',
                                                                              'type': 'ENUMERATED',
                                                                              'values': {0: 'psf1',
                                                                                         1: 'psf2',
                                                                                         2: 'psf3',
                                                                                         3: 'psf4',
                                                                                         4: 'psf5',
                                                                                         5: 'psf6',
                                                                                         6: 'psf8',
                                                                                         7: 'psf10',
                                                                                         8: 'psf20',
                                                                                         9: 'psf30',
                                                                                         10: 'psf40',
                                                                                         11: 'psf50',
                                                                                         12: 'psf60',
                                                                                         13: 'psf80',
                                                                                         14: 'psf100',
                                                                                         15: 'psf200',
                                                                                         16: 'psf300',
                                                                                         17: 'psf500',
                                                                                         18: 'psf750',
                                                                                         19: 'psf1280',
                                                                                         20: 'psf1920',
                                                                                         21: 'psf2560',
                                                                                         22: 'spare10',
                                                                                         23: 'spare9',
                                                                                         24: 'spare8',
                                                                                         25: 'spare7',
                                                                                         26: 'spare6',
                                                                                         27: 'spare5',
                                                                                         28: 'spare4',
                                                                                         29: 'spare3',
                                                                                         30: 'spare2',
                                                                                         31: 'spare1'}},
                                                                             {'name': 'drx-RetransmissionTimer',
                                                                              'type': 'ENUMERATED',
                                                                              'values': {0: 'psf1',
                                                                                         1: 'psf2',
                                                                                         2: 'psf4',
                                                                                         3: 'psf6',
                                                                                         4: 'psf8',
                                                                                         5: 'psf16',
                                                                                         6: 'psf24',
                                                                                         7: 'psf33'}},
                                                                             {'members': [{'name': 'sf10',
                                                                                           'restricted-to': [(0,
                                                                                                              9)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf20',
                                                                                           'restricted-to': [(0,
                                                                                                              19)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf32',
                                                                                           'restricted-to': [(0,
                                                                                                              31)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf40',
                                                                                           'restricted-to': [(0,
                                                                                                              39)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf64',
                                                                                           'restricted-to': [(0,
                                                                                                              63)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf80',
                                                                                           'restricted-to': [(0,
                                                                                                              79)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf128',
                                                                                           'restricted-to': [(0,
                                                                                                              127)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf160',
                                                                                           'restricted-to': [(0,
                                                                                                              159)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf256',
                                                                                           'restricted-to': [(0,
                                                                                                              255)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf320',
                                                                                           'restricted-to': [(0,
                                                                                                              319)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf512',
                                                                                           'restricted-to': [(0,
                                                                                                              511)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf640',
                                                                                           'restricted-to': [(0,
                                                                                                              639)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf1024',
                                                                                           'restricted-to': [(0,
                                                                                                              1023)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf1280',
                                                                                           'restricted-to': [(0,
                                                                                                              1279)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf2048',
                                                                                           'restricted-to': [(0,
                                                                                                              2047)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sf2560',
                                                                                           'restricted-to': [(0,
                                                                                                              2559)],
                                                                                           'type': 'INTEGER'}],
                                                                              'name': 'longDRX-CycleStartOffset',
                                                                              'type': 'CHOICE'},
                                                                             {'members': [{'name': 'shortDRX-Cycle',
                                                                                           'type': 'ENUMERATED',
                                                                                           'values': {0: 'sf2',
                                                                                                      1: 'sf5',
                                                                                                      2: 'sf8',
                                                                                                      3: 'sf10',
                                                                                                      4: 'sf16',
                                                                                                      5: 'sf20',
                                                                                                      6: 'sf32',
                                                                                                      7: 'sf40',
                                                                                                      8: 'sf64',
                                                                                                      9: 'sf80',
                                                                                                      10: 'sf128',
                                                                                                      11: 'sf160',
                                                                                                      12: 'sf256',
                                                                                                      13: 'sf320',
                                                                                                      14: 'sf512',
                                                                                                      15: 'sf640'}},
                                                                                          {'name': 'drxShortCycleTimer',
                                                                                           'restricted-to': [(1,
                                                                                                              16)],
                                                                                           'type': 'INTEGER'}],
                                                                              'name': 'shortDRX',
                                                                              'optional': True,
                                                                              'type': 'SEQUENCE'}],
                                                                 'name': 'setup',
                                                                 'type': 'SEQUENCE'}],
                                                    'type': 'CHOICE'},
                                     'DedicatedInfoCDMA2000': {'type': 'OCTET '
                                                                       'STRING'},
                                     'DedicatedInfoNAS': {'type': 'OCTET '
                                                                  'STRING'},
                                     'DeltaFList-PUCCH': {'members': [{'name': 'deltaF-PUCCH-Format1',
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 'deltaF-2',
                                                                                  1: 'deltaF0',
                                                                                  2: 'deltaF2'}},
                                                                      {'name': 'deltaF-PUCCH-Format1b',
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 'deltaF1',
                                                                                  1: 'deltaF3',
                                                                                  2: 'deltaF5'}},
                                                                      {'name': 'deltaF-PUCCH-Format2',
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 'deltaF-2',
                                                                                  1: 'deltaF0',
                                                                                  2: 'deltaF1',
                                                                                  3: 'deltaF2'}},
                                                                      {'name': 'deltaF-PUCCH-Format2a',
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 'deltaF-2',
                                                                                  1: 'deltaF0',
                                                                                  2: 'deltaF2'}},
                                                                      {'name': 'deltaF-PUCCH-Format2b',
                                                                       'type': 'ENUMERATED',
                                                                       'values': {0: 'deltaF-2',
                                                                                  1: 'deltaF0',
                                                                                  2: 'deltaF2'}}],
                                                          'type': 'SEQUENCE'},
                                     'EstablishmentCause': {'type': 'ENUMERATED',
                                                            'values': {0: 'emergency',
                                                                       1: 'highPriorityAccess',
                                                                       2: 'mt-Access',
                                                                       3: 'mo-Signalling',
                                                                       4: 'mo-Data',
                                                                       5: 'spare3',
                                                                       6: 'spare2',
                                                                       7: 'spare1'}},
                                     'ExplicitListOfARFCNs': {'element': {'type': 'ARFCN-ValueGERAN'},
                                                              'size': [(0, 31)],
                                                              'type': 'SEQUENCE '
                                                                      'OF'},
                                     'FilterCoefficient': {'type': 'ENUMERATED',
                                                           'values': {0: 'fc0',
                                                                      1: 'fc1',
                                                                      2: 'fc2',
                                                                      3: 'fc3',
                                                                      4: 'fc4',
                                                                      5: 'fc5',
                                                                      6: 'fc6',
                                                                      7: 'fc7',
                                                                      8: 'fc8',
                                                                      9: 'fc9',
                                                                      10: 'fc11',
                                                                      11: 'fc13',
                                                                      12: 'fc15',
                                                                      13: 'fc17',
                                                                      14: 'fc19',
                                                                      15: 'spare1',
                                                                      16: '...'}},
                                     'FreqPriorityEUTRA': {'members': [{'name': 'carrierFreq',
                                                                        'type': 'ARFCN-ValueEUTRA'},
                                                                       {'name': 'cellReselectionPriority',
                                                                        'type': 'CellReselectionPriority'}],
                                                           'type': 'SEQUENCE'},
                                     'FreqPriorityListEUTRA': {'element': {'type': 'FreqPriorityEUTRA'},
                                                               'size': [(1,
                                                                         'maxFreq')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'FreqPriorityListUTRA-FDD': {'element': {'type': 'FreqPriorityUTRA-FDD'},
                                                                  'size': [(1,
                                                                            'maxUTRA-FDD-Carrier')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'FreqPriorityListUTRA-TDD': {'element': {'type': 'FreqPriorityUTRA-TDD'},
                                                                  'size': [(1,
                                                                            'maxUTRA-TDD-Carrier')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'FreqPriorityUTRA-FDD': {'members': [{'name': 'carrierFreq',
                                                                           'type': 'ARFCN-ValueUTRA'},
                                                                          {'name': 'cellReselectionPriority',
                                                                           'type': 'CellReselectionPriority'}],
                                                              'type': 'SEQUENCE'},
                                     'FreqPriorityUTRA-TDD': {'members': [{'name': 'carrierFreq',
                                                                           'type': 'ARFCN-ValueUTRA'},
                                                                          {'name': 'cellReselectionPriority',
                                                                           'type': 'CellReselectionPriority'}],
                                                              'type': 'SEQUENCE'},
                                     'FreqsPriorityGERAN': {'members': [{'name': 'carrierFreqs',
                                                                         'type': 'CarrierFreqsGERAN'},
                                                                        {'name': 'cellReselectionPriority',
                                                                         'type': 'CellReselectionPriority'}],
                                                            'type': 'SEQUENCE'},
                                     'FreqsPriorityListGERAN': {'element': {'type': 'FreqsPriorityGERAN'},
                                                                'size': [(1,
                                                                          'maxGNFG')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'Handover': {'members': [{'name': 'targetRAT-Type',
                                                               'type': 'ENUMERATED',
                                                               'values': {0: 'utra',
                                                                          1: 'geran',
                                                                          2: 'cdma2000-1XRTT',
                                                                          3: 'cdma2000-HRPD',
                                                                          4: 'spare4',
                                                                          5: 'spare3',
                                                                          6: 'spare2',
                                                                          7: 'spare1',
                                                                          8: '...'}},
                                                              {'name': 'targetRAT-MessageContainer',
                                                               'type': 'OCTET '
                                                                       'STRING'},
                                                              {'name': 'nas-SecurityParamFromEUTRA',
                                                               'optional': True,
                                                               'size': [1],
                                                               'type': 'OCTET '
                                                                       'STRING'},
                                                              {'name': 'systemInformation',
                                                               'optional': True,
                                                               'type': 'SI-OrPSI-GERAN'}],
                                                  'type': 'SEQUENCE'},
                                     'HandoverFromEUTRAPreparationRequest': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                                         {'members': [{'members': [{'name': 'handoverFromEUTRAPreparationRequest-r8',
                                                                                                                    'type': 'HandoverFromEUTRAPreparationRequest-r8-IEs'},
                                                                                                                   {'name': 'spare3',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare2',
                                                                                                                    'type': 'NULL'},
                                                                                                                   {'name': 'spare1',
                                                                                                                    'type': 'NULL'}],
                                                                                                       'name': 'c1',
                                                                                                       'type': 'CHOICE'},
                                                                                                      {'members': [],
                                                                                                       'name': 'criticalExtensionsFuture',
                                                                                                       'type': 'SEQUENCE'}],
                                                                                          'name': 'criticalExtensions',
                                                                                          'type': 'CHOICE'}],
                                                                             'type': 'SEQUENCE'},
                                     'HandoverFromEUTRAPreparationRequest-r8-IEs': {'members': [{'name': 'cdma2000-Type',
                                                                                                 'type': 'CDMA2000-Type'},
                                                                                                {'name': 'rand',
                                                                                                 'optional': True,
                                                                                                 'type': 'RAND-CDMA2000'},
                                                                                                {'name': 'mobilityParameters',
                                                                                                 'optional': True,
                                                                                                 'type': 'MobilityParametersCDMA2000'},
                                                                                                {'members': [],
                                                                                                 'name': 'nonCriticalExtension',
                                                                                                 'optional': True,
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'type': 'SEQUENCE'},
                                     'Hysteresis': {'restricted-to': [(0, 30)],
                                                    'type': 'INTEGER'},
                                     'IMSI': {'element': {'type': 'IMSI-Digit'},
                                              'size': [(6, 21)],
                                              'type': 'SEQUENCE OF'},
                                     'IMSI-Digit': {'restricted-to': [(0, 9)],
                                                    'type': 'INTEGER'},
                                     'IRAT-ParametersCDMA2000-1XRTT': {'members': [{'name': 'supportedBandList1XRTT',
                                                                                    'type': 'SupportedBandList1XRTT'},
                                                                                   {'name': 'tx-Config1XRTT',
                                                                                    'type': 'ENUMERATED',
                                                                                    'values': {0: 'single',
                                                                                               1: 'dual'}},
                                                                                   {'name': 'rx-Config1XRTT',
                                                                                    'type': 'ENUMERATED',
                                                                                    'values': {0: 'single',
                                                                                               1: 'dual'}}],
                                                                       'type': 'SEQUENCE'},
                                     'IRAT-ParametersCDMA2000-HRPD': {'members': [{'name': 'supportedBandListHRPD',
                                                                                   'type': 'SupportedBandListHRPD'},
                                                                                  {'name': 'tx-ConfigHRPD',
                                                                                   'type': 'ENUMERATED',
                                                                                   'values': {0: 'single',
                                                                                              1: 'dual'}},
                                                                                  {'name': 'rx-ConfigHRPD',
                                                                                   'type': 'ENUMERATED',
                                                                                   'values': {0: 'single',
                                                                                              1: 'dual'}}],
                                                                      'type': 'SEQUENCE'},
                                     'IRAT-ParametersGERAN': {'members': [{'name': 'supportedBandListGERAN',
                                                                           'type': 'SupportedBandListGERAN'},
                                                                          {'name': 'interRAT-PS-HO-ToGERAN',
                                                                           'type': 'BOOLEAN'}],
                                                              'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-FDD': {'members': [{'name': 'supportedBandListUTRA-FDD',
                                                                              'type': 'SupportedBandListUTRA-FDD'}],
                                                                 'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-TDD128': {'members': [{'name': 'supportedBandListUTRA-TDD128',
                                                                                 'type': 'SupportedBandListUTRA-TDD128'}],
                                                                    'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-TDD384': {'members': [{'name': 'supportedBandListUTRA-TDD384',
                                                                                 'type': 'SupportedBandListUTRA-TDD384'}],
                                                                    'type': 'SEQUENCE'},
                                     'IRAT-ParametersUTRA-TDD768': {'members': [{'name': 'supportedBandListUTRA-TDD768',
                                                                                 'type': 'SupportedBandListUTRA-TDD768'}],
                                                                    'type': 'SEQUENCE'},
                                     'IdleModeMobilityControlInfo': {'members': [{'name': 'freqPriorityListEUTRA',
                                                                                  'optional': True,
                                                                                  'type': 'FreqPriorityListEUTRA'},
                                                                                 {'name': 'freqPriorityListGERAN',
                                                                                  'optional': True,
                                                                                  'type': 'FreqsPriorityListGERAN'},
                                                                                 {'name': 'freqPriorityListUTRA-FDD',
                                                                                  'optional': True,
                                                                                  'type': 'FreqPriorityListUTRA-FDD'},
                                                                                 {'name': 'freqPriorityListUTRA-TDD',
                                                                                  'optional': True,
                                                                                  'type': 'FreqPriorityListUTRA-TDD'},
                                                                                 {'name': 'bandClassPriorityListHRPD',
                                                                                  'optional': True,
                                                                                  'type': 'BandClassPriorityListHRPD'},
                                                                                 {'name': 'bandClassPriorityList1XRTT',
                                                                                  'optional': True,
                                                                                  'type': 'BandClassPriorityList1XRTT'},
                                                                                 {'name': 't320',
                                                                                  'optional': True,
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': {0: 'min5',
                                                                                             1: 'min10',
                                                                                             2: 'min20',
                                                                                             3: 'min30',
                                                                                             4: 'min60',
                                                                                             5: 'min120',
                                                                                             6: 'min180',
                                                                                             7: 'spare1'}},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'InitialUE-Identity': {'members': [{'name': 's-TMSI',
                                                                         'type': 'S-TMSI'},
                                                                        {'name': 'randomValue',
                                                                         'size': [40],
                                                                         'type': 'BIT '
                                                                                 'STRING'}],
                                                            'type': 'CHOICE'},
                                     'InterFreqBandInfo': {'members': [{'name': 'interFreqNeedForGaps',
                                                                        'type': 'BOOLEAN'}],
                                                           'type': 'SEQUENCE'},
                                     'InterFreqBandList': {'element': {'type': 'InterFreqBandInfo'},
                                                           'size': [(1,
                                                                     'maxBands')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'InterFreqBlackCellList': {'element': {'type': 'PhysCellIdRange'},
                                                                'size': [(1,
                                                                          'maxCellBlack')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'InterFreqCarrierFreqInfo': {'members': [{'name': 'dl-CarrierFreq',
                                                                               'type': 'ARFCN-ValueEUTRA'},
                                                                              {'name': 'q-RxLevMin',
                                                                               'type': 'Q-RxLevMin'},
                                                                              {'name': 'p-Max',
                                                                               'optional': True,
                                                                               'type': 'P-Max'},
                                                                              {'name': 't-ReselectionEUTRA',
                                                                               'type': 'T-Reselection'},
                                                                              {'name': 't-ReselectionEUTRA-SF',
                                                                               'optional': True,
                                                                               'type': 'SpeedStateScaleFactors'},
                                                                              {'name': 'threshX-High',
                                                                               'type': 'ReselectionThreshold'},
                                                                              {'name': 'threshX-Low',
                                                                               'type': 'ReselectionThreshold'},
                                                                              {'name': 'allowedMeasBandwidth',
                                                                               'type': 'AllowedMeasBandwidth'},
                                                                              {'name': 'presenceAntennaPort1',
                                                                               'type': 'PresenceAntennaPort1'},
                                                                              {'name': 'cellReselectionPriority',
                                                                               'optional': True,
                                                                               'type': 'CellReselectionPriority'},
                                                                              {'name': 'neighCellConfig',
                                                                               'type': 'NeighCellConfig'},
                                                                              {'default': 'dB0',
                                                                               'name': 'q-OffsetFreq',
                                                                               'type': 'Q-OffsetRange'},
                                                                              {'name': 'interFreqNeighCellList',
                                                                               'optional': True,
                                                                               'type': 'InterFreqNeighCellList'},
                                                                              {'name': 'interFreqBlackCellList',
                                                                               'optional': True,
                                                                               'type': 'InterFreqBlackCellList'},
                                                                              '...'],
                                                                  'type': 'SEQUENCE'},
                                     'InterFreqCarrierFreqList': {'element': {'type': 'InterFreqCarrierFreqInfo'},
                                                                  'size': [(1,
                                                                            'maxFreq')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'InterFreqNeighCellInfo': {'members': [{'name': 'physCellId',
                                                                             'type': 'PhysCellId'},
                                                                            {'name': 'q-OffsetCell',
                                                                             'type': 'Q-OffsetRange'}],
                                                                'type': 'SEQUENCE'},
                                     'InterFreqNeighCellList': {'element': {'type': 'InterFreqNeighCellInfo'},
                                                                'size': [(1,
                                                                          'maxCellInter')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'InterRAT-BandInfo': {'members': [{'name': 'interRAT-NeedForGaps',
                                                                        'type': 'BOOLEAN'}],
                                                           'type': 'SEQUENCE'},
                                     'InterRAT-BandList': {'element': {'type': 'InterRAT-BandInfo'},
                                                           'size': [(1,
                                                                     'maxBands')],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'IntraFreqBlackCellList': {'element': {'type': 'PhysCellIdRange'},
                                                                'size': [(1,
                                                                          'maxCellBlack')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'IntraFreqNeighCellInfo': {'members': [{'name': 'physCellId',
                                                                             'type': 'PhysCellId'},
                                                                            {'name': 'q-OffsetCell',
                                                                             'type': 'Q-OffsetRange'},
                                                                            '...'],
                                                                'type': 'SEQUENCE'},
                                     'IntraFreqNeighCellList': {'element': {'type': 'IntraFreqNeighCellInfo'},
                                                                'size': [(1,
                                                                          'maxCellIntra')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'LogicalChannelConfig': {'members': [{'members': [{'name': 'priority',
                                                                                        'restricted-to': [(1,
                                                                                                           16)],
                                                                                        'type': 'INTEGER'},
                                                                                       {'name': 'prioritisedBitRate',
                                                                                        'type': 'ENUMERATED',
                                                                                        'values': {0: 'kBps0',
                                                                                                   1: 'kBps8',
                                                                                                   2: 'kBps16',
                                                                                                   3: 'kBps32',
                                                                                                   4: 'kBps64',
                                                                                                   5: 'kBps128',
                                                                                                   6: 'kBps256',
                                                                                                   7: 'infinity',
                                                                                                   8: 'spare8',
                                                                                                   9: 'spare7',
                                                                                                   10: 'spare6',
                                                                                                   11: 'spare5',
                                                                                                   12: 'spare4',
                                                                                                   13: 'spare3',
                                                                                                   14: 'spare2',
                                                                                                   15: 'spare1'}},
                                                                                       {'name': 'bucketSizeDuration',
                                                                                        'type': 'ENUMERATED',
                                                                                        'values': {0: 'ms50',
                                                                                                   1: 'ms100',
                                                                                                   2: 'ms150',
                                                                                                   3: 'ms300',
                                                                                                   4: 'ms500',
                                                                                                   5: 'ms1000',
                                                                                                   6: 'spare2',
                                                                                                   7: 'spare1'}},
                                                                                       {'name': 'logicalChannelGroup',
                                                                                        'optional': True,
                                                                                        'restricted-to': [(0,
                                                                                                           3)],
                                                                                        'type': 'INTEGER'}],
                                                                           'name': 'ul-SpecificParameters',
                                                                           'optional': True,
                                                                           'type': 'SEQUENCE'},
                                                                          '...'],
                                                              'type': 'SEQUENCE'},
                                     'MAC-MainConfig': {'members': [{'members': [{'name': 'maxHARQ-Tx',
                                                                                  'optional': True,
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': {0: 'n1',
                                                                                             1: 'n2',
                                                                                             2: 'n3',
                                                                                             3: 'n4',
                                                                                             4: 'n5',
                                                                                             5: 'n6',
                                                                                             6: 'n7',
                                                                                             7: 'n8',
                                                                                             8: 'n10',
                                                                                             9: 'n12',
                                                                                             10: 'n16',
                                                                                             11: 'n20',
                                                                                             12: 'n24',
                                                                                             13: 'n28',
                                                                                             14: 'spare2',
                                                                                             15: 'spare1'}},
                                                                                 {'name': 'periodicBSR-Timer',
                                                                                  'optional': True,
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': {0: 'sf5',
                                                                                             1: 'sf10',
                                                                                             2: 'sf16',
                                                                                             3: 'sf20',
                                                                                             4: 'sf32',
                                                                                             5: 'sf40',
                                                                                             6: 'sf64',
                                                                                             7: 'sf80',
                                                                                             8: 'sf128',
                                                                                             9: 'sf160',
                                                                                             10: 'sf320',
                                                                                             11: 'sf640',
                                                                                             12: 'sf1280',
                                                                                             13: 'sf2560',
                                                                                             14: 'infinity',
                                                                                             15: 'spare1'}},
                                                                                 {'name': 'retxBSR-Timer',
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': {0: 'sf320',
                                                                                             1: 'sf640',
                                                                                             2: 'sf1280',
                                                                                             3: 'sf2560',
                                                                                             4: 'sf5120',
                                                                                             5: 'sf10240',
                                                                                             6: 'spare2',
                                                                                             7: 'spare1'}},
                                                                                 {'name': 'ttiBundling',
                                                                                  'type': 'BOOLEAN'}],
                                                                     'name': 'ul-SCH-Config',
                                                                     'optional': True,
                                                                     'type': 'SEQUENCE'},
                                                                    {'name': 'drx-Config',
                                                                     'optional': True,
                                                                     'type': 'DRX-Config'},
                                                                    {'name': 'timeAlignmentTimerDedicated',
                                                                     'type': 'TimeAlignmentTimer'},
                                                                    {'members': [{'name': 'release',
                                                                                  'type': 'NULL'},
                                                                                 {'members': [{'name': 'periodicPHR-Timer',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': {0: 'sf10',
                                                                                                          1: 'sf20',
                                                                                                          2: 'sf50',
                                                                                                          3: 'sf100',
                                                                                                          4: 'sf200',
                                                                                                          5: 'sf500',
                                                                                                          6: 'sf1000',
                                                                                                          7: 'infinity'}},
                                                                                              {'name': 'prohibitPHR-Timer',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': {0: 'sf0',
                                                                                                          1: 'sf10',
                                                                                                          2: 'sf20',
                                                                                                          3: 'sf50',
                                                                                                          4: 'sf100',
                                                                                                          5: 'sf200',
                                                                                                          6: 'sf500',
                                                                                                          7: 'sf1000'}},
                                                                                              {'name': 'dl-PathlossChange',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': {0: 'dB1',
                                                                                                          1: 'dB3',
                                                                                                          2: 'dB6',
                                                                                                          3: 'infinity'}}],
                                                                                  'name': 'setup',
                                                                                  'type': 'SEQUENCE'}],
                                                                     'name': 'phr-Config',
                                                                     'optional': True,
                                                                     'type': 'CHOICE'},
                                                                    '...'],
                                                        'type': 'SEQUENCE'},
                                     'MBSFN-SubframeConfig': {'members': [{'name': 'radioframeAllocationPeriod',
                                                                           'type': 'ENUMERATED',
                                                                           'values': {0: 'n1',
                                                                                      1: 'n2',
                                                                                      2: 'n4',
                                                                                      3: 'n8',
                                                                                      4: 'n16',
                                                                                      5: 'n32'}},
                                                                          {'name': 'radioframeAllocationOffset',
                                                                           'restricted-to': [(0,
                                                                                              7)],
                                                                           'type': 'INTEGER'},
                                                                          {'members': [{'name': 'oneFrame',
                                                                                        'size': [6],
                                                                                        'type': 'BIT '
                                                                                                'STRING'},
                                                                                       {'name': 'fourFrames',
                                                                                        'size': [24],
                                                                                        'type': 'BIT '
                                                                                                'STRING'}],
                                                                           'name': 'subframeAllocation',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'MBSFN-SubframeConfigList': {'element': {'type': 'MBSFN-SubframeConfig'},
                                                                  'size': [(1,
                                                                            'maxMBSFN-Allocations')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'MCC': {'element': {'type': 'MCC-MNC-Digit'},
                                             'size': [3],
                                             'type': 'SEQUENCE OF'},
                                     'MCC-MNC-Digit': {'restricted-to': [(0,
                                                                          9)],
                                                       'type': 'INTEGER'},
                                     'MMEC': {'size': [8],
                                              'type': 'BIT STRING'},
                                     'MNC': {'element': {'type': 'MCC-MNC-Digit'},
                                             'size': [(2, 3)],
                                             'type': 'SEQUENCE OF'},
                                     'MasterInformationBlock': {'members': [{'name': 'dl-Bandwidth',
                                                                             'type': 'ENUMERATED',
                                                                             'values': {0: 'n6',
                                                                                        1: 'n15',
                                                                                        2: 'n25',
                                                                                        3: 'n50',
                                                                                        4: 'n75',
                                                                                        5: 'n100'}},
                                                                            {'name': 'phich-Config',
                                                                             'type': 'PHICH-Config'},
                                                                            {'name': 'systemFrameNumber',
                                                                             'size': [8],
                                                                             'type': 'BIT '
                                                                                     'STRING'},
                                                                            {'name': 'spare',
                                                                             'size': [10],
                                                                             'type': 'BIT '
                                                                                     'STRING'}],
                                                                'type': 'SEQUENCE'},
                                     'MeasConfig': {'members': [{'name': 'measObjectToRemoveList',
                                                                 'optional': True,
                                                                 'type': 'MeasObjectToRemoveList'},
                                                                {'name': 'measObjectToAddModList',
                                                                 'optional': True,
                                                                 'type': 'MeasObjectToAddModList'},
                                                                {'name': 'reportConfigToRemoveList',
                                                                 'optional': True,
                                                                 'type': 'ReportConfigToRemoveList'},
                                                                {'name': 'reportConfigToAddModList',
                                                                 'optional': True,
                                                                 'type': 'ReportConfigToAddModList'},
                                                                {'name': 'measIdToRemoveList',
                                                                 'optional': True,
                                                                 'type': 'MeasIdToRemoveList'},
                                                                {'name': 'measIdToAddModList',
                                                                 'optional': True,
                                                                 'type': 'MeasIdToAddModList'},
                                                                {'name': 'quantityConfig',
                                                                 'optional': True,
                                                                 'type': 'QuantityConfig'},
                                                                {'name': 'measGapConfig',
                                                                 'optional': True,
                                                                 'type': 'MeasGapConfig'},
                                                                {'name': 's-Measure',
                                                                 'optional': True,
                                                                 'type': 'RSRP-Range'},
                                                                {'name': 'preRegistrationInfoHRPD',
                                                                 'optional': True,
                                                                 'type': 'PreRegistrationInfoHRPD'},
                                                                {'members': [{'name': 'release',
                                                                              'type': 'NULL'},
                                                                             {'members': [{'name': 'mobilityStateParameters',
                                                                                           'type': 'MobilityStateParameters'},
                                                                                          {'name': 'timeToTrigger-SF',
                                                                                           'type': 'SpeedStateScaleFactors'}],
                                                                              'name': 'setup',
                                                                              'type': 'SEQUENCE'}],
                                                                 'name': 'speedStatePars',
                                                                 'optional': True,
                                                                 'type': 'CHOICE'},
                                                                '...'],
                                                    'type': 'SEQUENCE'},
                                     'MeasGapConfig': {'members': [{'name': 'release',
                                                                    'type': 'NULL'},
                                                                   {'members': [{'members': [{'name': 'gp0',
                                                                                              'restricted-to': [(0,
                                                                                                                 39)],
                                                                                              'type': 'INTEGER'},
                                                                                             {'name': 'gp1',
                                                                                              'restricted-to': [(0,
                                                                                                                 79)],
                                                                                              'type': 'INTEGER'},
                                                                                             '...'],
                                                                                 'name': 'gapOffset',
                                                                                 'type': 'CHOICE'}],
                                                                    'name': 'setup',
                                                                    'type': 'SEQUENCE'}],
                                                       'type': 'CHOICE'},
                                     'MeasId': {'restricted-to': [(1,
                                                                   'maxMeasId')],
                                                'type': 'INTEGER'},
                                     'MeasIdToAddMod': {'members': [{'name': 'measId',
                                                                     'type': 'MeasId'},
                                                                    {'name': 'measObjectId',
                                                                     'type': 'MeasObjectId'},
                                                                    {'name': 'reportConfigId',
                                                                     'type': 'ReportConfigId'}],
                                                        'type': 'SEQUENCE'},
                                     'MeasIdToAddModList': {'element': {'type': 'MeasIdToAddMod'},
                                                            'size': [(1,
                                                                      'maxMeasId')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'MeasIdToRemoveList': {'element': {'type': 'MeasId'},
                                                            'size': [(1,
                                                                      'maxMeasId')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'MeasObjectCDMA2000': {'members': [{'name': 'cdma2000-Type',
                                                                         'type': 'CDMA2000-Type'},
                                                                        {'name': 'carrierFreq',
                                                                         'type': 'CarrierFreqCDMA2000'},
                                                                        {'name': 'searchWindowSize',
                                                                         'optional': True,
                                                                         'restricted-to': [(0,
                                                                                            15)],
                                                                         'type': 'INTEGER'},
                                                                        {'default': 0,
                                                                         'name': 'offsetFreq',
                                                                         'type': 'Q-OffsetRangeInterRAT'},
                                                                        {'name': 'cellsToRemoveList',
                                                                         'optional': True,
                                                                         'type': 'CellIndexList'},
                                                                        {'name': 'cellsToAddModList',
                                                                         'optional': True,
                                                                         'type': 'CellsToAddModListCDMA2000'},
                                                                        {'name': 'cellForWhichToReportCGI',
                                                                         'optional': True,
                                                                         'type': 'PhysCellIdCDMA2000'},
                                                                        '...'],
                                                            'type': 'SEQUENCE'},
                                     'MeasObjectEUTRA': {'members': [{'name': 'carrierFreq',
                                                                      'type': 'ARFCN-ValueEUTRA'},
                                                                     {'name': 'allowedMeasBandwidth',
                                                                      'type': 'AllowedMeasBandwidth'},
                                                                     {'name': 'presenceAntennaPort1',
                                                                      'type': 'PresenceAntennaPort1'},
                                                                     {'name': 'neighCellConfig',
                                                                      'type': 'NeighCellConfig'},
                                                                     {'default': 'dB0',
                                                                      'name': 'offsetFreq',
                                                                      'type': 'Q-OffsetRange'},
                                                                     {'name': 'cellsToRemoveList',
                                                                      'optional': True,
                                                                      'type': 'CellIndexList'},
                                                                     {'name': 'cellsToAddModList',
                                                                      'optional': True,
                                                                      'type': 'CellsToAddModList'},
                                                                     {'name': 'blackCellsToRemoveList',
                                                                      'optional': True,
                                                                      'type': 'CellIndexList'},
                                                                     {'name': 'blackCellsToAddModList',
                                                                      'optional': True,
                                                                      'type': 'BlackCellsToAddModList'},
                                                                     {'name': 'cellForWhichToReportCGI',
                                                                      'optional': True,
                                                                      'type': 'PhysCellId'},
                                                                     '...'],
                                                         'type': 'SEQUENCE'},
                                     'MeasObjectGERAN': {'members': [{'name': 'carrierFreqs',
                                                                      'type': 'CarrierFreqsGERAN'},
                                                                     {'default': 0,
                                                                      'name': 'offsetFreq',
                                                                      'type': 'Q-OffsetRangeInterRAT'},
                                                                     {'default': '0b11111111',
                                                                      'name': 'ncc-Permitted',
                                                                      'size': [8],
                                                                      'type': 'BIT '
                                                                              'STRING'},
                                                                     {'name': 'cellForWhichToReportCGI',
                                                                      'optional': True,
                                                                      'type': 'PhysCellIdGERAN'},
                                                                     '...'],
                                                         'type': 'SEQUENCE'},
                                     'MeasObjectId': {'restricted-to': [(1,
                                                                         'maxObjectId')],
                                                      'type': 'INTEGER'},
                                     'MeasObjectToAddMod': {'members': [{'name': 'measObjectId',
                                                                         'type': 'MeasObjectId'},
                                                                        {'members': [{'name': 'measObjectEUTRA',
                                                                                      'type': 'MeasObjectEUTRA'},
                                                                                     {'name': 'measObjectUTRA',
                                                                                      'type': 'MeasObjectUTRA'},
                                                                                     {'name': 'measObjectGERAN',
                                                                                      'type': 'MeasObjectGERAN'},
                                                                                     {'name': 'measObjectCDMA2000',
                                                                                      'type': 'MeasObjectCDMA2000'},
                                                                                     '...'],
                                                                         'name': 'measObject',
                                                                         'type': 'CHOICE'}],
                                                            'type': 'SEQUENCE'},
                                     'MeasObjectToAddModList': {'element': {'type': 'MeasObjectToAddMod'},
                                                                'size': [(1,
                                                                          'maxObjectId')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'MeasObjectToRemoveList': {'element': {'type': 'MeasObjectId'},
                                                                'size': [(1,
                                                                          'maxObjectId')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'MeasObjectUTRA': {'members': [{'name': 'carrierFreq',
                                                                     'type': 'ARFCN-ValueUTRA'},
                                                                    {'default': 0,
                                                                     'name': 'offsetFreq',
                                                                     'type': 'Q-OffsetRangeInterRAT'},
                                                                    {'name': 'cellsToRemoveList',
                                                                     'optional': True,
                                                                     'type': 'CellIndexList'},
                                                                    {'members': [{'name': 'cellsToAddModListUTRA-FDD',
                                                                                  'type': 'CellsToAddModListUTRA-FDD'},
                                                                                 {'name': 'cellsToAddModListUTRA-TDD',
                                                                                  'type': 'CellsToAddModListUTRA-TDD'}],
                                                                     'name': 'cellsToAddModList',
                                                                     'optional': True,
                                                                     'type': 'CHOICE'},
                                                                    {'members': [{'name': 'utra-FDD',
                                                                                  'type': 'PhysCellIdUTRA-FDD'},
                                                                                 {'name': 'utra-TDD',
                                                                                  'type': 'PhysCellIdUTRA-TDD'}],
                                                                     'name': 'cellForWhichToReportCGI',
                                                                     'optional': True,
                                                                     'type': 'CHOICE'},
                                                                    '...'],
                                                        'type': 'SEQUENCE'},
                                     'MeasParameters': {'members': [{'name': 'bandListEUTRA',
                                                                     'type': 'BandListEUTRA'}],
                                                        'type': 'SEQUENCE'},
                                     'MeasResultCDMA2000': {'members': [{'name': 'physCellId',
                                                                         'type': 'PhysCellIdCDMA2000'},
                                                                        {'name': 'cgi-Info',
                                                                         'optional': True,
                                                                         'type': 'CellGlobalIdCDMA2000'},
                                                                        {'members': [{'name': 'pilotPnPhase',
                                                                                      'optional': True,
                                                                                      'restricted-to': [(0,
                                                                                                         32767)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'pilotStrength',
                                                                                      'restricted-to': [(0,
                                                                                                         63)],
                                                                                      'type': 'INTEGER'},
                                                                                     '...'],
                                                                         'name': 'measResult',
                                                                         'type': 'SEQUENCE'}],
                                                            'type': 'SEQUENCE'},
                                     'MeasResultEUTRA': {'members': [{'name': 'physCellId',
                                                                      'type': 'PhysCellId'},
                                                                     {'members': [{'name': 'cellGlobalId',
                                                                                   'type': 'CellGlobalIdEUTRA'},
                                                                                  {'name': 'trackingAreaCode',
                                                                                   'type': 'TrackingAreaCode'},
                                                                                  {'name': 'plmn-IdentityList',
                                                                                   'optional': True,
                                                                                   'type': 'PLMN-IdentityList2'}],
                                                                      'name': 'cgi-Info',
                                                                      'optional': True,
                                                                      'type': 'SEQUENCE'},
                                                                     {'members': [{'name': 'rsrpResult',
                                                                                   'optional': True,
                                                                                   'type': 'RSRP-Range'},
                                                                                  {'name': 'rsrqResult',
                                                                                   'optional': True,
                                                                                   'type': 'RSRQ-Range'},
                                                                                  '...'],
                                                                      'name': 'measResult',
                                                                      'type': 'SEQUENCE'}],
                                                         'type': 'SEQUENCE'},
                                     'MeasResultGERAN': {'members': [{'name': 'carrierFreq',
                                                                      'type': 'CarrierFreqGERAN'},
                                                                     {'name': 'physCellId',
                                                                      'type': 'PhysCellIdGERAN'},
                                                                     {'members': [{'name': 'cellGlobalId',
                                                                                   'type': 'CellGlobalIdGERAN'},
                                                                                  {'name': 'routingAreaCode',
                                                                                   'optional': True,
                                                                                   'size': [8],
                                                                                   'type': 'BIT '
                                                                                           'STRING'}],
                                                                      'name': 'cgi-Info',
                                                                      'optional': True,
                                                                      'type': 'SEQUENCE'},
                                                                     {'members': [{'name': 'rssi',
                                                                                   'restricted-to': [(0,
                                                                                                      63)],
                                                                                   'type': 'INTEGER'},
                                                                                  '...'],
                                                                      'name': 'measResult',
                                                                      'type': 'SEQUENCE'}],
                                                         'type': 'SEQUENCE'},
                                     'MeasResultListCDMA2000': {'element': {'type': 'MeasResultCDMA2000'},
                                                                'size': [(1,
                                                                          'maxCellReport')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'MeasResultListEUTRA': {'element': {'type': 'MeasResultEUTRA'},
                                                             'size': [(1,
                                                                       'maxCellReport')],
                                                             'type': 'SEQUENCE '
                                                                     'OF'},
                                     'MeasResultListGERAN': {'element': {'type': 'MeasResultGERAN'},
                                                             'size': [(1,
                                                                       'maxCellReport')],
                                                             'type': 'SEQUENCE '
                                                                     'OF'},
                                     'MeasResultListUTRA': {'element': {'type': 'MeasResultUTRA'},
                                                            'size': [(1,
                                                                      'maxCellReport')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'MeasResultUTRA': {'members': [{'members': [{'name': 'fdd',
                                                                                  'type': 'PhysCellIdUTRA-FDD'},
                                                                                 {'name': 'tdd',
                                                                                  'type': 'PhysCellIdUTRA-TDD'}],
                                                                     'name': 'physCellId',
                                                                     'type': 'CHOICE'},
                                                                    {'members': [{'name': 'cellGlobalId',
                                                                                  'type': 'CellGlobalIdUTRA'},
                                                                                 {'name': 'locationAreaCode',
                                                                                  'optional': True,
                                                                                  'size': [16],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'routingAreaCode',
                                                                                  'optional': True,
                                                                                  'size': [8],
                                                                                  'type': 'BIT '
                                                                                          'STRING'},
                                                                                 {'name': 'plmn-IdentityList',
                                                                                  'optional': True,
                                                                                  'type': 'PLMN-IdentityList2'}],
                                                                     'name': 'cgi-Info',
                                                                     'optional': True,
                                                                     'type': 'SEQUENCE'},
                                                                    {'members': [{'name': 'utra-RSCP',
                                                                                  'optional': True,
                                                                                  'restricted-to': [(-5,
                                                                                                     91)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'utra-EcN0',
                                                                                  'optional': True,
                                                                                  'restricted-to': [(0,
                                                                                                     49)],
                                                                                  'type': 'INTEGER'},
                                                                                 '...'],
                                                                     'name': 'measResult',
                                                                     'type': 'SEQUENCE'}],
                                                        'type': 'SEQUENCE'},
                                     'MeasResults': {'members': [{'name': 'measId',
                                                                  'type': 'MeasId'},
                                                                 {'members': [{'name': 'rsrpResult',
                                                                               'type': 'RSRP-Range'},
                                                                              {'name': 'rsrqResult',
                                                                               'type': 'RSRQ-Range'}],
                                                                  'name': 'measResultServCell',
                                                                  'type': 'SEQUENCE'},
                                                                 {'members': [{'name': 'measResultListEUTRA',
                                                                               'type': 'MeasResultListEUTRA'},
                                                                              {'name': 'measResultListUTRA',
                                                                               'type': 'MeasResultListUTRA'},
                                                                              {'name': 'measResultListGERAN',
                                                                               'type': 'MeasResultListGERAN'},
                                                                              {'name': 'measResultsCDMA2000',
                                                                               'type': 'MeasResultsCDMA2000'},
                                                                              '...'],
                                                                  'name': 'measResultNeighCells',
                                                                  'optional': True,
                                                                  'type': 'CHOICE'},
                                                                 '...'],
                                                     'type': 'SEQUENCE'},
                                     'MeasResultsCDMA2000': {'members': [{'name': 'preRegistrationStatusHRPD',
                                                                          'type': 'BOOLEAN'},
                                                                         {'name': 'measResultListCDMA2000',
                                                                          'type': 'MeasResultListCDMA2000'}],
                                                             'type': 'SEQUENCE'},
                                     'MeasurementReport': {'members': [{'members': [{'members': [{'name': 'measurementReport-r8',
                                                                                                  'type': 'MeasurementReport-r8-IEs'},
                                                                                                 {'name': 'spare7',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare6',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare5',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare4',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare3',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare2',
                                                                                                  'type': 'NULL'},
                                                                                                 {'name': 'spare1',
                                                                                                  'type': 'NULL'}],
                                                                                     'name': 'c1',
                                                                                     'type': 'CHOICE'},
                                                                                    {'members': [],
                                                                                     'name': 'criticalExtensionsFuture',
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'criticalExtensions',
                                                                        'type': 'CHOICE'}],
                                                           'type': 'SEQUENCE'},
                                     'MeasurementReport-r8-IEs': {'members': [{'name': 'measResults',
                                                                               'type': 'MeasResults'},
                                                                              {'members': [],
                                                                               'name': 'nonCriticalExtension',
                                                                               'optional': True,
                                                                               'type': 'SEQUENCE'}],
                                                                  'type': 'SEQUENCE'},
                                     'MobilityControlInfo': {'members': [{'name': 'targetPhysCellId',
                                                                          'type': 'PhysCellId'},
                                                                         {'name': 'carrierFreq',
                                                                          'optional': True,
                                                                          'type': 'CarrierFreqEUTRA'},
                                                                         {'name': 'carrierBandwidth',
                                                                          'optional': True,
                                                                          'type': 'CarrierBandwidthEUTRA'},
                                                                         {'name': 'additionalSpectrumEmission',
                                                                          'optional': True,
                                                                          'type': 'AdditionalSpectrumEmission'},
                                                                         {'name': 't304',
                                                                          'type': 'ENUMERATED',
                                                                          'values': {0: 'ms50',
                                                                                     1: 'ms100',
                                                                                     2: 'ms150',
                                                                                     3: 'ms200',
                                                                                     4: 'ms500',
                                                                                     5: 'ms1000',
                                                                                     6: 'ms2000',
                                                                                     7: 'spare1'}},
                                                                         {'name': 'newUE-Identity',
                                                                          'type': 'C-RNTI'},
                                                                         {'name': 'radioResourceConfigCommon',
                                                                          'type': 'RadioResourceConfigCommon'},
                                                                         {'name': 'rach-ConfigDedicated',
                                                                          'optional': True,
                                                                          'type': 'RACH-ConfigDedicated'},
                                                                         '...'],
                                                             'type': 'SEQUENCE'},
                                     'MobilityFromEUTRACommand': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                               'type': 'RRC-TransactionIdentifier'},
                                                                              {'members': [{'members': [{'name': 'mobilityFromEUTRACommand-r8',
                                                                                                         'type': 'MobilityFromEUTRACommand-r8-IEs'},
                                                                                                        {'name': 'spare3',
                                                                                                         'type': 'NULL'},
                                                                                                        {'name': 'spare2',
                                                                                                         'type': 'NULL'},
                                                                                                        {'name': 'spare1',
                                                                                                         'type': 'NULL'}],
                                                                                            'name': 'c1',
                                                                                            'type': 'CHOICE'},
                                                                                           {'members': [],
                                                                                            'name': 'criticalExtensionsFuture',
                                                                                            'type': 'SEQUENCE'}],
                                                                               'name': 'criticalExtensions',
                                                                               'type': 'CHOICE'}],
                                                                  'type': 'SEQUENCE'},
                                     'MobilityFromEUTRACommand-r8-IEs': {'members': [{'name': 'cs-FallbackIndicator',
                                                                                      'type': 'BOOLEAN'},
                                                                                     {'members': [{'name': 'handover',
                                                                                                   'type': 'Handover'},
                                                                                                  {'name': 'cellChangeOrder',
                                                                                                   'type': 'CellChangeOrder'}],
                                                                                      'name': 'purpose',
                                                                                      'type': 'CHOICE'},
                                                                                     {'members': [],
                                                                                      'name': 'nonCriticalExtension',
                                                                                      'optional': True,
                                                                                      'type': 'SEQUENCE'}],
                                                                         'type': 'SEQUENCE'},
                                     'MobilityParametersCDMA2000': {'type': 'OCTET '
                                                                            'STRING'},
                                     'MobilityStateParameters': {'members': [{'name': 't-Evaluation',
                                                                              'type': 'ENUMERATED',
                                                                              'values': {0: 's30',
                                                                                         1: 's60',
                                                                                         2: 's120',
                                                                                         3: 's180',
                                                                                         4: 's240',
                                                                                         5: 'spare3',
                                                                                         6: 'spare2',
                                                                                         7: 'spare1'}},
                                                                             {'name': 't-HystNormal',
                                                                              'type': 'ENUMERATED',
                                                                              'values': {0: 's30',
                                                                                         1: 's60',
                                                                                         2: 's120',
                                                                                         3: 's180',
                                                                                         4: 's240',
                                                                                         5: 'spare3',
                                                                                         6: 'spare2',
                                                                                         7: 'spare1'}},
                                                                             {'name': 'n-CellChangeMedium',
                                                                              'restricted-to': [(1,
                                                                                                 16)],
                                                                              'type': 'INTEGER'},
                                                                             {'name': 'n-CellChangeHigh',
                                                                              'restricted-to': [(1,
                                                                                                 16)],
                                                                              'type': 'INTEGER'}],
                                                                 'type': 'SEQUENCE'},
                                     'N1-PUCCH-AN-PersistentList': {'element': {'restricted-to': [(0,
                                                                                                   2047)],
                                                                                'type': 'INTEGER'},
                                                                    'size': [(1,
                                                                              4)],
                                                                    'type': 'SEQUENCE '
                                                                            'OF'},
                                     'NeighCellCDMA2000': {'members': [{'name': 'bandClass',
                                                                        'type': 'BandclassCDMA2000'},
                                                                       {'name': 'neighCellsPerFreqList',
                                                                        'type': 'NeighCellsPerBandclassListCDMA2000'}],
                                                           'type': 'SEQUENCE'},
                                     'NeighCellConfig': {'size': [2],
                                                         'type': 'BIT STRING'},
                                     'NeighCellListCDMA2000': {'element': {'type': 'NeighCellCDMA2000'},
                                                               'size': [(1,
                                                                         16)],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'NeighCellsPerBandclassCDMA2000': {'members': [{'name': 'arfcn',
                                                                                     'type': 'ARFCN-ValueCDMA2000'},
                                                                                    {'name': 'physCellIdList',
                                                                                     'type': 'PhysCellIdListCDMA2000'}],
                                                                        'type': 'SEQUENCE'},
                                     'NeighCellsPerBandclassListCDMA2000': {'element': {'type': 'NeighCellsPerBandclassCDMA2000'},
                                                                            'size': [(1,
                                                                                      16)],
                                                                            'type': 'SEQUENCE '
                                                                                    'OF'},
                                     'NextHopChainingCount': {'restricted-to': [(0,
                                                                                 7)],
                                                              'type': 'INTEGER'},
                                     'P-Max': {'restricted-to': [(-30, 33)],
                                               'type': 'INTEGER'},
                                     'PCCH-Config': {'members': [{'name': 'defaultPagingCycle',
                                                                  'type': 'ENUMERATED',
                                                                  'values': {0: 'rf32',
                                                                             1: 'rf64',
                                                                             2: 'rf128',
                                                                             3: 'rf256'}},
                                                                 {'name': 'nB',
                                                                  'type': 'ENUMERATED',
                                                                  'values': {0: 'fourT',
                                                                             1: 'twoT',
                                                                             2: 'oneT',
                                                                             3: 'halfT',
                                                                             4: 'quarterT',
                                                                             5: 'oneEighthT',
                                                                             6: 'oneSixteenthT',
                                                                             7: 'oneThirtySecondT'}}],
                                                     'type': 'SEQUENCE'},
                                     'PCCH-Message': {'members': [{'name': 'message',
                                                                   'type': 'PCCH-MessageType'}],
                                                      'type': 'SEQUENCE'},
                                     'PCCH-MessageType': {'members': [{'members': [{'name': 'paging',
                                                                                    'type': 'Paging'}],
                                                                       'name': 'c1',
                                                                       'type': 'CHOICE'},
                                                                      {'members': [],
                                                                       'name': 'messageClassExtension',
                                                                       'type': 'SEQUENCE'}],
                                                          'type': 'CHOICE'},
                                     'PDCP-Config': {'members': [{'name': 'discardTimer',
                                                                  'optional': True,
                                                                  'type': 'ENUMERATED',
                                                                  'values': {0: 'ms50',
                                                                             1: 'ms100',
                                                                             2: 'ms150',
                                                                             3: 'ms300',
                                                                             4: 'ms500',
                                                                             5: 'ms750',
                                                                             6: 'ms1500',
                                                                             7: 'infinity'}},
                                                                 {'members': [{'name': 'statusReportRequired',
                                                                               'type': 'BOOLEAN'}],
                                                                  'name': 'rlc-AM',
                                                                  'optional': True,
                                                                  'type': 'SEQUENCE'},
                                                                 {'members': [{'name': 'pdcp-SN-Size',
                                                                               'type': 'ENUMERATED',
                                                                               'values': {0: 'len7bits',
                                                                                          1: 'len12bits'}}],
                                                                  'name': 'rlc-UM',
                                                                  'optional': True,
                                                                  'type': 'SEQUENCE'},
                                                                 {'members': [{'name': 'notUsed',
                                                                               'type': 'NULL'},
                                                                              {'members': [{'default': 15,
                                                                                            'name': 'maxCID',
                                                                                            'restricted-to': [(1,
                                                                                                               16383)],
                                                                                            'type': 'INTEGER'},
                                                                                           {'members': [{'name': 'profile0x0001',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0002',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0003',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0004',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0006',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0101',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0102',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0103',
                                                                                                         'type': 'BOOLEAN'},
                                                                                                        {'name': 'profile0x0104',
                                                                                                         'type': 'BOOLEAN'}],
                                                                                            'name': 'profiles',
                                                                                            'type': 'SEQUENCE'},
                                                                                           '...'],
                                                                               'name': 'rohc',
                                                                               'type': 'SEQUENCE'}],
                                                                  'name': 'headerCompression',
                                                                  'type': 'CHOICE'},
                                                                 '...'],
                                                     'type': 'SEQUENCE'},
                                     'PDCP-Parameters': {'members': [{'members': [{'name': 'profile0x0001',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0002',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0003',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0004',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0006',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0101',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0102',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0103',
                                                                                   'type': 'BOOLEAN'},
                                                                                  {'name': 'profile0x0104',
                                                                                   'type': 'BOOLEAN'}],
                                                                      'name': 'supportedROHC-Profiles',
                                                                      'type': 'SEQUENCE'},
                                                                     {'default': 'cs16',
                                                                      'name': 'maxNumberROHC-ContextSessions',
                                                                      'type': 'ENUMERATED',
                                                                      'values': {0: 'cs2',
                                                                                 1: 'cs4',
                                                                                 2: 'cs8',
                                                                                 3: 'cs12',
                                                                                 4: 'cs16',
                                                                                 5: 'cs24',
                                                                                 6: 'cs32',
                                                                                 7: 'cs48',
                                                                                 8: 'cs64',
                                                                                 9: 'cs128',
                                                                                 10: 'cs256',
                                                                                 11: 'cs512',
                                                                                 12: 'cs1024',
                                                                                 13: 'cs16384',
                                                                                 14: 'spare2',
                                                                                 15: 'spare1'}},
                                                                     '...'],
                                                         'type': 'SEQUENCE'},
                                     'PDSCH-ConfigCommon': {'members': [{'name': 'referenceSignalPower',
                                                                         'restricted-to': [(-60,
                                                                                            50)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'p-b',
                                                                         'restricted-to': [(0,
                                                                                            3)],
                                                                         'type': 'INTEGER'}],
                                                            'type': 'SEQUENCE'},
                                     'PDSCH-ConfigDedicated': {'members': [{'name': 'p-a',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'dB-6',
                                                                                       1: 'dB-4dot77',
                                                                                       2: 'dB-3',
                                                                                       3: 'dB-1dot77',
                                                                                       4: 'dB0',
                                                                                       5: 'dB1',
                                                                                       6: 'dB2',
                                                                                       7: 'dB3'}}],
                                                               'type': 'SEQUENCE'},
                                     'PHICH-Config': {'members': [{'name': 'phich-Duration',
                                                                   'type': 'ENUMERATED',
                                                                   'values': {0: 'normal',
                                                                              1: 'extended'}},
                                                                  {'name': 'phich-Resource',
                                                                   'type': 'ENUMERATED',
                                                                   'values': {0: 'oneSixth',
                                                                              1: 'half',
                                                                              2: 'one',
                                                                              3: 'two'}}],
                                                      'type': 'SEQUENCE'},
                                     'PLMN-Identity': {'members': [{'name': 'mcc',
                                                                    'optional': True,
                                                                    'type': 'MCC'},
                                                                   {'name': 'mnc',
                                                                    'type': 'MNC'}],
                                                       'type': 'SEQUENCE'},
                                     'PLMN-IdentityInfo': {'members': [{'name': 'plmn-Identity',
                                                                        'type': 'PLMN-Identity'},
                                                                       {'name': 'cellReservedForOperatorUse',
                                                                        'type': 'ENUMERATED',
                                                                        'values': {0: 'reserved',
                                                                                   1: 'notReserved'}}],
                                                           'type': 'SEQUENCE'},
                                     'PLMN-IdentityList': {'element': {'type': 'PLMN-IdentityInfo'},
                                                           'size': [(1, 6)],
                                                           'type': 'SEQUENCE '
                                                                   'OF'},
                                     'PLMN-IdentityList2': {'element': {'type': 'PLMN-Identity'},
                                                            'size': [(1, 5)],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'PRACH-Config': {'members': [{'name': 'rootSequenceIndex',
                                                                   'restricted-to': [(0,
                                                                                      837)],
                                                                   'type': 'INTEGER'},
                                                                  {'name': 'prach-ConfigInfo',
                                                                   'optional': True,
                                                                   'type': 'PRACH-ConfigInfo'}],
                                                      'type': 'SEQUENCE'},
                                     'PRACH-ConfigInfo': {'members': [{'name': 'prach-ConfigIndex',
                                                                       'restricted-to': [(0,
                                                                                          63)],
                                                                       'type': 'INTEGER'},
                                                                      {'name': 'highSpeedFlag',
                                                                       'type': 'BOOLEAN'},
                                                                      {'name': 'zeroCorrelationZoneConfig',
                                                                       'restricted-to': [(0,
                                                                                          15)],
                                                                       'type': 'INTEGER'},
                                                                      {'name': 'prach-FreqOffset',
                                                                       'restricted-to': [(0,
                                                                                          94)],
                                                                       'type': 'INTEGER'}],
                                                          'type': 'SEQUENCE'},
                                     'PRACH-ConfigSIB': {'members': [{'name': 'rootSequenceIndex',
                                                                      'restricted-to': [(0,
                                                                                         837)],
                                                                      'type': 'INTEGER'},
                                                                     {'name': 'prach-ConfigInfo',
                                                                      'type': 'PRACH-ConfigInfo'}],
                                                         'type': 'SEQUENCE'},
                                     'PUCCH-ConfigCommon': {'members': [{'name': 'deltaPUCCH-Shift',
                                                                         'type': 'ENUMERATED',
                                                                         'values': {0: 'ds1',
                                                                                    1: 'ds2',
                                                                                    2: 'ds3'}},
                                                                        {'name': 'nRB-CQI',
                                                                         'restricted-to': [(0,
                                                                                            98)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'nCS-AN',
                                                                         'restricted-to': [(0,
                                                                                            7)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'n1PUCCH-AN',
                                                                         'restricted-to': [(0,
                                                                                            2047)],
                                                                         'type': 'INTEGER'}],
                                                            'type': 'SEQUENCE'},
                                     'PUCCH-ConfigDedicated': {'members': [{'members': [{'name': 'release',
                                                                                         'type': 'NULL'},
                                                                                        {'members': [{'name': 'repetitionFactor',
                                                                                                      'type': 'ENUMERATED',
                                                                                                      'values': {0: 'n2',
                                                                                                                 1: 'n4',
                                                                                                                 2: 'n6',
                                                                                                                 3: 'spare1'}},
                                                                                                     {'name': 'n1PUCCH-AN-Rep',
                                                                                                      'restricted-to': [(0,
                                                                                                                         2047)],
                                                                                                      'type': 'INTEGER'}],
                                                                                         'name': 'setup',
                                                                                         'type': 'SEQUENCE'}],
                                                                            'name': 'ackNackRepetition',
                                                                            'type': 'CHOICE'},
                                                                           {'name': 'tdd-AckNackFeedbackMode',
                                                                            'optional': True,
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'bundling',
                                                                                       1: 'multiplexing'}}],
                                                               'type': 'SEQUENCE'},
                                     'PUSCH-ConfigCommon': {'members': [{'members': [{'name': 'n-SB',
                                                                                      'restricted-to': [(1,
                                                                                                         4)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'hoppingMode',
                                                                                      'type': 'ENUMERATED',
                                                                                      'values': {0: 'interSubFrame',
                                                                                                 1: 'intraAndInterSubFrame'}},
                                                                                     {'name': 'pusch-HoppingOffset',
                                                                                      'restricted-to': [(0,
                                                                                                         98)],
                                                                                      'type': 'INTEGER'},
                                                                                     {'name': 'enable64QAM',
                                                                                      'type': 'BOOLEAN'}],
                                                                         'name': 'pusch-ConfigBasic',
                                                                         'type': 'SEQUENCE'},
                                                                        {'name': 'ul-ReferenceSignalsPUSCH',
                                                                         'type': 'UL-ReferenceSignalsPUSCH'}],
                                                            'type': 'SEQUENCE'},
                                     'PUSCH-ConfigDedicated': {'members': [{'name': 'betaOffset-ACK-Index',
                                                                            'restricted-to': [(0,
                                                                                               15)],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'betaOffset-RI-Index',
                                                                            'restricted-to': [(0,
                                                                                               15)],
                                                                            'type': 'INTEGER'},
                                                                           {'name': 'betaOffset-CQI-Index',
                                                                            'restricted-to': [(0,
                                                                                               15)],
                                                                            'type': 'INTEGER'}],
                                                               'type': 'SEQUENCE'},
                                     'Paging': {'members': [{'name': 'pagingRecordList',
                                                             'optional': True,
                                                             'type': 'PagingRecordList'},
                                                            {'name': 'systemInfoModification',
                                                             'optional': True,
                                                             'type': 'ENUMERATED',
                                                             'values': {0: 'true'}},
                                                            {'name': 'etws-Indication',
                                                             'optional': True,
                                                             'type': 'ENUMERATED',
                                                             'values': {0: 'true'}},
                                                            {'members': [],
                                                             'name': 'nonCriticalExtension',
                                                             'optional': True,
                                                             'type': 'SEQUENCE'}],
                                                'type': 'SEQUENCE'},
                                     'PagingRecord': {'members': [{'name': 'ue-Identity',
                                                                   'type': 'PagingUE-Identity'},
                                                                  {'name': 'cn-Domain',
                                                                   'type': 'ENUMERATED',
                                                                   'values': {0: 'ps',
                                                                              1: 'cs'}},
                                                                  '...'],
                                                      'type': 'SEQUENCE'},
                                     'PagingRecordList': {'element': {'type': 'PagingRecord'},
                                                          'size': [(1,
                                                                    'maxPageRec')],
                                                          'type': 'SEQUENCE '
                                                                  'OF'},
                                     'PagingUE-Identity': {'members': [{'name': 's-TMSI',
                                                                        'type': 'S-TMSI'},
                                                                       {'name': 'imsi',
                                                                        'type': 'IMSI'},
                                                                       '...'],
                                                           'type': 'CHOICE'},
                                     'PhyLayerParameters': {'members': [{'name': 'ue-TxAntennaSelectionSupported',
                                                                         'type': 'BOOLEAN'},
                                                                        {'name': 'ue-SpecificRefSigsSupported',
                                                                         'type': 'BOOLEAN'}],
                                                            'type': 'SEQUENCE'},
                                     'PhysCellId': {'restricted-to': [(0, 503)],
                                                    'type': 'INTEGER'},
                                     'PhysCellIdCDMA2000': {'restricted-to': [(0,
                                                                               'maxPNOffset')],
                                                            'type': 'INTEGER'},
                                     'PhysCellIdGERAN': {'members': [{'name': 'networkColourCode',
                                                                      'size': [3],
                                                                      'type': 'BIT '
                                                                              'STRING'},
                                                                     {'name': 'baseStationColourCode',
                                                                      'size': [3],
                                                                      'type': 'BIT '
                                                                              'STRING'}],
                                                         'type': 'SEQUENCE'},
                                     'PhysCellIdListCDMA2000': {'element': {'type': 'PhysCellIdCDMA2000'},
                                                                'size': [(1,
                                                                          16)],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'PhysCellIdRange': {'members': [{'name': 'start',
                                                                      'type': 'PhysCellId'},
                                                                     {'name': 'range',
                                                                      'optional': True,
                                                                      'type': 'ENUMERATED',
                                                                      'values': {0: 'n4',
                                                                                 1: 'n8',
                                                                                 2: 'n12',
                                                                                 3: 'n16',
                                                                                 4: 'n24',
                                                                                 5: 'n32',
                                                                                 6: 'n48',
                                                                                 7: 'n64',
                                                                                 8: 'n84',
                                                                                 9: 'n96',
                                                                                 10: 'n128',
                                                                                 11: 'n168',
                                                                                 12: 'n252',
                                                                                 13: 'n504',
                                                                                 14: 'spare2',
                                                                                 15: 'spare1'}}],
                                                         'type': 'SEQUENCE'},
                                     'PhysCellIdUTRA-FDD': {'restricted-to': [(0,
                                                                               511)],
                                                            'type': 'INTEGER'},
                                     'PhysCellIdUTRA-TDD': {'restricted-to': [(0,
                                                                               127)],
                                                            'type': 'INTEGER'},
                                     'PhysicalConfigDedicated': {'members': [{'name': 'pdsch-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'PDSCH-ConfigDedicated'},
                                                                             {'name': 'pucch-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'PUCCH-ConfigDedicated'},
                                                                             {'name': 'pusch-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'PUSCH-ConfigDedicated'},
                                                                             {'name': 'uplinkPowerControlDedicated',
                                                                              'optional': True,
                                                                              'type': 'UplinkPowerControlDedicated'},
                                                                             {'name': 'tpc-PDCCH-ConfigPUCCH',
                                                                              'optional': True,
                                                                              'type': 'TPC-PDCCH-Config'},
                                                                             {'name': 'tpc-PDCCH-ConfigPUSCH',
                                                                              'optional': True,
                                                                              'type': 'TPC-PDCCH-Config'},
                                                                             {'name': 'cqi-ReportConfig',
                                                                              'optional': True,
                                                                              'type': 'CQI-ReportConfig'},
                                                                             {'name': 'soundingRS-UL-ConfigDedicated',
                                                                              'optional': True,
                                                                              'type': 'SoundingRS-UL-ConfigDedicated'},
                                                                             {'members': [{'name': 'explicitValue',
                                                                                           'type': 'AntennaInfoDedicated'},
                                                                                          {'name': 'defaultValue',
                                                                                           'type': 'NULL'}],
                                                                              'name': 'antennaInfo',
                                                                              'optional': True,
                                                                              'type': 'CHOICE'},
                                                                             {'name': 'schedulingRequestConfig',
                                                                              'optional': True,
                                                                              'type': 'SchedulingRequestConfig'},
                                                                             '...'],
                                                                 'type': 'SEQUENCE'},
                                     'PollByte': {'type': 'ENUMERATED',
                                                  'values': {0: 'kB25',
                                                             1: 'kB50',
                                                             2: 'kB75',
                                                             3: 'kB100',
                                                             4: 'kB125',
                                                             5: 'kB250',
                                                             6: 'kB375',
                                                             7: 'kB500',
                                                             8: 'kB750',
                                                             9: 'kB1000',
                                                             10: 'kB1250',
                                                             11: 'kB1500',
                                                             12: 'kB2000',
                                                             13: 'kB3000',
                                                             14: 'kBinfinity',
                                                             15: 'spare1'}},
                                     'PollPDU': {'type': 'ENUMERATED',
                                                 'values': {0: 'p4',
                                                            1: 'p8',
                                                            2: 'p16',
                                                            3: 'p32',
                                                            4: 'p64',
                                                            5: 'p128',
                                                            6: 'p256',
                                                            7: 'pInfinity'}},
                                     'PreRegistrationInfoHRPD': {'members': [{'name': 'preRegistrationAllowed',
                                                                              'type': 'BOOLEAN'},
                                                                             {'name': 'preRegistrationZoneId',
                                                                              'optional': True,
                                                                              'type': 'PreRegistrationZoneIdHRPD'},
                                                                             {'name': 'secondaryPreRegistrationZoneIdList',
                                                                              'optional': True,
                                                                              'type': 'SecondaryPreRegistrationZoneIdListHRPD'}],
                                                                 'type': 'SEQUENCE'},
                                     'PreRegistrationZoneIdHRPD': {'restricted-to': [(0,
                                                                                      255)],
                                                                   'type': 'INTEGER'},
                                     'PresenceAntennaPort1': {'type': 'BOOLEAN'},
                                     'Q-OffsetRange': {'type': 'ENUMERATED',
                                                       'values': {0: 'dB-24',
                                                                  1: 'dB-22',
                                                                  2: 'dB-20',
                                                                  3: 'dB-18',
                                                                  4: 'dB-16',
                                                                  5: 'dB-14',
                                                                  6: 'dB-12',
                                                                  7: 'dB-10',
                                                                  8: 'dB-8',
                                                                  9: 'dB-6',
                                                                  10: 'dB-5',
                                                                  11: 'dB-4',
                                                                  12: 'dB-3',
                                                                  13: 'dB-2',
                                                                  14: 'dB-1',
                                                                  15: 'dB0',
                                                                  16: 'dB1',
                                                                  17: 'dB2',
                                                                  18: 'dB3',
                                                                  19: 'dB4',
                                                                  20: 'dB5',
                                                                  21: 'dB6',
                                                                  22: 'dB8',
                                                                  23: 'dB10',
                                                                  24: 'dB12',
                                                                  25: 'dB14',
                                                                  26: 'dB16',
                                                                  27: 'dB18',
                                                                  28: 'dB20',
                                                                  29: 'dB22',
                                                                  30: 'dB24'}},
                                     'Q-OffsetRangeInterRAT': {'restricted-to': [(-15,
                                                                                  15)],
                                                               'type': 'INTEGER'},
                                     'Q-RxLevMin': {'restricted-to': [(-70,
                                                                       -22)],
                                                    'type': 'INTEGER'},
                                     'QuantityConfig': {'members': [{'name': 'quantityConfigEUTRA',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigEUTRA'},
                                                                    {'name': 'quantityConfigUTRA',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigUTRA'},
                                                                    {'name': 'quantityConfigGERAN',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigGERAN'},
                                                                    {'name': 'quantityConfigCDMA2000',
                                                                     'optional': True,
                                                                     'type': 'QuantityConfigCDMA2000'},
                                                                    '...'],
                                                        'type': 'SEQUENCE'},
                                     'QuantityConfigCDMA2000': {'members': [{'name': 'measQuantityCDMA2000',
                                                                             'type': 'ENUMERATED',
                                                                             'values': {0: 'pilotStrength',
                                                                                        1: 'pilotPnPhaseAndPilotStrength'}}],
                                                                'type': 'SEQUENCE'},
                                     'QuantityConfigEUTRA': {'members': [{'default': 'fc4',
                                                                          'name': 'filterCoefficientRSRP',
                                                                          'type': 'FilterCoefficient'},
                                                                         {'default': 'fc4',
                                                                          'name': 'filterCoefficientRSRQ',
                                                                          'type': 'FilterCoefficient'}],
                                                             'type': 'SEQUENCE'},
                                     'QuantityConfigGERAN': {'members': [{'name': 'measQuantityGERAN',
                                                                          'type': 'ENUMERATED',
                                                                          'values': {0: 'rssi'}},
                                                                         {'default': 'fc2',
                                                                          'name': 'filterCoefficient',
                                                                          'type': 'FilterCoefficient'}],
                                                             'type': 'SEQUENCE'},
                                     'QuantityConfigUTRA': {'members': [{'name': 'measQuantityUTRA-FDD',
                                                                         'type': 'ENUMERATED',
                                                                         'values': {0: 'cpich-RSCP',
                                                                                    1: 'cpich-EcN0'}},
                                                                        {'name': 'measQuantityUTRA-TDD',
                                                                         'type': 'ENUMERATED',
                                                                         'values': {0: 'pccpch-RSCP'}},
                                                                        {'default': 'fc4',
                                                                         'name': 'filterCoefficient',
                                                                         'type': 'FilterCoefficient'}],
                                                            'type': 'SEQUENCE'},
                                     'RACH-ConfigCommon': {'members': [{'members': [{'name': 'numberOfRA-Preambles',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': {0: 'n4',
                                                                                                1: 'n8',
                                                                                                2: 'n12',
                                                                                                3: 'n16',
                                                                                                4: 'n20',
                                                                                                5: 'n24',
                                                                                                6: 'n28',
                                                                                                7: 'n32',
                                                                                                8: 'n36',
                                                                                                9: 'n40',
                                                                                                10: 'n44',
                                                                                                11: 'n48',
                                                                                                12: 'n52',
                                                                                                13: 'n56',
                                                                                                14: 'n60',
                                                                                                15: 'n64'}},
                                                                                    {'members': [{'name': 'sizeOfRA-PreamblesGroupA',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': {0: 'n4',
                                                                                                             1: 'n8',
                                                                                                             2: 'n12',
                                                                                                             3: 'n16',
                                                                                                             4: 'n20',
                                                                                                             5: 'n24',
                                                                                                             6: 'n28',
                                                                                                             7: 'n32',
                                                                                                             8: 'n36',
                                                                                                             9: 'n40',
                                                                                                             10: 'n44',
                                                                                                             11: 'n48',
                                                                                                             12: 'n52',
                                                                                                             13: 'n56',
                                                                                                             14: 'n60'}},
                                                                                                 {'name': 'messageSizeGroupA',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': {0: 'b56',
                                                                                                             1: 'b144',
                                                                                                             2: 'b208',
                                                                                                             3: 'b256'}},
                                                                                                 {'name': 'messagePowerOffsetGroupB',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': {0: 'minusinfinity',
                                                                                                             1: 'dB0',
                                                                                                             2: 'dB5',
                                                                                                             3: 'dB8',
                                                                                                             4: 'dB10',
                                                                                                             5: 'dB12',
                                                                                                             6: 'dB15',
                                                                                                             7: 'dB18'}},
                                                                                                 '...'],
                                                                                     'name': 'preamblesGroupAConfig',
                                                                                     'optional': True,
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'preambleInfo',
                                                                        'type': 'SEQUENCE'},
                                                                       {'members': [{'name': 'powerRampingStep',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': {0: 'dB0',
                                                                                                1: 'dB2',
                                                                                                2: 'dB4',
                                                                                                3: 'dB6'}},
                                                                                    {'name': 'preambleInitialReceivedTargetPower',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': {0: 'dBm-120',
                                                                                                1: 'dBm-118',
                                                                                                2: 'dBm-116',
                                                                                                3: 'dBm-114',
                                                                                                4: 'dBm-112',
                                                                                                5: 'dBm-110',
                                                                                                6: 'dBm-108',
                                                                                                7: 'dBm-106',
                                                                                                8: 'dBm-104',
                                                                                                9: 'dBm-102',
                                                                                                10: 'dBm-100',
                                                                                                11: 'dBm-98',
                                                                                                12: 'dBm-96',
                                                                                                13: 'dBm-94',
                                                                                                14: 'dBm-92',
                                                                                                15: 'dBm-90'}}],
                                                                        'name': 'powerRampingParameters',
                                                                        'type': 'SEQUENCE'},
                                                                       {'members': [{'name': 'preambleTransMax',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': {0: 'n3',
                                                                                                1: 'n4',
                                                                                                2: 'n5',
                                                                                                3: 'n6',
                                                                                                4: 'n7',
                                                                                                5: 'n8',
                                                                                                6: 'n10',
                                                                                                7: 'n20',
                                                                                                8: 'n50',
                                                                                                9: 'n100',
                                                                                                10: 'n200'}},
                                                                                    {'name': 'ra-ResponseWindowSize',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': {0: 'sf2',
                                                                                                1: 'sf3',
                                                                                                2: 'sf4',
                                                                                                3: 'sf5',
                                                                                                4: 'sf6',
                                                                                                5: 'sf7',
                                                                                                6: 'sf8',
                                                                                                7: 'sf10'}},
                                                                                    {'name': 'mac-ContentionResolutionTimer',
                                                                                     'type': 'ENUMERATED',
                                                                                     'values': {0: 'sf8',
                                                                                                1: 'sf16',
                                                                                                2: 'sf24',
                                                                                                3: 'sf32',
                                                                                                4: 'sf40',
                                                                                                5: 'sf48',
                                                                                                6: 'sf56',
                                                                                                7: 'sf64'}}],
                                                                        'name': 'ra-SupervisionInfo',
                                                                        'type': 'SEQUENCE'},
                                                                       {'name': 'maxHARQ-Msg3Tx',
                                                                        'restricted-to': [(1,
                                                                                           8)],
                                                                        'type': 'INTEGER'},
                                                                       '...'],
                                                           'type': 'SEQUENCE'},
                                     'RACH-ConfigDedicated': {'members': [{'name': 'ra-PreambleIndex',
                                                                           'restricted-to': [(0,
                                                                                              63)],
                                                                           'type': 'INTEGER'},
                                                                          {'name': 'ra-PRACH-MaskIndex',
                                                                           'restricted-to': [(0,
                                                                                              15)],
                                                                           'type': 'INTEGER'}],
                                                              'type': 'SEQUENCE'},
                                     'RAND-CDMA2000': {'size': [32],
                                                       'type': 'BIT STRING'},
                                     'RAT-Type': {'type': 'ENUMERATED',
                                                  'values': {0: 'eutra',
                                                             1: 'utra',
                                                             2: 'geran-cs',
                                                             3: 'geran-ps',
                                                             4: 'cdma2000-1XRTT',
                                                             5: 'spare3',
                                                             6: 'spare2',
                                                             7: 'spare1',
                                                             8: '...'}},
                                     'RF-Parameters': {'members': [{'name': 'supportedBandListEUTRA',
                                                                    'type': 'SupportedBandListEUTRA'}],
                                                       'type': 'SEQUENCE'},
                                     'RLC-Config': {'members': [{'members': [{'name': 'ul-AM-RLC',
                                                                              'type': 'UL-AM-RLC'},
                                                                             {'name': 'dl-AM-RLC',
                                                                              'type': 'DL-AM-RLC'}],
                                                                 'name': 'am',
                                                                 'type': 'SEQUENCE'},
                                                                {'members': [{'name': 'ul-UM-RLC',
                                                                              'type': 'UL-UM-RLC'},
                                                                             {'name': 'dl-UM-RLC',
                                                                              'type': 'DL-UM-RLC'}],
                                                                 'name': 'um-Bi-Directional',
                                                                 'type': 'SEQUENCE'},
                                                                {'members': [{'name': 'ul-UM-RLC',
                                                                              'type': 'UL-UM-RLC'}],
                                                                 'name': 'um-Uni-Directional-UL',
                                                                 'type': 'SEQUENCE'},
                                                                {'members': [{'name': 'dl-UM-RLC',
                                                                              'type': 'DL-UM-RLC'}],
                                                                 'name': 'um-Uni-Directional-DL',
                                                                 'type': 'SEQUENCE'},
                                                                '...'],
                                                    'type': 'CHOICE'},
                                     'RRC-TransactionIdentifier': {'restricted-to': [(0,
                                                                                      3)],
                                                                   'type': 'INTEGER'},
                                     'RRCConnectionReconfiguration': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                   'type': 'RRC-TransactionIdentifier'},
                                                                                  {'members': [{'members': [{'name': 'rrcConnectionReconfiguration-r8',
                                                                                                             'type': 'RRCConnectionReconfiguration-r8-IEs'},
                                                                                                            {'name': 'spare7',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare6',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare5',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare4',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare3',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare2',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare1',
                                                                                                             'type': 'NULL'}],
                                                                                                'name': 'c1',
                                                                                                'type': 'CHOICE'},
                                                                                               {'members': [],
                                                                                                'name': 'criticalExtensionsFuture',
                                                                                                'type': 'SEQUENCE'}],
                                                                                   'name': 'criticalExtensions',
                                                                                   'type': 'CHOICE'}],
                                                                      'type': 'SEQUENCE'},
                                     'RRCConnectionReconfiguration-r8-IEs': {'members': [{'name': 'measConfig',
                                                                                          'optional': True,
                                                                                          'type': 'MeasConfig'},
                                                                                         {'name': 'mobilityControlInfo',
                                                                                          'optional': True,
                                                                                          'type': 'MobilityControlInfo'},
                                                                                         {'element': {'type': 'DedicatedInfoNAS'},
                                                                                          'name': 'dedicatedInfoNASList',
                                                                                          'optional': True,
                                                                                          'size': [(1,
                                                                                                    'maxDRB')],
                                                                                          'type': 'SEQUENCE '
                                                                                                  'OF'},
                                                                                         {'name': 'radioResourceConfigDedicated',
                                                                                          'optional': True,
                                                                                          'type': 'RadioResourceConfigDedicated'},
                                                                                         {'name': 'securityConfigHO',
                                                                                          'optional': True,
                                                                                          'type': 'SecurityConfigHO'},
                                                                                         {'members': [],
                                                                                          'name': 'nonCriticalExtension',
                                                                                          'optional': True,
                                                                                          'type': 'SEQUENCE'}],
                                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReconfigurationComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                                          {'members': [{'name': 'rrcConnectionReconfigurationComplete-r8',
                                                                                                        'type': 'RRCConnectionReconfigurationComplete-r8-IEs'},
                                                                                                       {'members': [],
                                                                                                        'name': 'criticalExtensionsFuture',
                                                                                                        'type': 'SEQUENCE'}],
                                                                                           'name': 'criticalExtensions',
                                                                                           'type': 'CHOICE'}],
                                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionReconfigurationComplete-r8-IEs': {'members': [{'members': [],
                                                                                                  'name': 'nonCriticalExtension',
                                                                                                  'optional': True,
                                                                                                  'type': 'SEQUENCE'}],
                                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishment': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                   'type': 'RRC-TransactionIdentifier'},
                                                                                  {'members': [{'members': [{'name': 'rrcConnectionReestablishment-r8',
                                                                                                             'type': 'RRCConnectionReestablishment-r8-IEs'},
                                                                                                            {'name': 'spare7',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare6',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare5',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare4',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare3',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare2',
                                                                                                             'type': 'NULL'},
                                                                                                            {'name': 'spare1',
                                                                                                             'type': 'NULL'}],
                                                                                                'name': 'c1',
                                                                                                'type': 'CHOICE'},
                                                                                               {'members': [],
                                                                                                'name': 'criticalExtensionsFuture',
                                                                                                'type': 'SEQUENCE'}],
                                                                                   'name': 'criticalExtensions',
                                                                                   'type': 'CHOICE'}],
                                                                      'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishment-r8-IEs': {'members': [{'name': 'radioResourceConfigDedicated',
                                                                                          'type': 'RadioResourceConfigDedicated'},
                                                                                         {'name': 'nextHopChainingCount',
                                                                                          'type': 'NextHopChainingCount'},
                                                                                         {'members': [],
                                                                                          'name': 'nonCriticalExtension',
                                                                                          'optional': True,
                                                                                          'type': 'SEQUENCE'}],
                                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                                          {'members': [{'name': 'rrcConnectionReestablishmentComplete-r8',
                                                                                                        'type': 'RRCConnectionReestablishmentComplete-r8-IEs'},
                                                                                                       {'members': [],
                                                                                                        'name': 'criticalExtensionsFuture',
                                                                                                        'type': 'SEQUENCE'}],
                                                                                           'name': 'criticalExtensions',
                                                                                           'type': 'CHOICE'}],
                                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentComplete-r8-IEs': {'members': [{'members': [],
                                                                                                  'name': 'nonCriticalExtension',
                                                                                                  'optional': True,
                                                                                                  'type': 'SEQUENCE'}],
                                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentReject': {'members': [{'members': [{'name': 'rrcConnectionReestablishmentReject-r8',
                                                                                                      'type': 'RRCConnectionReestablishmentReject-r8-IEs'},
                                                                                                     {'members': [],
                                                                                                      'name': 'criticalExtensionsFuture',
                                                                                                      'type': 'SEQUENCE'}],
                                                                                         'name': 'criticalExtensions',
                                                                                         'type': 'CHOICE'}],
                                                                            'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentReject-r8-IEs': {'members': [{'members': [],
                                                                                                'name': 'nonCriticalExtension',
                                                                                                'optional': True,
                                                                                                'type': 'SEQUENCE'}],
                                                                                   'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentRequest': {'members': [{'members': [{'name': 'rrcConnectionReestablishmentRequest-r8',
                                                                                                       'type': 'RRCConnectionReestablishmentRequest-r8-IEs'},
                                                                                                      {'members': [],
                                                                                                       'name': 'criticalExtensionsFuture',
                                                                                                       'type': 'SEQUENCE'}],
                                                                                          'name': 'criticalExtensions',
                                                                                          'type': 'CHOICE'}],
                                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReestablishmentRequest-r8-IEs': {'members': [{'name': 'ue-Identity',
                                                                                                 'type': 'ReestabUE-Identity'},
                                                                                                {'name': 'reestablishmentCause',
                                                                                                 'type': 'ReestablishmentCause'},
                                                                                                {'name': 'spare',
                                                                                                 'size': [2],
                                                                                                 'type': 'BIT '
                                                                                                         'STRING'}],
                                                                                    'type': 'SEQUENCE'},
                                     'RRCConnectionReject': {'members': [{'members': [{'members': [{'name': 'rrcConnectionReject-r8',
                                                                                                    'type': 'RRCConnectionReject-r8-IEs'},
                                                                                                   {'name': 'spare3',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare2',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare1',
                                                                                                    'type': 'NULL'}],
                                                                                       'name': 'c1',
                                                                                       'type': 'CHOICE'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'RRCConnectionReject-r8-IEs': {'members': [{'name': 'waitTime',
                                                                                 'restricted-to': [(1,
                                                                                                    16)],
                                                                                 'type': 'INTEGER'},
                                                                                {'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'RRCConnectionRelease': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                          {'members': [{'members': [{'name': 'rrcConnectionRelease-r8',
                                                                                                     'type': 'RRCConnectionRelease-r8-IEs'},
                                                                                                    {'name': 'spare3',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare2',
                                                                                                     'type': 'NULL'},
                                                                                                    {'name': 'spare1',
                                                                                                     'type': 'NULL'}],
                                                                                        'name': 'c1',
                                                                                        'type': 'CHOICE'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionRelease-r8-IEs': {'members': [{'name': 'releaseCause',
                                                                                  'type': 'ReleaseCause'},
                                                                                 {'name': 'redirectedCarrierInfo',
                                                                                  'optional': True,
                                                                                  'type': 'RedirectedCarrierInfo'},
                                                                                 {'name': 'idleModeMobilityControlInfo',
                                                                                  'optional': True,
                                                                                  'type': 'IdleModeMobilityControlInfo'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionRequest': {'members': [{'members': [{'name': 'rrcConnectionRequest-r8',
                                                                                        'type': 'RRCConnectionRequest-r8-IEs'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'RRCConnectionRequest-r8-IEs': {'members': [{'name': 'ue-Identity',
                                                                                  'type': 'InitialUE-Identity'},
                                                                                 {'name': 'establishmentCause',
                                                                                  'type': 'EstablishmentCause'},
                                                                                 {'name': 'spare',
                                                                                  'size': [1],
                                                                                  'type': 'BIT '
                                                                                          'STRING'}],
                                                                     'type': 'SEQUENCE'},
                                     'RRCConnectionSetup': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                         'type': 'RRC-TransactionIdentifier'},
                                                                        {'members': [{'members': [{'name': 'rrcConnectionSetup-r8',
                                                                                                   'type': 'RRCConnectionSetup-r8-IEs'},
                                                                                                  {'name': 'spare7',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare6',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare5',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare4',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare3',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare2',
                                                                                                   'type': 'NULL'},
                                                                                                  {'name': 'spare1',
                                                                                                   'type': 'NULL'}],
                                                                                      'name': 'c1',
                                                                                      'type': 'CHOICE'},
                                                                                     {'members': [],
                                                                                      'name': 'criticalExtensionsFuture',
                                                                                      'type': 'SEQUENCE'}],
                                                                         'name': 'criticalExtensions',
                                                                         'type': 'CHOICE'}],
                                                            'type': 'SEQUENCE'},
                                     'RRCConnectionSetup-r8-IEs': {'members': [{'name': 'radioResourceConfigDedicated',
                                                                                'type': 'RadioResourceConfigDedicated'},
                                                                               {'members': [],
                                                                                'name': 'nonCriticalExtension',
                                                                                'optional': True,
                                                                                'type': 'SEQUENCE'}],
                                                                   'type': 'SEQUENCE'},
                                     'RRCConnectionSetupComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                                 'type': 'RRC-TransactionIdentifier'},
                                                                                {'members': [{'members': [{'name': 'rrcConnectionSetupComplete-r8',
                                                                                                           'type': 'RRCConnectionSetupComplete-r8-IEs'},
                                                                                                          {'name': 'spare3',
                                                                                                           'type': 'NULL'},
                                                                                                          {'name': 'spare2',
                                                                                                           'type': 'NULL'},
                                                                                                          {'name': 'spare1',
                                                                                                           'type': 'NULL'}],
                                                                                              'name': 'c1',
                                                                                              'type': 'CHOICE'},
                                                                                             {'members': [],
                                                                                              'name': 'criticalExtensionsFuture',
                                                                                              'type': 'SEQUENCE'}],
                                                                                 'name': 'criticalExtensions',
                                                                                 'type': 'CHOICE'}],
                                                                    'type': 'SEQUENCE'},
                                     'RRCConnectionSetupComplete-r8-IEs': {'members': [{'name': 'selectedPLMN-Identity',
                                                                                        'restricted-to': [(1,
                                                                                                           6)],
                                                                                        'type': 'INTEGER'},
                                                                                       {'name': 'registeredMME',
                                                                                        'optional': True,
                                                                                        'type': 'RegisteredMME'},
                                                                                       {'name': 'dedicatedInfoNAS',
                                                                                        'type': 'DedicatedInfoNAS'},
                                                                                       {'members': [],
                                                                                        'name': 'nonCriticalExtension',
                                                                                        'optional': True,
                                                                                        'type': 'SEQUENCE'}],
                                                                           'type': 'SEQUENCE'},
                                     'RSRP-Range': {'restricted-to': [(0, 97)],
                                                    'type': 'INTEGER'},
                                     'RSRQ-Range': {'restricted-to': [(0, 34)],
                                                    'type': 'INTEGER'},
                                     'RadioResourceConfigCommon': {'members': [{'name': 'rach-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'RACH-ConfigCommon'},
                                                                               {'name': 'prach-Config',
                                                                                'type': 'PRACH-Config'},
                                                                               {'name': 'pdsch-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'PDSCH-ConfigCommon'},
                                                                               {'name': 'pusch-ConfigCommon',
                                                                                'type': 'PUSCH-ConfigCommon'},
                                                                               {'name': 'phich-Config',
                                                                                'optional': True,
                                                                                'type': 'PHICH-Config'},
                                                                               {'name': 'pucch-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'PUCCH-ConfigCommon'},
                                                                               {'name': 'soundingRS-UL-ConfigCommon',
                                                                                'optional': True,
                                                                                'type': 'SoundingRS-UL-ConfigCommon'},
                                                                               {'name': 'uplinkPowerControlCommon',
                                                                                'optional': True,
                                                                                'type': 'UplinkPowerControlCommon'},
                                                                               {'name': 'antennaInfoCommon',
                                                                                'optional': True,
                                                                                'type': 'AntennaInfoCommon'},
                                                                               {'name': 'p-Max',
                                                                                'optional': True,
                                                                                'type': 'P-Max'},
                                                                               {'name': 'tdd-Config',
                                                                                'optional': True,
                                                                                'type': 'TDD-Config'},
                                                                               {'name': 'ul-CyclicPrefixLength',
                                                                                'type': 'UL-CyclicPrefixLength'},
                                                                               '...'],
                                                                   'type': 'SEQUENCE'},
                                     'RadioResourceConfigCommonSIB': {'members': [{'name': 'rach-ConfigCommon',
                                                                                   'type': 'RACH-ConfigCommon'},
                                                                                  {'name': 'bcch-Config',
                                                                                   'type': 'BCCH-Config'},
                                                                                  {'name': 'pcch-Config',
                                                                                   'type': 'PCCH-Config'},
                                                                                  {'name': 'prach-Config',
                                                                                   'type': 'PRACH-ConfigSIB'},
                                                                                  {'name': 'pdsch-ConfigCommon',
                                                                                   'type': 'PDSCH-ConfigCommon'},
                                                                                  {'name': 'pusch-ConfigCommon',
                                                                                   'type': 'PUSCH-ConfigCommon'},
                                                                                  {'name': 'pucch-ConfigCommon',
                                                                                   'type': 'PUCCH-ConfigCommon'},
                                                                                  {'name': 'soundingRS-UL-ConfigCommon',
                                                                                   'type': 'SoundingRS-UL-ConfigCommon'},
                                                                                  {'name': 'uplinkPowerControlCommon',
                                                                                   'type': 'UplinkPowerControlCommon'},
                                                                                  {'name': 'ul-CyclicPrefixLength',
                                                                                   'type': 'UL-CyclicPrefixLength'},
                                                                                  '...'],
                                                                      'type': 'SEQUENCE'},
                                     'RadioResourceConfigDedicated': {'members': [{'name': 'srb-ToAddModList',
                                                                                   'optional': True,
                                                                                   'type': 'SRB-ToAddModList'},
                                                                                  {'name': 'drb-ToAddModList',
                                                                                   'optional': True,
                                                                                   'type': 'DRB-ToAddModList'},
                                                                                  {'name': 'drb-ToReleaseList',
                                                                                   'optional': True,
                                                                                   'type': 'DRB-ToReleaseList'},
                                                                                  {'members': [{'name': 'explicitValue',
                                                                                                'type': 'MAC-MainConfig'},
                                                                                               {'name': 'defaultValue',
                                                                                                'type': 'NULL'}],
                                                                                   'name': 'mac-MainConfig',
                                                                                   'optional': True,
                                                                                   'type': 'CHOICE'},
                                                                                  {'name': 'sps-Config',
                                                                                   'optional': True,
                                                                                   'type': 'SPS-Config'},
                                                                                  {'name': 'physicalConfigDedicated',
                                                                                   'optional': True,
                                                                                   'type': 'PhysicalConfigDedicated'},
                                                                                  '...'],
                                                                      'type': 'SEQUENCE'},
                                     'RedirectedCarrierInfo': {'members': [{'name': 'eutra',
                                                                            'type': 'ARFCN-ValueEUTRA'},
                                                                           {'name': 'geran',
                                                                            'type': 'CarrierFreqsGERAN'},
                                                                           {'name': 'utra-FDD',
                                                                            'type': 'ARFCN-ValueUTRA'},
                                                                           {'name': 'utra-TDD',
                                                                            'type': 'ARFCN-ValueUTRA'},
                                                                           {'name': 'cdma2000-HRPD',
                                                                            'type': 'CarrierFreqCDMA2000'},
                                                                           {'name': 'cdma2000-1xRTT',
                                                                            'type': 'CarrierFreqCDMA2000'},
                                                                           '...'],
                                                               'type': 'CHOICE'},
                                     'ReestabUE-Identity': {'members': [{'name': 'c-RNTI',
                                                                         'type': 'C-RNTI'},
                                                                        {'name': 'physCellId',
                                                                         'type': 'PhysCellId'},
                                                                        {'name': 'shortMAC-I',
                                                                         'type': 'ShortMAC-I'}],
                                                            'type': 'SEQUENCE'},
                                     'ReestablishmentCause': {'type': 'ENUMERATED',
                                                              'values': {0: 'reconfigurationFailure',
                                                                         1: 'handoverFailure',
                                                                         2: 'otherFailure',
                                                                         3: 'spare1'}},
                                     'RegisteredMME': {'members': [{'name': 'plmn-Identity',
                                                                    'optional': True,
                                                                    'type': 'PLMN-Identity'},
                                                                   {'name': 'mmegi',
                                                                    'size': [16],
                                                                    'type': 'BIT '
                                                                            'STRING'},
                                                                   {'name': 'mmec',
                                                                    'type': 'MMEC'}],
                                                       'type': 'SEQUENCE'},
                                     'ReleaseCause': {'type': 'ENUMERATED',
                                                      'values': {0: 'loadBalancingTAUrequired',
                                                                 1: 'other',
                                                                 2: 'spare2',
                                                                 3: 'spare1'}},
                                     'ReportConfigEUTRA': {'members': [{'members': [{'members': [{'members': [{'members': [{'name': 'a1-Threshold',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA1',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a2-Threshold',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA2',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a3-Offset',
                                                                                                                            'restricted-to': [(-30,
                                                                                                                                               30)],
                                                                                                                            'type': 'INTEGER'},
                                                                                                                           {'name': 'reportOnLeave',
                                                                                                                            'type': 'BOOLEAN'}],
                                                                                                               'name': 'eventA3',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a4-Threshold',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA4',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              {'members': [{'name': 'a5-Threshold1',
                                                                                                                            'type': 'ThresholdEUTRA'},
                                                                                                                           {'name': 'a5-Threshold2',
                                                                                                                            'type': 'ThresholdEUTRA'}],
                                                                                                               'name': 'eventA5',
                                                                                                               'type': 'SEQUENCE'},
                                                                                                              '...'],
                                                                                                  'name': 'eventId',
                                                                                                  'type': 'CHOICE'},
                                                                                                 {'name': 'hysteresis',
                                                                                                  'type': 'Hysteresis'},
                                                                                                 {'name': 'timeToTrigger',
                                                                                                  'type': 'TimeToTrigger'}],
                                                                                     'name': 'event',
                                                                                     'type': 'SEQUENCE'},
                                                                                    {'members': [{'name': 'purpose',
                                                                                                  'type': 'ENUMERATED',
                                                                                                  'values': {0: 'reportStrongestCells',
                                                                                                             1: 'reportCGI'}}],
                                                                                     'name': 'periodical',
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'triggerType',
                                                                        'type': 'CHOICE'},
                                                                       {'name': 'triggerQuantity',
                                                                        'type': 'ENUMERATED',
                                                                        'values': {0: 'rsrp',
                                                                                   1: 'rsrq'}},
                                                                       {'name': 'reportQuantity',
                                                                        'type': 'ENUMERATED',
                                                                        'values': {0: 'sameAsTriggerQuantity',
                                                                                   1: 'both'}},
                                                                       {'name': 'maxReportCells',
                                                                        'restricted-to': [(1,
                                                                                           'maxCellReport')],
                                                                        'type': 'INTEGER'},
                                                                       {'name': 'reportInterval',
                                                                        'type': 'ReportInterval'},
                                                                       {'name': 'reportAmount',
                                                                        'type': 'ENUMERATED',
                                                                        'values': {0: 'r1',
                                                                                   1: 'r2',
                                                                                   2: 'r4',
                                                                                   3: 'r8',
                                                                                   4: 'r16',
                                                                                   5: 'r32',
                                                                                   6: 'r64',
                                                                                   7: 'infinity'}},
                                                                       '...'],
                                                           'type': 'SEQUENCE'},
                                     'ReportConfigId': {'restricted-to': [(1,
                                                                           'maxReportConfigId')],
                                                        'type': 'INTEGER'},
                                     'ReportConfigInterRAT': {'members': [{'members': [{'members': [{'members': [{'members': [{'members': [{'name': 'b1-ThresholdUTRA',
                                                                                                                                            'type': 'ThresholdUTRA'},
                                                                                                                                           {'name': 'b1-ThresholdGERAN',
                                                                                                                                            'type': 'ThresholdGERAN'},
                                                                                                                                           {'name': 'b1-ThresholdCDMA2000',
                                                                                                                                            'type': 'ThresholdCDMA2000'}],
                                                                                                                               'name': 'b1-Threshold',
                                                                                                                               'type': 'CHOICE'}],
                                                                                                                  'name': 'eventB1',
                                                                                                                  'type': 'SEQUENCE'},
                                                                                                                 {'members': [{'name': 'b2-Threshold1',
                                                                                                                               'type': 'ThresholdEUTRA'},
                                                                                                                              {'members': [{'name': 'b2-Threshold2UTRA',
                                                                                                                                            'type': 'ThresholdUTRA'},
                                                                                                                                           {'name': 'b2-Threshold2GERAN',
                                                                                                                                            'type': 'ThresholdGERAN'},
                                                                                                                                           {'name': 'b2-Threshold2CDMA2000',
                                                                                                                                            'type': 'ThresholdCDMA2000'}],
                                                                                                                               'name': 'b2-Threshold2',
                                                                                                                               'type': 'CHOICE'}],
                                                                                                                  'name': 'eventB2',
                                                                                                                  'type': 'SEQUENCE'},
                                                                                                                 '...'],
                                                                                                     'name': 'eventId',
                                                                                                     'type': 'CHOICE'},
                                                                                                    {'name': 'hysteresis',
                                                                                                     'type': 'Hysteresis'},
                                                                                                    {'name': 'timeToTrigger',
                                                                                                     'type': 'TimeToTrigger'}],
                                                                                        'name': 'event',
                                                                                        'type': 'SEQUENCE'},
                                                                                       {'members': [{'name': 'purpose',
                                                                                                     'type': 'ENUMERATED',
                                                                                                     'values': {0: 'reportStrongestCells',
                                                                                                                1: 'reportStrongestCellsForSON',
                                                                                                                2: 'reportCGI'}}],
                                                                                        'name': 'periodical',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'triggerType',
                                                                           'type': 'CHOICE'},
                                                                          {'name': 'maxReportCells',
                                                                           'restricted-to': [(1,
                                                                                              'maxCellReport')],
                                                                           'type': 'INTEGER'},
                                                                          {'name': 'reportInterval',
                                                                           'type': 'ReportInterval'},
                                                                          {'name': 'reportAmount',
                                                                           'type': 'ENUMERATED',
                                                                           'values': {0: 'r1',
                                                                                      1: 'r2',
                                                                                      2: 'r4',
                                                                                      3: 'r8',
                                                                                      4: 'r16',
                                                                                      5: 'r32',
                                                                                      6: 'r64',
                                                                                      7: 'infinity'}},
                                                                          '...'],
                                                              'type': 'SEQUENCE'},
                                     'ReportConfigToAddMod': {'members': [{'name': 'reportConfigId',
                                                                           'type': 'ReportConfigId'},
                                                                          {'members': [{'name': 'reportConfigEUTRA',
                                                                                        'type': 'ReportConfigEUTRA'},
                                                                                       {'name': 'reportConfigInterRAT',
                                                                                        'type': 'ReportConfigInterRAT'}],
                                                                           'name': 'reportConfig',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'ReportConfigToAddModList': {'element': {'type': 'ReportConfigToAddMod'},
                                                                  'size': [(1,
                                                                            'maxReportConfigId')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'ReportConfigToRemoveList': {'element': {'type': 'ReportConfigId'},
                                                                  'size': [(1,
                                                                            'maxReportConfigId')],
                                                                  'type': 'SEQUENCE '
                                                                          'OF'},
                                     'ReportInterval': {'type': 'ENUMERATED',
                                                        'values': {0: 'ms120',
                                                                   1: 'ms240',
                                                                   2: 'ms480',
                                                                   3: 'ms640',
                                                                   4: 'ms1024',
                                                                   5: 'ms2048',
                                                                   6: 'ms5120',
                                                                   7: 'ms10240',
                                                                   8: 'min1',
                                                                   9: 'min6',
                                                                   10: 'min12',
                                                                   11: 'min30',
                                                                   12: 'min60',
                                                                   13: 'spare3',
                                                                   14: 'spare2',
                                                                   15: 'spare1'}},
                                     'ReselectionThreshold': {'restricted-to': [(0,
                                                                                 31)],
                                                              'type': 'INTEGER'},
                                     'S-TMSI': {'members': [{'name': 'mmec',
                                                             'type': 'MMEC'},
                                                            {'name': 'm-TMSI',
                                                             'size': [32],
                                                             'type': 'BIT '
                                                                     'STRING'}],
                                                'type': 'SEQUENCE'},
                                     'SI-OrPSI-GERAN': {'members': [{'name': 'si',
                                                                     'type': 'SystemInfoListGERAN'},
                                                                    {'name': 'psi',
                                                                     'type': 'SystemInfoListGERAN'}],
                                                        'type': 'CHOICE'},
                                     'SIB-MappingInfo': {'element': {'type': 'SIB-Type'},
                                                         'size': [(0,
                                                                   'maxSIB-1')],
                                                         'type': 'SEQUENCE OF'},
                                     'SIB-Type': {'type': 'ENUMERATED',
                                                  'values': {0: 'sibType3',
                                                             1: 'sibType4',
                                                             2: 'sibType5',
                                                             3: 'sibType6',
                                                             4: 'sibType7',
                                                             5: 'sibType8',
                                                             6: 'sibType9',
                                                             7: 'sibType10',
                                                             8: 'sibType11',
                                                             9: 'spare7',
                                                             10: 'spare6',
                                                             11: 'spare5',
                                                             12: 'spare4',
                                                             13: 'spare3',
                                                             14: 'spare2',
                                                             15: 'spare1',
                                                             16: '...'}},
                                     'SN-FieldLength': {'type': 'ENUMERATED',
                                                        'values': {0: 'size5',
                                                                   1: 'size10'}},
                                     'SPS-Config': {'members': [{'name': 'semiPersistSchedC-RNTI',
                                                                 'optional': True,
                                                                 'type': 'C-RNTI'},
                                                                {'name': 'sps-ConfigDL',
                                                                 'optional': True,
                                                                 'type': 'SPS-ConfigDL'},
                                                                {'name': 'sps-ConfigUL',
                                                                 'optional': True,
                                                                 'type': 'SPS-ConfigUL'}],
                                                    'type': 'SEQUENCE'},
                                     'SPS-ConfigDL': {'members': [{'name': 'release',
                                                                   'type': 'NULL'},
                                                                  {'members': [{'name': 'semiPersistSchedIntervalDL',
                                                                                'type': 'ENUMERATED',
                                                                                'values': {0: 'sf10',
                                                                                           1: 'sf20',
                                                                                           2: 'sf32',
                                                                                           3: 'sf40',
                                                                                           4: 'sf64',
                                                                                           5: 'sf80',
                                                                                           6: 'sf128',
                                                                                           7: 'sf160',
                                                                                           8: 'sf320',
                                                                                           9: 'sf640',
                                                                                           10: 'spare6',
                                                                                           11: 'spare5',
                                                                                           12: 'spare4',
                                                                                           13: 'spare3',
                                                                                           14: 'spare2',
                                                                                           15: 'spare1'}},
                                                                               {'name': 'numberOfConfSPS-Processes',
                                                                                'restricted-to': [(1,
                                                                                                   8)],
                                                                                'type': 'INTEGER'},
                                                                               {'name': 'n1-PUCCH-AN-PersistentList',
                                                                                'type': 'N1-PUCCH-AN-PersistentList'},
                                                                               '...'],
                                                                   'name': 'setup',
                                                                   'type': 'SEQUENCE'}],
                                                      'type': 'CHOICE'},
                                     'SPS-ConfigUL': {'members': [{'name': 'release',
                                                                   'type': 'NULL'},
                                                                  {'members': [{'name': 'semiPersistSchedIntervalUL',
                                                                                'type': 'ENUMERATED',
                                                                                'values': {0: 'sf10',
                                                                                           1: 'sf20',
                                                                                           2: 'sf32',
                                                                                           3: 'sf40',
                                                                                           4: 'sf64',
                                                                                           5: 'sf80',
                                                                                           6: 'sf128',
                                                                                           7: 'sf160',
                                                                                           8: 'sf320',
                                                                                           9: 'sf640',
                                                                                           10: 'spare6',
                                                                                           11: 'spare5',
                                                                                           12: 'spare4',
                                                                                           13: 'spare3',
                                                                                           14: 'spare2',
                                                                                           15: 'spare1'}},
                                                                               {'name': 'implicitReleaseAfter',
                                                                                'type': 'ENUMERATED',
                                                                                'values': {0: 'e2',
                                                                                           1: 'e3',
                                                                                           2: 'e4',
                                                                                           3: 'e8'}},
                                                                               {'members': [{'name': 'p0-NominalPUSCH-Persistent',
                                                                                             'restricted-to': [(-126,
                                                                                                                24)],
                                                                                             'type': 'INTEGER'},
                                                                                            {'name': 'p0-UE-PUSCH-Persistent',
                                                                                             'restricted-to': [(-8,
                                                                                                                7)],
                                                                                             'type': 'INTEGER'}],
                                                                                'name': 'p0-Persistent',
                                                                                'optional': True,
                                                                                'type': 'SEQUENCE'},
                                                                               {'name': 'twoIntervalsConfig',
                                                                                'optional': True,
                                                                                'type': 'ENUMERATED',
                                                                                'values': {0: 'true'}},
                                                                               '...'],
                                                                   'name': 'setup',
                                                                   'type': 'SEQUENCE'}],
                                                      'type': 'CHOICE'},
                                     'SRB-ToAddMod': {'members': [{'name': 'srb-Identity',
                                                                   'restricted-to': [(1,
                                                                                      2)],
                                                                   'type': 'INTEGER'},
                                                                  {'members': [{'name': 'explicitValue',
                                                                                'type': 'RLC-Config'},
                                                                               {'name': 'defaultValue',
                                                                                'type': 'NULL'}],
                                                                   'name': 'rlc-Config',
                                                                   'optional': True,
                                                                   'type': 'CHOICE'},
                                                                  {'members': [{'name': 'explicitValue',
                                                                                'type': 'LogicalChannelConfig'},
                                                                               {'name': 'defaultValue',
                                                                                'type': 'NULL'}],
                                                                   'name': 'logicalChannelConfig',
                                                                   'optional': True,
                                                                   'type': 'CHOICE'},
                                                                  '...'],
                                                      'type': 'SEQUENCE'},
                                     'SRB-ToAddModList': {'element': {'type': 'SRB-ToAddMod'},
                                                          'size': [(1, 2)],
                                                          'type': 'SEQUENCE '
                                                                  'OF'},
                                     'SchedulingInfo': {'members': [{'name': 'si-Periodicity',
                                                                     'type': 'ENUMERATED',
                                                                     'values': {0: 'rf8',
                                                                                1: 'rf16',
                                                                                2: 'rf32',
                                                                                3: 'rf64',
                                                                                4: 'rf128',
                                                                                5: 'rf256',
                                                                                6: 'rf512'}},
                                                                    {'name': 'sib-MappingInfo',
                                                                     'type': 'SIB-MappingInfo'}],
                                                        'type': 'SEQUENCE'},
                                     'SchedulingInfoList': {'element': {'type': 'SchedulingInfo'},
                                                            'size': [(1,
                                                                      'maxSI-Message')],
                                                            'type': 'SEQUENCE '
                                                                    'OF'},
                                     'SchedulingRequestConfig': {'members': [{'name': 'release',
                                                                              'type': 'NULL'},
                                                                             {'members': [{'name': 'sr-PUCCH-ResourceIndex',
                                                                                           'restricted-to': [(0,
                                                                                                              2047)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'sr-ConfigIndex',
                                                                                           'restricted-to': [(0,
                                                                                                              155)],
                                                                                           'type': 'INTEGER'},
                                                                                          {'name': 'dsr-TransMax',
                                                                                           'type': 'ENUMERATED',
                                                                                           'values': {0: 'n4',
                                                                                                      1: 'n8',
                                                                                                      2: 'n16',
                                                                                                      3: 'n32',
                                                                                                      4: 'n64',
                                                                                                      5: 'spare3',
                                                                                                      6: 'spare2',
                                                                                                      7: 'spare1'}}],
                                                                              'name': 'setup',
                                                                              'type': 'SEQUENCE'}],
                                                                 'type': 'CHOICE'},
                                     'SecondaryPreRegistrationZoneIdListHRPD': {'element': {'type': 'PreRegistrationZoneIdHRPD'},
                                                                                'size': [(1,
                                                                                          2)],
                                                                                'type': 'SEQUENCE '
                                                                                        'OF'},
                                     'SecurityAlgorithmConfig': {'members': [{'name': 'cipheringAlgorithm',
                                                                              'type': 'ENUMERATED',
                                                                              'values': {0: 'eea0',
                                                                                         1: 'eea1',
                                                                                         2: 'eea2',
                                                                                         3: 'spare5',
                                                                                         4: 'spare4',
                                                                                         5: 'spare3',
                                                                                         6: 'spare2',
                                                                                         7: 'spare1',
                                                                                         8: '...'}},
                                                                             {'name': 'integrityProtAlgorithm',
                                                                              'type': 'ENUMERATED',
                                                                              'values': {0: 'reserved',
                                                                                         1: 'eia1',
                                                                                         2: 'eia2',
                                                                                         3: 'spare5',
                                                                                         4: 'spare4',
                                                                                         5: 'spare3',
                                                                                         6: 'spare2',
                                                                                         7: 'spare1',
                                                                                         8: '...'}}],
                                                                 'type': 'SEQUENCE'},
                                     'SecurityConfigHO': {'members': [{'members': [{'members': [{'name': 'securityAlgorithmConfig',
                                                                                                 'optional': True,
                                                                                                 'type': 'SecurityAlgorithmConfig'},
                                                                                                {'name': 'keyChangeIndicator',
                                                                                                 'type': 'BOOLEAN'},
                                                                                                {'name': 'nextHopChainingCount',
                                                                                                 'type': 'NextHopChainingCount'}],
                                                                                    'name': 'intraLTE',
                                                                                    'type': 'SEQUENCE'},
                                                                                   {'members': [{'name': 'securityAlgorithmConfig',
                                                                                                 'type': 'SecurityAlgorithmConfig'},
                                                                                                {'name': 'nas-SecurityParamToEUTRA',
                                                                                                 'size': [6],
                                                                                                 'type': 'OCTET '
                                                                                                         'STRING'}],
                                                                                    'name': 'interRAT',
                                                                                    'type': 'SEQUENCE'}],
                                                                       'name': 'handoverType',
                                                                       'type': 'CHOICE'},
                                                                      '...'],
                                                          'type': 'SEQUENCE'},
                                     'SecurityConfigSMC': {'members': [{'name': 'securityAlgorithmConfig',
                                                                        'type': 'SecurityAlgorithmConfig'},
                                                                       '...'],
                                                           'type': 'SEQUENCE'},
                                     'SecurityModeCommand': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                         {'members': [{'members': [{'name': 'securityModeCommand-r8',
                                                                                                    'type': 'SecurityModeCommand-r8-IEs'},
                                                                                                   {'name': 'spare3',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare2',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare1',
                                                                                                    'type': 'NULL'}],
                                                                                       'name': 'c1',
                                                                                       'type': 'CHOICE'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'SecurityModeCommand-r8-IEs': {'members': [{'name': 'securityConfigSMC',
                                                                                 'type': 'SecurityConfigSMC'},
                                                                                {'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'SecurityModeComplete': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                           'type': 'RRC-TransactionIdentifier'},
                                                                          {'members': [{'name': 'securityModeComplete-r8',
                                                                                        'type': 'SecurityModeComplete-r8-IEs'},
                                                                                       {'members': [],
                                                                                        'name': 'criticalExtensionsFuture',
                                                                                        'type': 'SEQUENCE'}],
                                                                           'name': 'criticalExtensions',
                                                                           'type': 'CHOICE'}],
                                                              'type': 'SEQUENCE'},
                                     'SecurityModeComplete-r8-IEs': {'members': [{'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'SecurityModeFailure': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                         {'members': [{'name': 'securityModeFailure-r8',
                                                                                       'type': 'SecurityModeFailure-r8-IEs'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'SecurityModeFailure-r8-IEs': {'members': [{'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'ShortMAC-I': {'size': [16],
                                                    'type': 'BIT STRING'},
                                     'SoundingRS-UL-ConfigCommon': {'members': [{'name': 'release',
                                                                                 'type': 'NULL'},
                                                                                {'members': [{'name': 'srs-BandwidthConfig',
                                                                                              'type': 'ENUMERATED',
                                                                                              'values': {0: 'bw0',
                                                                                                         1: 'bw1',
                                                                                                         2: 'bw2',
                                                                                                         3: 'bw3',
                                                                                                         4: 'bw4',
                                                                                                         5: 'bw5',
                                                                                                         6: 'bw6',
                                                                                                         7: 'bw7'}},
                                                                                             {'name': 'srs-SubframeConfig',
                                                                                              'type': 'ENUMERATED',
                                                                                              'values': {0: 'sc0',
                                                                                                         1: 'sc1',
                                                                                                         2: 'sc2',
                                                                                                         3: 'sc3',
                                                                                                         4: 'sc4',
                                                                                                         5: 'sc5',
                                                                                                         6: 'sc6',
                                                                                                         7: 'sc7',
                                                                                                         8: 'sc8',
                                                                                                         9: 'sc9',
                                                                                                         10: 'sc10',
                                                                                                         11: 'sc11',
                                                                                                         12: 'sc12',
                                                                                                         13: 'sc13',
                                                                                                         14: 'sc14',
                                                                                                         15: 'sc15'}},
                                                                                             {'name': 'ackNackSRS-SimultaneousTransmission',
                                                                                              'type': 'BOOLEAN'},
                                                                                             {'name': 'srs-MaxUpPts',
                                                                                              'optional': True,
                                                                                              'type': 'ENUMERATED',
                                                                                              'values': {0: 'true'}}],
                                                                                 'name': 'setup',
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'CHOICE'},
                                     'SoundingRS-UL-ConfigDedicated': {'members': [{'name': 'release',
                                                                                    'type': 'NULL'},
                                                                                   {'members': [{'name': 'srs-Bandwidth',
                                                                                                 'type': 'ENUMERATED',
                                                                                                 'values': {0: 'bw0',
                                                                                                            1: 'bw1',
                                                                                                            2: 'bw2',
                                                                                                            3: 'bw3'}},
                                                                                                {'name': 'srs-HoppingBandwidth',
                                                                                                 'type': 'ENUMERATED',
                                                                                                 'values': {0: 'hbw0',
                                                                                                            1: 'hbw1',
                                                                                                            2: 'hbw2',
                                                                                                            3: 'hbw3'}},
                                                                                                {'name': 'freqDomainPosition',
                                                                                                 'restricted-to': [(0,
                                                                                                                    23)],
                                                                                                 'type': 'INTEGER'},
                                                                                                {'name': 'duration',
                                                                                                 'type': 'BOOLEAN'},
                                                                                                {'name': 'srs-ConfigIndex',
                                                                                                 'restricted-to': [(0,
                                                                                                                    1023)],
                                                                                                 'type': 'INTEGER'},
                                                                                                {'name': 'transmissionComb',
                                                                                                 'restricted-to': [(0,
                                                                                                                    1)],
                                                                                                 'type': 'INTEGER'},
                                                                                                {'name': 'cyclicShift',
                                                                                                 'type': 'ENUMERATED',
                                                                                                 'values': {0: 'cs0',
                                                                                                            1: 'cs1',
                                                                                                            2: 'cs2',
                                                                                                            3: 'cs3',
                                                                                                            4: 'cs4',
                                                                                                            5: 'cs5',
                                                                                                            6: 'cs6',
                                                                                                            7: 'cs7'}}],
                                                                                    'name': 'setup',
                                                                                    'type': 'SEQUENCE'}],
                                                                       'type': 'CHOICE'},
                                     'SpeedStateScaleFactors': {'members': [{'name': 'sf-Medium',
                                                                             'type': 'ENUMERATED',
                                                                             'values': {0: 'oDot25',
                                                                                        1: 'oDot5',
                                                                                        2: 'oDot75',
                                                                                        3: 'lDot0'}},
                                                                            {'name': 'sf-High',
                                                                             'type': 'ENUMERATED',
                                                                             'values': {0: 'oDot25',
                                                                                        1: 'oDot5',
                                                                                        2: 'oDot75',
                                                                                        3: 'lDot0'}}],
                                                                'type': 'SEQUENCE'},
                                     'SupportedBandEUTRA': {'members': [{'name': 'bandEUTRA',
                                                                         'restricted-to': [(1,
                                                                                            64)],
                                                                         'type': 'INTEGER'},
                                                                        {'name': 'halfDuplex',
                                                                         'type': 'BOOLEAN'}],
                                                            'type': 'SEQUENCE'},
                                     'SupportedBandGERAN': {'type': 'ENUMERATED',
                                                            'values': {0: 'gsm450',
                                                                       1: 'gsm480',
                                                                       2: 'gsm710',
                                                                       3: 'gsm750',
                                                                       4: 'gsm810',
                                                                       5: 'gsm850',
                                                                       6: 'gsm900P',
                                                                       7: 'gsm900E',
                                                                       8: 'gsm900R',
                                                                       9: 'gsm1800',
                                                                       10: 'gsm1900',
                                                                       11: 'spare5',
                                                                       12: 'spare4',
                                                                       13: 'spare3',
                                                                       14: 'spare2',
                                                                       15: 'spare1',
                                                                       16: '...'}},
                                     'SupportedBandList1XRTT': {'element': {'type': 'BandclassCDMA2000'},
                                                                'size': [(1,
                                                                          'maxCDMA-BandClass')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'SupportedBandListEUTRA': {'element': {'type': 'SupportedBandEUTRA'},
                                                                'size': [(1,
                                                                          'maxBands')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'SupportedBandListGERAN': {'element': {'type': 'SupportedBandGERAN'},
                                                                'size': [(1,
                                                                          'maxBands')],
                                                                'type': 'SEQUENCE '
                                                                        'OF'},
                                     'SupportedBandListHRPD': {'element': {'type': 'BandclassCDMA2000'},
                                                               'size': [(1,
                                                                         'maxCDMA-BandClass')],
                                                               'type': 'SEQUENCE '
                                                                       'OF'},
                                     'SupportedBandListUTRA-FDD': {'element': {'type': 'SupportedBandUTRA-FDD'},
                                                                   'size': [(1,
                                                                             'maxBands')],
                                                                   'type': 'SEQUENCE '
                                                                           'OF'},
                                     'SupportedBandListUTRA-TDD128': {'element': {'type': 'SupportedBandUTRA-TDD128'},
                                                                      'size': [(1,
                                                                                'maxBands')],
                                                                      'type': 'SEQUENCE '
                                                                              'OF'},
                                     'SupportedBandListUTRA-TDD384': {'element': {'type': 'SupportedBandUTRA-TDD384'},
                                                                      'size': [(1,
                                                                                'maxBands')],
                                                                      'type': 'SEQUENCE '
                                                                              'OF'},
                                     'SupportedBandListUTRA-TDD768': {'element': {'type': 'SupportedBandUTRA-TDD768'},
                                                                      'size': [(1,
                                                                                'maxBands')],
                                                                      'type': 'SEQUENCE '
                                                                              'OF'},
                                     'SupportedBandUTRA-FDD': {'type': 'ENUMERATED',
                                                               'values': {0: 'bandI',
                                                                          1: 'bandII',
                                                                          2: 'bandIII',
                                                                          3: 'bandIV',
                                                                          4: 'bandV',
                                                                          5: 'bandVI',
                                                                          6: 'bandVII',
                                                                          7: 'bandVIII',
                                                                          8: 'bandIX',
                                                                          9: 'bandX',
                                                                          10: 'bandXI',
                                                                          11: 'bandXII',
                                                                          12: 'bandXIII',
                                                                          13: 'bandXIV',
                                                                          14: 'bandXV',
                                                                          15: 'bandXVI',
                                                                          16: '...',
                                                                          17: 'bandXVII-8a0',
                                                                          18: 'bandXVIII-8a0',
                                                                          19: 'bandXIX-8a0',
                                                                          20: 'bandXX-8a0',
                                                                          21: 'bandXXI-8a0',
                                                                          22: 'bandXXII-8a0',
                                                                          23: 'bandXXIII-8a0',
                                                                          24: 'bandXXIV-8a0',
                                                                          25: 'bandXXV-8a0',
                                                                          26: 'bandXXVI-8a0',
                                                                          27: 'bandXXVII-8a0',
                                                                          28: 'bandXXVIII-8a0',
                                                                          29: 'bandXXIX-8a0',
                                                                          30: 'bandXXX-8a0',
                                                                          31: 'bandXXXI-8a0',
                                                                          32: 'bandXXXII-8a0'}},
                                     'SupportedBandUTRA-TDD128': {'type': 'ENUMERATED',
                                                                  'values': {0: 'a',
                                                                             1: 'b',
                                                                             2: 'c',
                                                                             3: 'd',
                                                                             4: 'e',
                                                                             5: 'f',
                                                                             6: 'g',
                                                                             7: 'h',
                                                                             8: 'i',
                                                                             9: 'j',
                                                                             10: 'k',
                                                                             11: 'l',
                                                                             12: 'm',
                                                                             13: 'n',
                                                                             14: 'o',
                                                                             15: 'p',
                                                                             16: '...'}},
                                     'SupportedBandUTRA-TDD384': {'type': 'ENUMERATED',
                                                                  'values': {0: 'a',
                                                                             1: 'b',
                                                                             2: 'c',
                                                                             3: 'd',
                                                                             4: 'e',
                                                                             5: 'f',
                                                                             6: 'g',
                                                                             7: 'h',
                                                                             8: 'i',
                                                                             9: 'j',
                                                                             10: 'k',
                                                                             11: 'l',
                                                                             12: 'm',
                                                                             13: 'n',
                                                                             14: 'o',
                                                                             15: 'p',
                                                                             16: '...'}},
                                     'SupportedBandUTRA-TDD768': {'type': 'ENUMERATED',
                                                                  'values': {0: 'a',
                                                                             1: 'b',
                                                                             2: 'c',
                                                                             3: 'd',
                                                                             4: 'e',
                                                                             5: 'f',
                                                                             6: 'g',
                                                                             7: 'h',
                                                                             8: 'i',
                                                                             9: 'j',
                                                                             10: 'k',
                                                                             11: 'l',
                                                                             12: 'm',
                                                                             13: 'n',
                                                                             14: 'o',
                                                                             15: 'p',
                                                                             16: '...'}},
                                     'SystemInfoListGERAN': {'element': {'size': [(1,
                                                                                   23)],
                                                                         'type': 'OCTET '
                                                                                 'STRING'},
                                                             'size': [(1,
                                                                       'maxGERAN-SI')],
                                                             'type': 'SEQUENCE '
                                                                     'OF'},
                                     'SystemInformation': {'members': [{'members': [{'name': 'systemInformation-r8',
                                                                                     'type': 'SystemInformation-r8-IEs'},
                                                                                    {'members': [],
                                                                                     'name': 'criticalExtensionsFuture',
                                                                                     'type': 'SEQUENCE'}],
                                                                        'name': 'criticalExtensions',
                                                                        'type': 'CHOICE'}],
                                                           'type': 'SEQUENCE'},
                                     'SystemInformation-r8-IEs': {'members': [{'element': {'members': [{'name': 'sib2',
                                                                                                        'type': 'SystemInformationBlockType2'},
                                                                                                       {'name': 'sib3',
                                                                                                        'type': 'SystemInformationBlockType3'},
                                                                                                       {'name': 'sib4',
                                                                                                        'type': 'SystemInformationBlockType4'},
                                                                                                       {'name': 'sib5',
                                                                                                        'type': 'SystemInformationBlockType5'},
                                                                                                       {'name': 'sib6',
                                                                                                        'type': 'SystemInformationBlockType6'},
                                                                                                       {'name': 'sib7',
                                                                                                        'type': 'SystemInformationBlockType7'},
                                                                                                       {'name': 'sib8',
                                                                                                        'type': 'SystemInformationBlockType8'},
                                                                                                       {'name': 'sib9',
                                                                                                        'type': 'SystemInformationBlockType9'},
                                                                                                       {'name': 'sib10',
                                                                                                        'type': 'SystemInformationBlockType10'},
                                                                                                       {'name': 'sib11',
                                                                                                        'type': 'SystemInformationBlockType11'},
                                                                                                       '...'],
                                                                                           'type': 'CHOICE'},
                                                                               'name': 'sib-TypeAndInfo',
                                                                               'size': [(1,
                                                                                         'maxSIB')],
                                                                               'type': 'SEQUENCE '
                                                                                       'OF'},
                                                                              {'members': [],
                                                                               'name': 'nonCriticalExtension',
                                                                               'optional': True,
                                                                               'type': 'SEQUENCE'}],
                                                                  'type': 'SEQUENCE'},
                                     'SystemInformationBlockType1': {'members': [{'members': [{'name': 'plmn-IdentityList',
                                                                                               'type': 'PLMN-IdentityList'},
                                                                                              {'name': 'trackingAreaCode',
                                                                                               'type': 'TrackingAreaCode'},
                                                                                              {'name': 'cellIdentity',
                                                                                               'type': 'CellIdentity'},
                                                                                              {'name': 'cellBarred',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': {0: 'barred',
                                                                                                          1: 'notBarred'}},
                                                                                              {'name': 'intraFreqReselection',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': {0: 'allowed',
                                                                                                          1: 'notAllowed'}},
                                                                                              {'name': 'csg-Indication',
                                                                                               'type': 'BOOLEAN'},
                                                                                              {'name': 'csg-Identity',
                                                                                               'optional': True,
                                                                                               'size': [27],
                                                                                               'type': 'BIT '
                                                                                                       'STRING'}],
                                                                                  'name': 'cellAccessRelatedInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 'q-RxLevMin',
                                                                                               'type': 'Q-RxLevMin'},
                                                                                              {'name': 'q-RxLevMinOffset',
                                                                                               'optional': True,
                                                                                               'restricted-to': [(1,
                                                                                                                  8)],
                                                                                               'type': 'INTEGER'}],
                                                                                  'name': 'cellSelectionInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'name': 'p-Max',
                                                                                  'optional': True,
                                                                                  'type': 'P-Max'},
                                                                                 {'name': 'freqBandIndicator',
                                                                                  'restricted-to': [(1,
                                                                                                     64)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'schedulingInfoList',
                                                                                  'type': 'SchedulingInfoList'},
                                                                                 {'name': 'tdd-Config',
                                                                                  'optional': True,
                                                                                  'type': 'TDD-Config'},
                                                                                 {'name': 'si-WindowLength',
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': {0: 'ms1',
                                                                                             1: 'ms2',
                                                                                             2: 'ms5',
                                                                                             3: 'ms10',
                                                                                             4: 'ms15',
                                                                                             5: 'ms20',
                                                                                             6: 'ms40'}},
                                                                                 {'name': 'systemInfoValueTag',
                                                                                  'restricted-to': [(0,
                                                                                                     31)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'members': [],
                                                                                  'name': 'nonCriticalExtension',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'}],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType10': {'members': [{'name': 'messageIdentifier',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'serialNumber',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'warningType',
                                                                                   'size': [2],
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  {'name': 'warningSecurityInfo',
                                                                                   'optional': True,
                                                                                   'size': [50],
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  '...'],
                                                                      'type': 'SEQUENCE'},
                                     'SystemInformationBlockType11': {'members': [{'name': 'messageIdentifier',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'serialNumber',
                                                                                   'size': [16],
                                                                                   'type': 'BIT '
                                                                                           'STRING'},
                                                                                  {'name': 'warningMessageSegmentType',
                                                                                   'type': 'ENUMERATED',
                                                                                   'values': {0: 'notLastSegment',
                                                                                              1: 'lastSegment'}},
                                                                                  {'name': 'warningMessageSegmentNumber',
                                                                                   'restricted-to': [(0,
                                                                                                      63)],
                                                                                   'type': 'INTEGER'},
                                                                                  {'name': 'warningMessageSegment',
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  {'name': 'dataCodingScheme',
                                                                                   'optional': True,
                                                                                   'size': [1],
                                                                                   'type': 'OCTET '
                                                                                           'STRING'},
                                                                                  '...'],
                                                                      'type': 'SEQUENCE'},
                                     'SystemInformationBlockType2': {'members': [{'members': [{'name': 'ac-BarringForEmergency',
                                                                                               'type': 'BOOLEAN'},
                                                                                              {'name': 'ac-BarringForMO-Signalling',
                                                                                               'optional': True,
                                                                                               'type': 'AC-BarringConfig'},
                                                                                              {'name': 'ac-BarringForMO-Data',
                                                                                               'optional': True,
                                                                                               'type': 'AC-BarringConfig'}],
                                                                                  'name': 'ac-BarringInfo',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'name': 'radioResourceConfigCommon',
                                                                                  'type': 'RadioResourceConfigCommonSIB'},
                                                                                 {'name': 'ue-TimersAndConstants',
                                                                                  'type': 'UE-TimersAndConstants'},
                                                                                 {'members': [{'name': 'ul-CarrierFreq',
                                                                                               'optional': True,
                                                                                               'type': 'ARFCN-ValueEUTRA'},
                                                                                              {'name': 'ul-Bandwidth',
                                                                                               'optional': True,
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': {0: 'n6',
                                                                                                          1: 'n15',
                                                                                                          2: 'n25',
                                                                                                          3: 'n50',
                                                                                                          4: 'n75',
                                                                                                          5: 'n100'}},
                                                                                              {'name': 'additionalSpectrumEmission',
                                                                                               'type': 'AdditionalSpectrumEmission'}],
                                                                                  'name': 'freqInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'name': 'mbsfn-SubframeConfigList',
                                                                                  'optional': True,
                                                                                  'type': 'MBSFN-SubframeConfigList'},
                                                                                 {'name': 'timeAlignmentTimerCommon',
                                                                                  'type': 'TimeAlignmentTimer'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType3': {'members': [{'members': [{'name': 'q-Hyst',
                                                                                               'type': 'ENUMERATED',
                                                                                               'values': {0: 'dB0',
                                                                                                          1: 'dB1',
                                                                                                          2: 'dB2',
                                                                                                          3: 'dB3',
                                                                                                          4: 'dB4',
                                                                                                          5: 'dB5',
                                                                                                          6: 'dB6',
                                                                                                          7: 'dB8',
                                                                                                          8: 'dB10',
                                                                                                          9: 'dB12',
                                                                                                          10: 'dB14',
                                                                                                          11: 'dB16',
                                                                                                          12: 'dB18',
                                                                                                          13: 'dB20',
                                                                                                          14: 'dB22',
                                                                                                          15: 'dB24'}},
                                                                                              {'members': [{'name': 'mobilityStateParameters',
                                                                                                            'type': 'MobilityStateParameters'},
                                                                                                           {'members': [{'name': 'sf-Medium',
                                                                                                                         'type': 'ENUMERATED',
                                                                                                                         'values': {0: 'dB-6',
                                                                                                                                    1: 'dB-4',
                                                                                                                                    2: 'dB-2',
                                                                                                                                    3: 'dB0'}},
                                                                                                                        {'name': 'sf-High',
                                                                                                                         'type': 'ENUMERATED',
                                                                                                                         'values': {0: 'dB-6',
                                                                                                                                    1: 'dB-4',
                                                                                                                                    2: 'dB-2',
                                                                                                                                    3: 'dB0'}}],
                                                                                                            'name': 'q-HystSF',
                                                                                                            'type': 'SEQUENCE'}],
                                                                                               'name': 'speedStateReselectionPars',
                                                                                               'optional': True,
                                                                                               'type': 'SEQUENCE'}],
                                                                                  'name': 'cellReselectionInfoCommon',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 's-NonIntraSearch',
                                                                                               'optional': True,
                                                                                               'type': 'ReselectionThreshold'},
                                                                                              {'name': 'threshServingLow',
                                                                                               'type': 'ReselectionThreshold'},
                                                                                              {'name': 'cellReselectionPriority',
                                                                                               'type': 'CellReselectionPriority'}],
                                                                                  'name': 'cellReselectionServingFreqInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 'q-RxLevMin',
                                                                                               'type': 'Q-RxLevMin'},
                                                                                              {'name': 'p-Max',
                                                                                               'optional': True,
                                                                                               'type': 'P-Max'},
                                                                                              {'name': 's-IntraSearch',
                                                                                               'optional': True,
                                                                                               'type': 'ReselectionThreshold'},
                                                                                              {'name': 'allowedMeasBandwidth',
                                                                                               'optional': True,
                                                                                               'type': 'AllowedMeasBandwidth'},
                                                                                              {'name': 'presenceAntennaPort1',
                                                                                               'type': 'PresenceAntennaPort1'},
                                                                                              {'name': 'neighCellConfig',
                                                                                               'type': 'NeighCellConfig'},
                                                                                              {'name': 't-ReselectionEUTRA',
                                                                                               'type': 'T-Reselection'},
                                                                                              {'name': 't-ReselectionEUTRA-SF',
                                                                                               'optional': True,
                                                                                               'type': 'SpeedStateScaleFactors'}],
                                                                                  'name': 'intraFreqCellReselectionInfo',
                                                                                  'type': 'SEQUENCE'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType4': {'members': [{'name': 'intraFreqNeighCellList',
                                                                                  'optional': True,
                                                                                  'type': 'IntraFreqNeighCellList'},
                                                                                 {'name': 'intraFreqBlackCellList',
                                                                                  'optional': True,
                                                                                  'type': 'IntraFreqBlackCellList'},
                                                                                 {'name': 'csg-PhysCellIdRange',
                                                                                  'optional': True,
                                                                                  'type': 'PhysCellIdRange'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType5': {'members': [{'name': 'interFreqCarrierFreqList',
                                                                                  'type': 'InterFreqCarrierFreqList'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType6': {'members': [{'name': 'carrierFreqListUTRA-FDD',
                                                                                  'optional': True,
                                                                                  'type': 'CarrierFreqListUTRA-FDD'},
                                                                                 {'name': 'carrierFreqListUTRA-TDD',
                                                                                  'optional': True,
                                                                                  'type': 'CarrierFreqListUTRA-TDD'},
                                                                                 {'name': 't-ReselectionUTRA',
                                                                                  'type': 'T-Reselection'},
                                                                                 {'name': 't-ReselectionUTRA-SF',
                                                                                  'optional': True,
                                                                                  'type': 'SpeedStateScaleFactors'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType7': {'members': [{'name': 't-ReselectionGERAN',
                                                                                  'type': 'T-Reselection'},
                                                                                 {'name': 't-ReselectionGERAN-SF',
                                                                                  'optional': True,
                                                                                  'type': 'SpeedStateScaleFactors'},
                                                                                 {'name': 'carrierFreqsInfoList',
                                                                                  'optional': True,
                                                                                  'type': 'CarrierFreqsInfoListGERAN'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType8': {'members': [{'name': 'systemTimeInfo',
                                                                                  'optional': True,
                                                                                  'type': 'SystemTimeInfoCDMA2000'},
                                                                                 {'name': 'searchWindowSize',
                                                                                  'optional': True,
                                                                                  'restricted-to': [(0,
                                                                                                     15)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'members': [{'name': 'preRegistrationInfoHRPD',
                                                                                               'type': 'PreRegistrationInfoHRPD'},
                                                                                              {'name': 'cellReselectionParametersHRPD',
                                                                                               'optional': True,
                                                                                               'type': 'CellReselectionParametersCDMA2000'}],
                                                                                  'name': 'parametersHRPD',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'},
                                                                                 {'members': [{'name': 'csfb-RegistrationParam1XRTT',
                                                                                               'optional': True,
                                                                                               'type': 'CSFB-RegistrationParam1XRTT'},
                                                                                              {'name': 'longCodeState1XRTT',
                                                                                               'optional': True,
                                                                                               'size': [42],
                                                                                               'type': 'BIT '
                                                                                                       'STRING'},
                                                                                              {'name': 'cellReselectionParameters1XRTT',
                                                                                               'optional': True,
                                                                                               'type': 'CellReselectionParametersCDMA2000'}],
                                                                                  'name': 'parameters1XRTT',
                                                                                  'optional': True,
                                                                                  'type': 'SEQUENCE'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemInformationBlockType9': {'members': [{'name': 'hnb-Name',
                                                                                  'optional': True,
                                                                                  'size': [(1,
                                                                                            48)],
                                                                                  'type': 'OCTET '
                                                                                          'STRING'},
                                                                                 '...'],
                                                                     'type': 'SEQUENCE'},
                                     'SystemTimeInfoCDMA2000': {'members': [{'name': 'cdma-EUTRA-Synchronisation',
                                                                             'type': 'BOOLEAN'},
                                                                            {'members': [{'name': 'synchronousSystemTime',
                                                                                          'size': [39],
                                                                                          'type': 'BIT '
                                                                                                  'STRING'},
                                                                                         {'name': 'asynchronousSystemTime',
                                                                                          'size': [49],
                                                                                          'type': 'BIT '
                                                                                                  'STRING'}],
                                                                             'name': 'cdma-SystemTime',
                                                                             'type': 'CHOICE'}],
                                                                'type': 'SEQUENCE'},
                                     'T-PollRetransmit': {'type': 'ENUMERATED',
                                                          'values': {0: 'ms5',
                                                                     1: 'ms10',
                                                                     2: 'ms15',
                                                                     3: 'ms20',
                                                                     4: 'ms25',
                                                                     5: 'ms30',
                                                                     6: 'ms35',
                                                                     7: 'ms40',
                                                                     8: 'ms45',
                                                                     9: 'ms50',
                                                                     10: 'ms55',
                                                                     11: 'ms60',
                                                                     12: 'ms65',
                                                                     13: 'ms70',
                                                                     14: 'ms75',
                                                                     15: 'ms80',
                                                                     16: 'ms85',
                                                                     17: 'ms90',
                                                                     18: 'ms95',
                                                                     19: 'ms100',
                                                                     20: 'ms105',
                                                                     21: 'ms110',
                                                                     22: 'ms115',
                                                                     23: 'ms120',
                                                                     24: 'ms125',
                                                                     25: 'ms130',
                                                                     26: 'ms135',
                                                                     27: 'ms140',
                                                                     28: 'ms145',
                                                                     29: 'ms150',
                                                                     30: 'ms155',
                                                                     31: 'ms160',
                                                                     32: 'ms165',
                                                                     33: 'ms170',
                                                                     34: 'ms175',
                                                                     35: 'ms180',
                                                                     36: 'ms185',
                                                                     37: 'ms190',
                                                                     38: 'ms195',
                                                                     39: 'ms200',
                                                                     40: 'ms205',
                                                                     41: 'ms210',
                                                                     42: 'ms215',
                                                                     43: 'ms220',
                                                                     44: 'ms225',
                                                                     45: 'ms230',
                                                                     46: 'ms235',
                                                                     47: 'ms240',
                                                                     48: 'ms245',
                                                                     49: 'ms250',
                                                                     50: 'ms300',
                                                                     51: 'ms350',
                                                                     52: 'ms400',
                                                                     53: 'ms450',
                                                                     54: 'ms500',
                                                                     55: 'spare9',
                                                                     56: 'spare8',
                                                                     57: 'spare7',
                                                                     58: 'spare6',
                                                                     59: 'spare5',
                                                                     60: 'spare4',
                                                                     61: 'spare3',
                                                                     62: 'spare2',
                                                                     63: 'spare1'}},
                                     'T-Reordering': {'type': 'ENUMERATED',
                                                      'values': {0: 'ms0',
                                                                 1: 'ms5',
                                                                 2: 'ms10',
                                                                 3: 'ms15',
                                                                 4: 'ms20',
                                                                 5: 'ms25',
                                                                 6: 'ms30',
                                                                 7: 'ms35',
                                                                 8: 'ms40',
                                                                 9: 'ms45',
                                                                 10: 'ms50',
                                                                 11: 'ms55',
                                                                 12: 'ms60',
                                                                 13: 'ms65',
                                                                 14: 'ms70',
                                                                 15: 'ms75',
                                                                 16: 'ms80',
                                                                 17: 'ms85',
                                                                 18: 'ms90',
                                                                 19: 'ms95',
                                                                 20: 'ms100',
                                                                 21: 'ms110',
                                                                 22: 'ms120',
                                                                 23: 'ms130',
                                                                 24: 'ms140',
                                                                 25: 'ms150',
                                                                 26: 'ms160',
                                                                 27: 'ms170',
                                                                 28: 'ms180',
                                                                 29: 'ms190',
                                                                 30: 'ms200',
                                                                 31: 'spare1'}},
                                     'T-Reselection': {'restricted-to': [(0,
                                                                          7)],
                                                       'type': 'INTEGER'},
                                     'T-StatusProhibit': {'type': 'ENUMERATED',
                                                          'values': {0: 'ms0',
                                                                     1: 'ms5',
                                                                     2: 'ms10',
                                                                     3: 'ms15',
                                                                     4: 'ms20',
                                                                     5: 'ms25',
                                                                     6: 'ms30',
                                                                     7: 'ms35',
                                                                     8: 'ms40',
                                                                     9: 'ms45',
                                                                     10: 'ms50',
                                                                     11: 'ms55',
                                                                     12: 'ms60',
                                                                     13: 'ms65',
                                                                     14: 'ms70',
                                                                     15: 'ms75',
                                                                     16: 'ms80',
                                                                     17: 'ms85',
                                                                     18: 'ms90',
                                                                     19: 'ms95',
                                                                     20: 'ms100',
                                                                     21: 'ms105',
                                                                     22: 'ms110',
                                                                     23: 'ms115',
                                                                     24: 'ms120',
                                                                     25: 'ms125',
                                                                     26: 'ms130',
                                                                     27: 'ms135',
                                                                     28: 'ms140',
                                                                     29: 'ms145',
                                                                     30: 'ms150',
                                                                     31: 'ms155',
                                                                     32: 'ms160',
                                                                     33: 'ms165',
                                                                     34: 'ms170',
                                                                     35: 'ms175',
                                                                     36: 'ms180',
                                                                     37: 'ms185',
                                                                     38: 'ms190',
                                                                     39: 'ms195',
                                                                     40: 'ms200',
                                                                     41: 'ms205',
                                                                     42: 'ms210',
                                                                     43: 'ms215',
                                                                     44: 'ms220',
                                                                     45: 'ms225',
                                                                     46: 'ms230',
                                                                     47: 'ms235',
                                                                     48: 'ms240',
                                                                     49: 'ms245',
                                                                     50: 'ms250',
                                                                     51: 'ms300',
                                                                     52: 'ms350',
                                                                     53: 'ms400',
                                                                     54: 'ms450',
                                                                     55: 'ms500',
                                                                     56: 'spare8',
                                                                     57: 'spare7',
                                                                     58: 'spare6',
                                                                     59: 'spare5',
                                                                     60: 'spare4',
                                                                     61: 'spare3',
                                                                     62: 'spare2',
                                                                     63: 'spare1'}},
                                     'TDD-Config': {'members': [{'name': 'subframeAssignment',
                                                                 'type': 'ENUMERATED',
                                                                 'values': {0: 'sa0',
                                                                            1: 'sa1',
                                                                            2: 'sa2',
                                                                            3: 'sa3',
                                                                            4: 'sa4',
                                                                            5: 'sa5',
                                                                            6: 'sa6'}},
                                                                {'name': 'specialSubframePatterns',
                                                                 'type': 'ENUMERATED',
                                                                 'values': {0: 'ssp0',
                                                                            1: 'ssp1',
                                                                            2: 'ssp2',
                                                                            3: 'ssp3',
                                                                            4: 'ssp4',
                                                                            5: 'ssp5',
                                                                            6: 'ssp6',
                                                                            7: 'ssp7',
                                                                            8: 'ssp8'}}],
                                                    'type': 'SEQUENCE'},
                                     'TPC-Index': {'members': [{'name': 'indexOfFormat3',
                                                                'restricted-to': [(1,
                                                                                   15)],
                                                                'type': 'INTEGER'},
                                                               {'name': 'indexOfFormat3A',
                                                                'restricted-to': [(1,
                                                                                   31)],
                                                                'type': 'INTEGER'}],
                                                   'type': 'CHOICE'},
                                     'TPC-PDCCH-Config': {'members': [{'name': 'release',
                                                                       'type': 'NULL'},
                                                                      {'members': [{'name': 'tpc-RNTI',
                                                                                    'size': [16],
                                                                                    'type': 'BIT '
                                                                                            'STRING'},
                                                                                   {'name': 'tpc-Index',
                                                                                    'type': 'TPC-Index'}],
                                                                       'name': 'setup',
                                                                       'type': 'SEQUENCE'}],
                                                          'type': 'CHOICE'},
                                     'ThresholdCDMA2000': {'restricted-to': [(0,
                                                                              63)],
                                                           'type': 'INTEGER'},
                                     'ThresholdEUTRA': {'members': [{'name': 'threshold-RSRP',
                                                                     'type': 'RSRP-Range'},
                                                                    {'name': 'threshold-RSRQ',
                                                                     'type': 'RSRQ-Range'}],
                                                        'type': 'CHOICE'},
                                     'ThresholdGERAN': {'restricted-to': [(0,
                                                                           63)],
                                                        'type': 'INTEGER'},
                                     'ThresholdUTRA': {'members': [{'name': 'utra-RSCP',
                                                                    'restricted-to': [(-5,
                                                                                       91)],
                                                                    'type': 'INTEGER'},
                                                                   {'name': 'utra-EcN0',
                                                                    'restricted-to': [(0,
                                                                                       49)],
                                                                    'type': 'INTEGER'}],
                                                       'type': 'CHOICE'},
                                     'TimeAlignmentTimer': {'type': 'ENUMERATED',
                                                            'values': {0: 'sf500',
                                                                       1: 'sf750',
                                                                       2: 'sf1280',
                                                                       3: 'sf1920',
                                                                       4: 'sf2560',
                                                                       5: 'sf5120',
                                                                       6: 'sf10240',
                                                                       7: 'infinity'}},
                                     'TimeToTrigger': {'type': 'ENUMERATED',
                                                       'values': {0: 'ms0',
                                                                  1: 'ms40',
                                                                  2: 'ms64',
                                                                  3: 'ms80',
                                                                  4: 'ms100',
                                                                  5: 'ms128',
                                                                  6: 'ms160',
                                                                  7: 'ms256',
                                                                  8: 'ms320',
                                                                  9: 'ms480',
                                                                  10: 'ms512',
                                                                  11: 'ms640',
                                                                  12: 'ms1024',
                                                                  13: 'ms1280',
                                                                  14: 'ms2560',
                                                                  15: 'ms5120'}},
                                     'TrackingAreaCode': {'size': [16],
                                                          'type': 'BIT STRING'},
                                     'UE-CapabilityRAT-Container': {'members': [{'name': 'rat-Type',
                                                                                 'type': 'RAT-Type'},
                                                                                {'name': 'ueCapabilityRAT-Container',
                                                                                 'type': 'OCTET '
                                                                                         'STRING'}],
                                                                    'type': 'SEQUENCE'},
                                     'UE-CapabilityRAT-ContainerList': {'element': {'type': 'UE-CapabilityRAT-Container'},
                                                                        'size': [(0,
                                                                                  'maxRAT-Capabilities')],
                                                                        'type': 'SEQUENCE '
                                                                                'OF'},
                                     'UE-CapabilityRequest': {'element': {'type': 'RAT-Type'},
                                                              'size': [(1,
                                                                        'maxRAT-Capabilities')],
                                                              'type': 'SEQUENCE '
                                                                      'OF'},
                                     'UE-EUTRA-Capability': {'members': [{'name': 'accessStratumRelease',
                                                                          'type': 'AccessStratumRelease'},
                                                                         {'name': 'ue-Category',
                                                                          'restricted-to': [(1,
                                                                                             5)],
                                                                          'type': 'INTEGER'},
                                                                         {'name': 'pdcp-Parameters',
                                                                          'type': 'PDCP-Parameters'},
                                                                         {'name': 'phyLayerParameters',
                                                                          'type': 'PhyLayerParameters'},
                                                                         {'name': 'rf-Parameters',
                                                                          'type': 'RF-Parameters'},
                                                                         {'name': 'measParameters',
                                                                          'type': 'MeasParameters'},
                                                                         {'name': 'featureGroupIndicators',
                                                                          'optional': True,
                                                                          'size': [32],
                                                                          'type': 'BIT '
                                                                                  'STRING'},
                                                                         {'members': [{'name': 'utraFDD',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-FDD'},
                                                                                      {'name': 'utraTDD128',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-TDD128'},
                                                                                      {'name': 'utraTDD384',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-TDD384'},
                                                                                      {'name': 'utraTDD768',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersUTRA-TDD768'},
                                                                                      {'name': 'geran',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersGERAN'},
                                                                                      {'name': 'cdma2000-HRPD',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersCDMA2000-HRPD'},
                                                                                      {'name': 'cdma2000-1xRTT',
                                                                                       'optional': True,
                                                                                       'type': 'IRAT-ParametersCDMA2000-1XRTT'}],
                                                                          'name': 'interRAT-Parameters',
                                                                          'type': 'SEQUENCE'},
                                                                         {'members': [],
                                                                          'name': 'nonCriticalExtension',
                                                                          'optional': True,
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'SEQUENCE'},
                                     'UE-TimersAndConstants': {'members': [{'name': 't300',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'ms100',
                                                                                       1: 'ms200',
                                                                                       2: 'ms300',
                                                                                       3: 'ms400',
                                                                                       4: 'ms600',
                                                                                       5: 'ms1000',
                                                                                       6: 'ms1500',
                                                                                       7: 'ms2000'}},
                                                                           {'name': 't301',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'ms100',
                                                                                       1: 'ms200',
                                                                                       2: 'ms300',
                                                                                       3: 'ms400',
                                                                                       4: 'ms600',
                                                                                       5: 'ms1000',
                                                                                       6: 'ms1500',
                                                                                       7: 'ms2000'}},
                                                                           {'name': 't310',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'ms0',
                                                                                       1: 'ms50',
                                                                                       2: 'ms100',
                                                                                       3: 'ms200',
                                                                                       4: 'ms500',
                                                                                       5: 'ms1000',
                                                                                       6: 'ms2000'}},
                                                                           {'name': 'n310',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'n1',
                                                                                       1: 'n2',
                                                                                       2: 'n3',
                                                                                       3: 'n4',
                                                                                       4: 'n6',
                                                                                       5: 'n8',
                                                                                       6: 'n10',
                                                                                       7: 'n20'}},
                                                                           {'name': 't311',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'ms1000',
                                                                                       1: 'ms3000',
                                                                                       2: 'ms5000',
                                                                                       3: 'ms10000',
                                                                                       4: 'ms15000',
                                                                                       5: 'ms20000',
                                                                                       6: 'ms30000'}},
                                                                           {'name': 'n311',
                                                                            'type': 'ENUMERATED',
                                                                            'values': {0: 'n1',
                                                                                       1: 'n2',
                                                                                       2: 'n3',
                                                                                       3: 'n4',
                                                                                       4: 'n5',
                                                                                       5: 'n6',
                                                                                       6: 'n8',
                                                                                       7: 'n10'}},
                                                                           '...'],
                                                               'type': 'SEQUENCE'},
                                     'UECapabilityEnquiry': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                          'type': 'RRC-TransactionIdentifier'},
                                                                         {'members': [{'members': [{'name': 'ueCapabilityEnquiry-r8',
                                                                                                    'type': 'UECapabilityEnquiry-r8-IEs'},
                                                                                                   {'name': 'spare3',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare2',
                                                                                                    'type': 'NULL'},
                                                                                                   {'name': 'spare1',
                                                                                                    'type': 'NULL'}],
                                                                                       'name': 'c1',
                                                                                       'type': 'CHOICE'},
                                                                                      {'members': [],
                                                                                       'name': 'criticalExtensionsFuture',
                                                                                       'type': 'SEQUENCE'}],
                                                                          'name': 'criticalExtensions',
                                                                          'type': 'CHOICE'}],
                                                             'type': 'SEQUENCE'},
                                     'UECapabilityEnquiry-r8-IEs': {'members': [{'name': 'ue-CapabilityRequest',
                                                                                 'type': 'UE-CapabilityRequest'},
                                                                                {'members': [],
                                                                                 'name': 'nonCriticalExtension',
                                                                                 'optional': True,
                                                                                 'type': 'SEQUENCE'}],
                                                                    'type': 'SEQUENCE'},
                                     'UECapabilityInformation': {'members': [{'name': 'rrc-TransactionIdentifier',
                                                                              'type': 'RRC-TransactionIdentifier'},
                                                                             {'members': [{'members': [{'name': 'ueCapabilityInformation-r8',
                                                                                                        'type': 'UECapabilityInformation-r8-IEs'},
                                                                                                       {'name': 'spare7',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare6',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare5',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare4',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare3',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare2',
                                                                                                        'type': 'NULL'},
                                                                                                       {'name': 'spare1',
                                                                                                        'type': 'NULL'}],
                                                                                           'name': 'c1',
                                                                                           'type': 'CHOICE'},
                                                                                          {'members': [],
                                                                                           'name': 'criticalExtensionsFuture',
                                                                                           'type': 'SEQUENCE'}],
                                                                              'name': 'criticalExtensions',
                                                                              'type': 'CHOICE'}],
                                                                 'type': 'SEQUENCE'},
                                     'UECapabilityInformation-r8-IEs': {'members': [{'name': 'ue-CapabilityRAT-ContainerList',
                                                                                     'type': 'UE-CapabilityRAT-ContainerList'},
                                                                                    {'members': [],
                                                                                     'name': 'nonCriticalExtension',
                                                                                     'optional': True,
                                                                                     'type': 'SEQUENCE'}],
                                                                        'type': 'SEQUENCE'},
                                     'UL-AM-RLC': {'members': [{'name': 't-PollRetransmit',
                                                                'type': 'T-PollRetransmit'},
                                                               {'name': 'pollPDU',
                                                                'type': 'PollPDU'},
                                                               {'name': 'pollByte',
                                                                'type': 'PollByte'},
                                                               {'name': 'maxRetxThreshold',
                                                                'type': 'ENUMERATED',
                                                                'values': {0: 't1',
                                                                           1: 't2',
                                                                           2: 't3',
                                                                           3: 't4',
                                                                           4: 't6',
                                                                           5: 't8',
                                                                           6: 't16',
                                                                           7: 't32'}}],
                                                   'type': 'SEQUENCE'},
                                     'UL-CCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'UL-CCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'UL-CCCH-MessageType': {'members': [{'members': [{'name': 'rrcConnectionReestablishmentRequest',
                                                                                       'type': 'RRCConnectionReestablishmentRequest'},
                                                                                      {'name': 'rrcConnectionRequest',
                                                                                       'type': 'RRCConnectionRequest'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'UL-CyclicPrefixLength': {'type': 'ENUMERATED',
                                                               'values': {0: 'len1',
                                                                          1: 'len2'}},
                                     'UL-DCCH-Message': {'members': [{'name': 'message',
                                                                      'type': 'UL-DCCH-MessageType'}],
                                                         'type': 'SEQUENCE'},
                                     'UL-DCCH-MessageType': {'members': [{'members': [{'name': 'csfbParametersRequestCDMA2000',
                                                                                       'type': 'CSFBParametersRequestCDMA2000'},
                                                                                      {'name': 'measurementReport',
                                                                                       'type': 'MeasurementReport'},
                                                                                      {'name': 'rrcConnectionReconfigurationComplete',
                                                                                       'type': 'RRCConnectionReconfigurationComplete'},
                                                                                      {'name': 'rrcConnectionReestablishmentComplete',
                                                                                       'type': 'RRCConnectionReestablishmentComplete'},
                                                                                      {'name': 'rrcConnectionSetupComplete',
                                                                                       'type': 'RRCConnectionSetupComplete'},
                                                                                      {'name': 'securityModeComplete',
                                                                                       'type': 'SecurityModeComplete'},
                                                                                      {'name': 'securityModeFailure',
                                                                                       'type': 'SecurityModeFailure'},
                                                                                      {'name': 'ueCapabilityInformation',
                                                                                       'type': 'UECapabilityInformation'},
                                                                                      {'name': 'ulHandoverPreparationTransfer',
                                                                                       'type': 'ULHandoverPreparationTransfer'},
                                                                                      {'name': 'ulInformationTransfer',
                                                                                       'type': 'ULInformationTransfer'},
                                                                                      {'name': 'counterCheckResponse',
                                                                                       'type': 'CounterCheckResponse'},
                                                                                      {'name': 'spare5',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare4',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare3',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare2',
                                                                                       'type': 'NULL'},
                                                                                      {'name': 'spare1',
                                                                                       'type': 'NULL'}],
                                                                          'name': 'c1',
                                                                          'type': 'CHOICE'},
                                                                         {'members': [],
                                                                          'name': 'messageClassExtension',
                                                                          'type': 'SEQUENCE'}],
                                                             'type': 'CHOICE'},
                                     'UL-ReferenceSignalsPUSCH': {'members': [{'name': 'groupHoppingEnabled',
                                                                               'type': 'BOOLEAN'},
                                                                              {'name': 'groupAssignmentPUSCH',
                                                                               'restricted-to': [(0,
                                                                                                  29)],
                                                                               'type': 'INTEGER'},
                                                                              {'name': 'sequenceHoppingEnabled',
                                                                               'type': 'BOOLEAN'},
                                                                              {'name': 'cyclicShift',
                                                                               'restricted-to': [(0,
                                                                                                  7)],
                                                                               'type': 'INTEGER'}],
                                                                  'type': 'SEQUENCE'},
                                     'UL-UM-RLC': {'members': [{'name': 'sn-FieldLength',
                                                                'type': 'SN-FieldLength'}],
                                                   'type': 'SEQUENCE'},
                                     'ULHandoverPreparationTransfer': {'members': [{'members': [{'members': [{'name': 'ulHandoverPreparationTransfer-r8',
                                                                                                              'type': 'ULHandoverPreparationTransfer-r8-IEs'},
                                                                                                             {'name': 'spare3',
                                                                                                              'type': 'NULL'},
                                                                                                             {'name': 'spare2',
                                                                                                              'type': 'NULL'},
                                                                                                             {'name': 'spare1',
                                                                                                              'type': 'NULL'}],
                                                                                                 'name': 'c1',
                                                                                                 'type': 'CHOICE'},
                                                                                                {'members': [],
                                                                                                 'name': 'criticalExtensionsFuture',
                                                                                                 'type': 'SEQUENCE'}],
                                                                                    'name': 'criticalExtensions',
                                                                                    'type': 'CHOICE'}],
                                                                       'type': 'SEQUENCE'},
                                     'ULHandoverPreparationTransfer-r8-IEs': {'members': [{'name': 'cdma2000-Type',
                                                                                           'type': 'CDMA2000-Type'},
                                                                                          {'name': 'meid',
                                                                                           'optional': True,
                                                                                           'size': [56],
                                                                                           'type': 'BIT '
                                                                                                   'STRING'},
                                                                                          {'name': 'dedicatedInfo',
                                                                                           'type': 'DedicatedInfoCDMA2000'},
                                                                                          {'members': [],
                                                                                           'name': 'nonCriticalExtension',
                                                                                           'optional': True,
                                                                                           'type': 'SEQUENCE'}],
                                                                              'type': 'SEQUENCE'},
                                     'ULInformationTransfer': {'members': [{'members': [{'members': [{'name': 'ulInformationTransfer-r8',
                                                                                                      'type': 'ULInformationTransfer-r8-IEs'},
                                                                                                     {'name': 'spare3',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare2',
                                                                                                      'type': 'NULL'},
                                                                                                     {'name': 'spare1',
                                                                                                      'type': 'NULL'}],
                                                                                         'name': 'c1',
                                                                                         'type': 'CHOICE'},
                                                                                        {'members': [],
                                                                                         'name': 'criticalExtensionsFuture',
                                                                                         'type': 'SEQUENCE'}],
                                                                            'name': 'criticalExtensions',
                                                                            'type': 'CHOICE'}],
                                                               'type': 'SEQUENCE'},
                                     'ULInformationTransfer-r8-IEs': {'members': [{'members': [{'name': 'dedicatedInfoNAS',
                                                                                                'type': 'DedicatedInfoNAS'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-1XRTT',
                                                                                                'type': 'DedicatedInfoCDMA2000'},
                                                                                               {'name': 'dedicatedInfoCDMA2000-HRPD',
                                                                                                'type': 'DedicatedInfoCDMA2000'}],
                                                                                   'name': 'dedicatedInfoType',
                                                                                   'type': 'CHOICE'},
                                                                                  {'members': [],
                                                                                   'name': 'nonCriticalExtension',
                                                                                   'optional': True,
                                                                                   'type': 'SEQUENCE'}],
                                                                      'type': 'SEQUENCE'},
                                     'UplinkPowerControlCommon': {'members': [{'name': 'p0-NominalPUSCH',
                                                                               'restricted-to': [(-126,
                                                                                                  24)],
                                                                               'type': 'INTEGER'},
                                                                              {'name': 'alpha',
                                                                               'type': 'ENUMERATED',
                                                                               'values': {0: 'al0',
                                                                                          1: 'al04',
                                                                                          2: 'al05',
                                                                                          3: 'al06',
                                                                                          4: 'al07',
                                                                                          5: 'al08',
                                                                                          6: 'al09',
                                                                                          7: 'al1'}},
                                                                              {'name': 'p0-NominalPUCCH',
                                                                               'restricted-to': [(-127,
                                                                                                  -96)],
                                                                               'type': 'INTEGER'},
                                                                              {'name': 'deltaFList-PUCCH',
                                                                               'type': 'DeltaFList-PUCCH'},
                                                                              {'name': 'deltaPreambleMsg3',
                                                                               'restricted-to': [(-1,
                                                                                                  6)],
                                                                               'type': 'INTEGER'}],
                                                                  'type': 'SEQUENCE'},
                                     'UplinkPowerControlDedicated': {'members': [{'name': 'p0-UE-PUSCH',
                                                                                  'restricted-to': [(-8,
                                                                                                     7)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'deltaMCS-Enabled',
                                                                                  'type': 'ENUMERATED',
                                                                                  'values': {0: 'en0',
                                                                                             1: 'en1'}},
                                                                                 {'name': 'accumulationEnabled',
                                                                                  'type': 'BOOLEAN'},
                                                                                 {'name': 'p0-UE-PUCCH',
                                                                                  'restricted-to': [(-8,
                                                                                                     7)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'name': 'pSRS-Offset',
                                                                                  'restricted-to': [(0,
                                                                                                     15)],
                                                                                  'type': 'INTEGER'},
                                                                                 {'default': 'fc4',
                                                                                  'name': 'filterCoefficient',
                                                                                  'type': 'FilterCoefficient'}],
                                                                     'type': 'SEQUENCE'}},
                           'values': {'maxBands': {'type': 'INTEGER',
                                                   'value': 64},
                                      'maxCDMA-BandClass': {'type': 'INTEGER',
                                                            'value': 32},
                                      'maxCellBlack': {'type': 'INTEGER',
                                                       'value': 16},
                                      'maxCellInter': {'type': 'INTEGER',
                                                       'value': 16},
                                      'maxCellIntra': {'type': 'INTEGER',
                                                       'value': 16},
                                      'maxCellMeas': {'type': 'INTEGER',
                                                      'value': 32},
                                      'maxCellReport': {'type': 'INTEGER',
                                                        'value': 8},
                                      'maxDRB': {'type': 'INTEGER',
                                                 'value': 11},
                                      'maxEARFCN': {'type': 'INTEGER',
                                                    'value': 65535},
                                      'maxFreq': {'type': 'INTEGER',
                                                  'value': 8},
                                      'maxGERAN-SI': {'type': 'INTEGER',
                                                      'value': 10},
                                      'maxGNFG': {'type': 'INTEGER',
                                                  'value': 16},
                                      'maxMBSFN-Allocations': {'type': 'INTEGER',
                                                               'value': 8},
                                      'maxMCS-1': {'type': 'INTEGER',
                                                   'value': 16},
                                      'maxMeasId': {'type': 'INTEGER',
                                                    'value': 32},
                                      'maxObjectId': {'type': 'INTEGER',
                                                      'value': 32},
                                      'maxPNOffset': {'type': 'INTEGER',
                                                      'value': 511},
                                      'maxPageRec': {'type': 'INTEGER',
                                                     'value': 16},
                                      'maxRAT-Capabilities': {'type': 'INTEGER',
                                                              'value': 8},
                                      'maxReportConfigId': {'type': 'INTEGER',
                                                            'value': 32},
                                      'maxSI-Message': {'type': 'INTEGER',
                                                        'value': 32},
                                      'maxSIB': {'type': 'INTEGER',
                                                 'value': 32},
                                      'maxSIB-1': {'type': 'INTEGER',
                                                   'value': 31},
                                      'maxUTRA-FDD-Carrier': {'type': 'INTEGER',
                                                              'value': 16},
                                      'maxUTRA-TDD-Carrier': {'type': 'INTEGER',
                                                              'value': 16}}},
 'EUTRA-UE-Variables': {'extensibility-implied': False,
                        'imports': {'EUTRA-RRC-Definitions': ['CellIdentity',
                                                              'SpeedStateScaleFactors',
                                                              'C-RNTI',
                                                              'MeasId',
                                                              'MeasIdToAddModList',
                                                              'MeasObjectToAddModList',
                                                              'MobilityStateParameters',
                                                              'NeighCellConfig',
                                                              'PhysCellId',
                                                              'QuantityConfig',
                                                              'ReportConfigToAddModList',
                                                              'RSRP-Range',
                                                              'maxCellMeas',
                                                              'maxMeasId']},
                        'object-classes': {},
                        'object-sets': {},
                        'tags': 'AUTOMATIC',
                        'types': {'CellsTriggeredList': {'element': {'type': 'PhysCellId'},
                                                         'size': [(1,
                                                                   'maxCellMeas')],
                                                         'type': 'SEQUENCE OF'},
                                  'VarMeasConfig': {'members': [{'name': 'measIdList',
                                                                 'optional': True,
                                                                 'type': 'MeasIdToAddModList'},
                                                                {'name': 'measObjectList',
                                                                 'optional': True,
                                                                 'type': 'MeasObjectToAddModList'},
                                                                {'name': 'reportConfigList',
                                                                 'optional': True,
                                                                 'type': 'ReportConfigToAddModList'},
                                                                {'name': 'quantityConfig',
                                                                 'optional': True,
                                                                 'type': 'QuantityConfig'},
                                                                {'name': 's-Measure',
                                                                 'optional': True,
                                                                 'type': 'RSRP-Range'},
                                                                {'members': [{'name': 'release',
                                                                              'type': 'NULL'},
                                                                             {'members': [{'name': 'mobilityStateParameters',
                                                                                           'type': 'MobilityStateParameters'},
                                                                                          {'name': 'timeToTrigger-SF',
                                                                                           'type': 'SpeedStateScaleFactors'}],
                                                                              'name': 'setup',
                                                                              'type': 'SEQUENCE'}],
                                                                 'name': 'speedStatePars',
                                                                 'optional': True,
                                                                 'type': 'CHOICE'}],
                                                    'type': 'SEQUENCE'},
                                  'VarMeasReport': {'members': [{'name': 'measId',
                                                                 'type': 'MeasId'},
                                                                {'name': 'cellsTriggeredList',
                                                                 'optional': True,
                                                                 'type': 'CellsTriggeredList'},
                                                                {'name': 'numberOfReportsSent',
                                                                 'type': 'INTEGER'}],
                                                    'type': 'SEQUENCE'},
                                  'VarMeasReportList': {'element': {'type': 'VarMeasReport'},
                                                        'size': [(1,
                                                                  'maxMeasId')],
                                                        'type': 'SEQUENCE OF'},
                                  'VarShortMAC-Input': {'members': [{'name': 'cellIdentity',
                                                                     'type': 'CellIdentity'},
                                                                    {'name': 'physCellId',
                                                                     'type': 'PhysCellId'},
                                                                    {'name': 'c-RNTI',
                                                                     'type': 'C-RNTI'}],
                                                        'type': 'SEQUENCE'}},
                        'values': {}}}